
/**
 * File csl_serdes_restore_default.h
 *
 *  Brief
 *  Autogenerated SERDES CONFIG Functions.
 *
 *  It restores the serdes to its default values
 *
 *  
 *  ============================================================================
 *  @n   (C) Copyright 2013, Texas Instruments, Inc.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
*/

/** ============================================================================ 
 *
 * @defgroup CSL_SERDES_RESTORE SERDES RESTORE
 * @ingroup CSL_SERDES_API
 *
 * @section Introduction
 *
 * @subsection xxx Overview
 * This module deals with setting up SERDES restore configuration after a shutdown is initiated. The API flow should be as follows:   \n
 *
 * CSL_SerDes_COMLANE_Restore_Default (base_addr);
 *
 * CSL_SerDes_Lane_Restore_Default (base_addr, lane_num);
 *
 * CSL_SerDes_CMU_Restore_Default (base_addr);
 *
 * @subsection References
 *    
 * ============================================================================
 */ 

/** @addtogroup CSL_SERDES_RESTORE
 @{ */
/** ============================================================================
 *   @n@b CSL_SerDes_CMU_Restore_Default
 *
 *   @b Description
 *   @n This API restores the Serdes CMU registers.
 *
 *   @b Arguments   base_addr
 *
 *   <b> Return Value  </b>  None
 *
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @n  None
 *
 *   @b Reads
 *   @n None 
 *
 *  <b> Usage Constraints: </b>
 *  @n  Should be called after CSL_SerDes_COMLANE_Restore_Default and CSL_SerDes_Lane_Restore_Default APIs
 *
 *   @b Example
 *   @verbatim
 
    CSL_SerDes_CMU_Restore_Default(CSL_PCIE_SERDES_CFG_REGS);

    @endverbatim
 * ===========================================================================
 */
CSL_IDEF_INLINE void CSL_SerDes_CMU_Restore_Default
(
 uint32_t base_addr
) 
{

/* CMU DEFAULTS */
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x0), 15, 8, (uint32_t)0x8);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x0), 23, 16, (uint32_t)0x82);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x0), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x4), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x4), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x4), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x4), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x8), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x8), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x8), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x8), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xc), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xc), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xc), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xc), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x10), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x10), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x10), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x10), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x14), 7, 0, (uint32_t)0x2E);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x14), 15, 8, (uint32_t)0x2E);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x14), 23, 16, (uint32_t)0x5);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x14), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x18), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x18), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x18), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x18), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x1c), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x1c), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x1c), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x1c), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x20), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x20), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x20), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x20), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x24), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x24), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x24), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x24), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x28), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x28), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x28), 23, 16, (uint32_t)0x2);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x28), 31, 24, (uint32_t)0xA0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x2c), 7, 0, (uint32_t)0x2);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x2c), 15, 8, (uint32_t)0x44);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x2c), 23, 16, (uint32_t)0x41);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x2c), 31, 24, (uint32_t)0x20);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x30), 7, 0, (uint32_t)0x0C);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x30), 15, 8, (uint32_t)0x20);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x30), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x30), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x34), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x34), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x34), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x34), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x38), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x38), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x38), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x38), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x3c), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x3c), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x3c), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x3c), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x40), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x40), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x40), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x40), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x44), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x44), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x44), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x44), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x48), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x48), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x48), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x48), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x4c), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x4c), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x4c), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x4c), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x50), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x50), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x50), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x50), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x54), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x54), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x54), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x54), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x58), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x58), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x58), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x58), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x5c), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x5c), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x5c), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x5c), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x60), 7, 0, (uint32_t)0x48);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x60), 15, 8, (uint32_t)0xE6);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x60), 23, 16, (uint32_t)0x44);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x60), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x64), 7, 0, (uint32_t)0x2);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x64), 15, 8, (uint32_t)0x87);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x64), 23, 16, (uint32_t)0xC1);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x64), 31, 24, (uint32_t)0x2);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x68), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x68), 15, 8, (uint32_t)0x82);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x68), 23, 16, (uint32_t)0x0F);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x68), 31, 24, (uint32_t)0x17);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x6c), 7, 0, (uint32_t)0x14);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x6c), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x6c), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x6c), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x70), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x70), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x70), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x70), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x74), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x74), 15, 8, (uint32_t)0xC8);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x74), 23, 16, (uint32_t)0x32);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x74), 31, 24, (uint32_t)0x1C);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x78), 7, 0, (uint32_t)0x9);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x78), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x78), 23, 16, (uint32_t)0x2);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x78), 31, 24, (uint32_t)0x40);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x7c), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x7c), 15, 8, (uint32_t)0x1C);

}	     

/** @addtogroup CSL_SERDES_RESTORE
 @{ */
/** ============================================================================
 *   @n@b CSL_SerDes_COMLANE_Restore_Default
 *
 *   @b Description
 *   @n This API restores the Serdes COMLANE registers.
 *
 *   @b Arguments   base_addr
 *
 *   <b> Return Value  </b>  None
 *
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @n  None
 *
 *   @b Reads
 *   @n None 
 *
 *  <b> Usage Constraints: </b>
 *  @n  Should be called after Lanes have been disabled and TX CMU PLL is disabled. (Available in each IP serdes shutdown APIs)
 *
 *   @b Example
 *   @verbatim
 
    CSL_SerDes_COMLANE_Restore_Default(CSL_PCIE_SERDES_CFG_REGS);

    @endverbatim
 * ===========================================================================
 */
CSL_IDEF_INLINE void CSL_SerDes_COMLANE_Restore_Default
(
 uint32_t base_addr
) 
{

/* COMLANE DEFAULTS */
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x0), 7, 0, (uint32_t)0x40);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x000 + 0x0), 7, 0, (uint32_t)0x02);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x0), 15, 8, (uint32_t)0x4);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x0), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x0), 31, 24, (uint32_t)0x4);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x4), 7, 0, (uint32_t)0x1E);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x4), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x4), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x4), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x8), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x8), 15, 8, (uint32_t)0x85);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x8), 23, 16, (uint32_t)0xE2);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x8), 31, 24, (uint32_t)0x32);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xc), 7, 0, (uint32_t)0x82);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xc), 15, 8, (uint32_t)0x1);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xc), 23, 16, (uint32_t)0x18);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xc), 31, 24, (uint32_t)0x74);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x10), 7, 0, (uint32_t)0x6);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x10), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x10), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x14), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x18), 7, 0, (uint32_t)0x63);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x18), 15, 8, (uint32_t)0x14);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x18), 23, 16, (uint32_t)0x68);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x18), 31, 24, (uint32_t)0xBC);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x1c), 7, 0, (uint32_t)0xC0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x1c), 15, 8, (uint32_t)0x2E);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x30), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x30), 15, 8, (uint32_t)0x2E);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x30), 23, 16, (uint32_t)0x2E);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x30), 31, 24, (uint32_t)0x14);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x34), 7, 0, (uint32_t)0x14);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x34), 15, 8, (uint32_t)0x14);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x34), 23, 16, (uint32_t)0x14);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x34), 31, 24, (uint32_t)0x14);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x38), 7, 0, (uint32_t)0x14);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x38), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x38), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x38), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x3c), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x3c), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x3c), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x3c), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x40), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x40), 15, 8, (uint32_t)0x95);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x40), 23, 16, (uint32_t)0x4C);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x40), 31, 24, (uint32_t)0xE4);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x44), 7, 0, (uint32_t)0x95);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x44), 15, 8, (uint32_t)0xBD);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x44), 23, 16, (uint32_t)0x3);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x44), 31, 24, (uint32_t)0x58);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x48), 7, 0, (uint32_t)0xC9);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x48), 15, 8, (uint32_t)0xD0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x48), 23, 16, (uint32_t)0xC5);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x48), 31, 24, (uint32_t)0x34);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x4c), 7, 0, (uint32_t)0x0B);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x4c), 15, 8, (uint32_t)0x87);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x4c), 23, 16, (uint32_t)0x2);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x4c), 31, 24, (uint32_t)0xA0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x50), 7, 0, (uint32_t)0x0A);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x50), 15, 8, (uint32_t)0x98);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x50), 23, 16, (uint32_t)0x0F);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x50), 31, 24, (uint32_t)0x51);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x54), 7, 0, (uint32_t)0x82);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x54), 15, 8, (uint32_t)0x4E);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x54), 23, 16, (uint32_t)0x2E);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x54), 31, 24, (uint32_t)0x40);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x58), 7, 0, (uint32_t)0x7A);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x58), 15, 8, (uint32_t)0x11);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x58), 23, 16, (uint32_t)0x2D);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x58), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x5c), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x5c), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x5c), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x5c), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x60), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x60), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x60), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x60), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x64), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x64), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x64), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x64), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x68), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x68), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x68), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x68), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x6c), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x6c), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x6c), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x6c), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x70), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x70), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x70), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x70), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x74), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x74), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x74), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x74), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x78), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x78), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x78), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x78), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x7c), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x7c), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x7c), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x7c), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x80), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x80), 15, 8, (uint32_t)0xFF);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x80), 23, 16, (uint32_t)0x1);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x80), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x84), 7, 0, (uint32_t)0x83);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x84), 15, 8, (uint32_t)0x7);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x84), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x84), 31, 24, (uint32_t)0xF0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x88), 7, 0, (uint32_t)0xFF);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x88), 15, 8, (uint32_t)0xFF);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x88), 23, 16, (uint32_t)0x3F);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x88), 31, 24, (uint32_t)0xCF);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x8c), 7, 0, (uint32_t)0x2F);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x8c), 15, 8, (uint32_t)0x23);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x8c), 23, 16, (uint32_t)0x13);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x8c), 31, 24, (uint32_t)0x83);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x90), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x90), 15, 8, (uint32_t)0x20);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x90), 23, 16, (uint32_t)0x50);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x90), 31, 24, (uint32_t)0x55);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x94), 7, 0, (uint32_t)0x55);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x94), 15, 8, (uint32_t)0x55);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x94), 31, 24, (uint32_t)0x1);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x98), 7, 0, (uint32_t)0x20);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x98), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x9c), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xa0), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xa0), 31, 24, (uint32_t)0x80);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xa4), 7, 0, (uint32_t)0x15);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xa4), 15, 8, (uint32_t)0xA8);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xa4), 23, 16, (uint32_t)0x52);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xa4), 31, 24, (uint32_t)0xAD);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xa8), 7, 0, (uint32_t)0x52);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xa8), 15, 8, (uint32_t)0xAD);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xa8), 23, 16, (uint32_t)0x52);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xa8), 31, 24, (uint32_t)0x5);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xac), 7, 0, (uint32_t)0xF8);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xac), 15, 8, (uint32_t)0x3);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xac), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xac), 31, 24, (uint32_t)0x29);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xb0), 7, 0, (uint32_t)0x6B);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xb0), 15, 8, (uint32_t)0x81);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xb0), 23, 16, (uint32_t)0x20);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xb0), 31, 24, (uint32_t)0x8);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xb4), 7, 0, (uint32_t)0x82);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xb4), 15, 8, (uint32_t)0x97);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xb4), 23, 16, (uint32_t)0x40);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xb4), 31, 24, (uint32_t)0x10);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xb8), 7, 0, (uint32_t)0x4);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xb8), 15, 8, (uint32_t)0x1);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xb8), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xb8), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xbc), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xbc), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xbc), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xbc), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xc0), 7, 0, (uint32_t)0x88);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xc0), 15, 8, (uint32_t)0xFA);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xc0), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xc0), 31, 24, (uint32_t)0x28);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xc4), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xc4), 15, 8, (uint32_t)0x28);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xc4), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xc4), 31, 24, (uint32_t)0x1);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xc8), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xe8), 31, 24, (uint32_t)0x3);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xec), 7, 0, (uint32_t)0x3);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xec), 15, 8, (uint32_t)0x40);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xec), 23, 16, (uint32_t)0x1F);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xec), 31, 24, (uint32_t)0x54);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xf0), 7, 0, (uint32_t)0x1);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xf0), 15, 8, (uint32_t)0xA5);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xf0), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xf0), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xf4), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xf4), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xf4), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xf4), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xf8), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0xfc), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x100), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x100), 15, 8, (uint32_t)0xA5);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x100), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x100), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x104), 7, 0, (uint32_t)0x5);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x104), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x104), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x108), 7, 0, (uint32_t)0x33);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x108), 15, 8, (uint32_t)0x58);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x108), 23, 16, (uint32_t)0x4F);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x108), 31, 24, (uint32_t)0x87);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x10c), 7, 0, (uint32_t)0x5F);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x10c), 15, 8, (uint32_t)0xC0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x10c), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x10c), 31, 24, (uint32_t)0x4);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x110), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x110), 15, 8, (uint32_t)0x1D);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x110), 23, 16, (uint32_t)0x1);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x110), 31, 24, (uint32_t)0x3F);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x114), 7, 0, (uint32_t)0xDF);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x114), 15, 8, (uint32_t)0x71);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x114), 23, 16, (uint32_t)0x3F);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x114), 31, 24, (uint32_t)0x1D);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x118), 7, 0, (uint32_t)0x31);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x118), 15, 8, (uint32_t)0xC0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x118), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x118), 31, 24, (uint32_t)0x0C);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x11c), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x11c), 15, 8, (uint32_t)0x1D);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x11c), 23, 16, (uint32_t)0x1);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x11c), 31, 24, (uint32_t)0x3F);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x120), 7, 0, (uint32_t)0xDF);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x120), 15, 8, (uint32_t)0x71);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x120), 23, 16, (uint32_t)0x3F);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x120), 31, 24, (uint32_t)0x1D);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x124), 7, 0, (uint32_t)0x31);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x1f4), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x1f4), 15, 8, (uint32_t)0x0F);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x1f4), 31, 24, (uint32_t)0xF1);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0xa00 + 0x1f8), 7, 0, (uint32_t)0x0);

}

/** @addtogroup CSL_SERDES_RESTORE
 @{ */
/** ============================================================================
 *   @n@b CSL_SerDes_Lane_Restore_Default
 *
 *   @b Description
 *   @n This API restores the Serdes Lane registers.
 *
 *   @b Arguments   base_addr, lane_num
 *
 *   <b> Return Value  </b>  None
 *
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @n  None
 *
 *   @b Reads
 *   @n None 
 *
 *  <b> Usage Constraints: </b>
 *  @n  Should be called after CSL_SerDes_COMLANE_Restore_Default
 *
 *   @b Example
 *   @verbatim
 
    CSL_SerDes_Lane_Restore_Default(CSL_PCIE_SERDES_CFG_REGS);

    @endverbatim
 * ===========================================================================
 */
CSL_IDEF_INLINE void CSL_SerDes_Lane_Restore_Default
(
 uint32_t base_addr,
 uint32_t lane_num
)

{

/* LANE_DEFAULTS */
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x0 + (0x200)*lane_num), 7, 0, (uint32_t)0x2);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x0 + (0x200)*lane_num), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x0 + (0x200)*lane_num), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x0 + (0x200)*lane_num), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x4 + (0x200)*lane_num), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x4 + (0x200)*lane_num), 15, 8, (uint32_t)0x10);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x4 + (0x200)*lane_num), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x4 + (0x200)*lane_num), 31, 24, (uint32_t)0x74);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x8 + (0x200)*lane_num), 7, 0, (uint32_t)0x20);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x8 + (0x200)*lane_num), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x8 + (0x200)*lane_num), 23, 16, (uint32_t)0x2);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0xc + (0x200)*lane_num), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x10 + (0x200)*lane_num), 7, 0, (uint32_t)0x22);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x10 + (0x200)*lane_num), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x10 + (0x200)*lane_num), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x10 + (0x200)*lane_num), 31, 24, (uint32_t)0x1B);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x14 + (0x200)*lane_num), 7, 0, (uint32_t)0x98);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x14 + (0x200)*lane_num), 15, 8, (uint32_t)0x33);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x14 + (0x200)*lane_num), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x14 + (0x200)*lane_num), 31, 24, (uint32_t)0x8);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x18 + (0x200)*lane_num), 7, 0, (uint32_t)0x4);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x18 + (0x200)*lane_num), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x18 + (0x200)*lane_num), 23, 16, (uint32_t)0x80);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x18 + (0x200)*lane_num), 31, 24, (uint32_t)0x75);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x1c + (0x200)*lane_num), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x1c + (0x200)*lane_num), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x1c + (0x200)*lane_num), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x1c + (0x200)*lane_num), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x20 + (0x200)*lane_num), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x20 + (0x200)*lane_num), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x20 + (0x200)*lane_num), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x20 + (0x200)*lane_num), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x24 + (0x200)*lane_num), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x24 + (0x200)*lane_num), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x24 + (0x200)*lane_num), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x24 + (0x200)*lane_num), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x28 + (0x200)*lane_num), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x28 + (0x200)*lane_num), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x28 + (0x200)*lane_num), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x28 + (0x200)*lane_num), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x2c + (0x200)*lane_num), 7, 0, (uint32_t)0x3);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x2c + (0x200)*lane_num), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x2c + (0x200)*lane_num), 23, 16, (uint32_t)0x30);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x2c + (0x200)*lane_num), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x30 + (0x200)*lane_num), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x30 + (0x200)*lane_num), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x30 + (0x200)*lane_num), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x30 + (0x200)*lane_num), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x34 + (0x200)*lane_num), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x34 + (0x200)*lane_num), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x34 + (0x200)*lane_num), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x34 + (0x200)*lane_num), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x38 + (0x200)*lane_num), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x38 + (0x200)*lane_num), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x38 + (0x200)*lane_num), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x38 + (0x200)*lane_num), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x3c + (0x200)*lane_num), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x3c + (0x200)*lane_num), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x3c + (0x200)*lane_num), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x3c + (0x200)*lane_num), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x40 + (0x200)*lane_num), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x40 + (0x200)*lane_num), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x40 + (0x200)*lane_num), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x40 + (0x200)*lane_num), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x44 + (0x200)*lane_num), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x44 + (0x200)*lane_num), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x44 + (0x200)*lane_num), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x44 + (0x200)*lane_num), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x48 + (0x200)*lane_num), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x48 + (0x200)*lane_num), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x4c + (0x200)*lane_num), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x4c + (0x200)*lane_num), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x4c + (0x200)*lane_num), 23, 16, (uint32_t)0x80);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x4c + (0x200)*lane_num), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x50 + (0x200)*lane_num), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x50 + (0x200)*lane_num), 15, 8, (uint32_t)0x1B);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x50 + (0x200)*lane_num), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x50 + (0x200)*lane_num), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x54 + (0x200)*lane_num), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x58 + (0x200)*lane_num), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x58 + (0x200)*lane_num), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x5c + (0x200)*lane_num), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x5c + (0x200)*lane_num), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x5c + (0x200)*lane_num), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x5c + (0x200)*lane_num), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x60 + (0x200)*lane_num), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x78 + (0x200)*lane_num), 15, 8, (uint32_t)0x50);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x78 + (0x200)*lane_num), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x78 + (0x200)*lane_num), 31, 24, (uint32_t)0x8F);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x7c + (0x200)*lane_num), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x7c + (0x200)*lane_num), 15, 8, (uint32_t)0x2A);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x7c + (0x200)*lane_num), 23, 16, (uint32_t)0x9);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x7c + (0x200)*lane_num), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x80 + (0x200)*lane_num), 7, 0, (uint32_t)0x80);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x80 + (0x200)*lane_num), 15, 8, (uint32_t)0x50);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x80 + (0x200)*lane_num), 23, 16, (uint32_t)0x80);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x80 + (0x200)*lane_num), 31, 24, (uint32_t)0x50);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x84 + (0x200)*lane_num), 7, 0, (uint32_t)0x90);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x84 + (0x200)*lane_num), 15, 8, (uint32_t)0x1F);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x84 + (0x200)*lane_num), 23, 16, (uint32_t)0x49);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x84 + (0x200)*lane_num), 31, 24, (uint32_t)0x6D);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x88 + (0x200)*lane_num), 7, 0, (uint32_t)0x40);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x88 + (0x200)*lane_num), 15, 8, (uint32_t)0x20);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x88 + (0x200)*lane_num), 23, 16, (uint32_t)0x20);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x88 + (0x200)*lane_num), 31, 24, (uint32_t)0x20);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x8c + (0x200)*lane_num), 7, 0, (uint32_t)0x20);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x8c + (0x200)*lane_num), 15, 8, (uint32_t)0x48);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x8c + (0x200)*lane_num), 23, 16, (uint32_t)0x40);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x8c + (0x200)*lane_num), 31, 24, (uint32_t)0x20);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x90 + (0x200)*lane_num), 7, 0, (uint32_t)0x20);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x90 + (0x200)*lane_num), 15, 8, (uint32_t)0x20);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x90 + (0x200)*lane_num), 23, 16, (uint32_t)0x20);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x90 + (0x200)*lane_num), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x94 + (0x200)*lane_num), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x94 + (0x200)*lane_num), 15, 8, (uint32_t)0x30);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x94 + (0x200)*lane_num), 23, 16, (uint32_t)0x63);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x94 + (0x200)*lane_num), 31, 24, (uint32_t)0x66);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x98 + (0x200)*lane_num), 7, 0, (uint32_t)0x44);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x98 + (0x200)*lane_num), 15, 8, (uint32_t)0x44);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x98 + (0x200)*lane_num), 23, 16, (uint32_t)0xF4);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x98 + (0x200)*lane_num), 31, 24, (uint32_t)0x79);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x9c + (0x200)*lane_num), 7, 0, (uint32_t)0x2);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x9c + (0x200)*lane_num), 15, 8, (uint32_t)0x30);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x9c + (0x200)*lane_num), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0x9c + (0x200)*lane_num), 31, 24, (uint32_t)0x10);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0xa0 + (0x200)*lane_num), 7, 0, (uint32_t)0x48);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0xa0 + (0x200)*lane_num), 15, 8, (uint32_t)0x30);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0xa0 + (0x200)*lane_num), 23, 16, (uint32_t)0x22);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0xa0 + (0x200)*lane_num), 31, 24, (uint32_t)0x33);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0xa4 + (0x200)*lane_num), 7, 0, (uint32_t)0x3);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0xa4 + (0x200)*lane_num), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0xa4 + (0x200)*lane_num), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0xa4 + (0x200)*lane_num), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0xa8 + (0x200)*lane_num), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0xa8 + (0x200)*lane_num), 15, 8, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0xa8 + (0x200)*lane_num), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0xa8 + (0x200)*lane_num), 31, 24, (uint32_t)0x50);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0xac + (0x200)*lane_num), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0xac + (0x200)*lane_num), 15, 8, (uint32_t)0x40);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0xac + (0x200)*lane_num), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0xac + (0x200)*lane_num), 31, 24, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0xb0 + (0x200)*lane_num), 7, 0, (uint32_t)0xF0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0xb0 + (0x200)*lane_num), 15, 8, (uint32_t)0xBD);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0xb0 + (0x200)*lane_num), 23, 16, (uint32_t)0x38);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0xb0 + (0x200)*lane_num), 31, 24, (uint32_t)0x12);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0xb4 + (0x200)*lane_num), 7, 0, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0xb4 + (0x200)*lane_num), 15, 8, (uint32_t)0x0A);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0xb4 + (0x200)*lane_num), 23, 16, (uint32_t)0x0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0xb4 + (0x200)*lane_num), 31, 24, (uint32_t)0xD0);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0xb8 + (0x200)*lane_num), 7, 0, (uint32_t)0x7);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0xb8 + (0x200)*lane_num), 15, 8, (uint32_t)0x4);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200 + 0xb8 + (0x200)*lane_num), 23, 16, (uint32_t)0x0);

}
/* @} */
