/********************************************************************
 * Copyright (C) 2003-2014 Texas Instruments Incorporated.
 * 
 *  Redistribution and use in source and binary forms, with or without 
 *  modification, are permitted provided that the following conditions 
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright 
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the 
 *    documentation and/or other materials provided with the   
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
*/
#ifndef _CSLR_TAC2_CFG_V0_H_
#define _CSLR_TAC2_CFG_V0_H_

/* CSL Modification:
 *  The file has been modified from the AUTOGEN file for the following
 *  reasons:-
 *      a) Modified the header file includes to be RTSC compliant
 *      b) Removed extra occurrence of CSL_TAC_CFG_ACM2_FRAME_ID_MASK
 *      c) Fixes. Removed occurrence of _SGCP6(7)_, _FE(3)_.
 */

#include <ti/csl/cslr.h>
#include <ti/csl/tistdtypes.h>

#define CSL_TAC_NUM_SGCP  6
#define CSL_TAC_NUM_FEI   (CSL_TAC_NUM_SGCP/2)

/* Minimum unit = 4 bytes */

/**************************************************************************\
* Register Overlay Structure for WAR_BUF
\**************************************************************************/
typedef struct  {
    volatile Uint32 WAR_BUF0;
    volatile Uint32 WAR_BUF1;
    volatile Uint32 WAR_BUF2;
    volatile Uint32 RSVD0;
} CSL_Tac_cfgWar_bufRegs;

/**************************************************************************\
* Register Overlay Structure for MIT
\**************************************************************************/
typedef struct  {
    volatile Uint32 MIT0;
    volatile Uint32 MIT1;
} CSL_Tac_cfgMitRegs;

/**************************************************************************\
* Register Overlay Structure for ACM
\**************************************************************************/
typedef struct  {
    volatile Uint32 ACM0;
    volatile Uint32 ACM1;
    volatile Uint32 ACM2;
    volatile Uint32 ACM3;
} CSL_Tac_cfgAcmRegs;

/**************************************************************************\
* Register Overlay Structure for VCT
\**************************************************************************/
typedef struct  {
    volatile Uint32 VCT0;
    volatile Uint32 VCT1;
    volatile Uint32 VCT2;
    volatile Uint32 VCT3;
    volatile Uint32 VCT4;
    volatile Uint32 VCT5;
    volatile Uint32 VCT6;
    volatile Uint32 VCT7;
} CSL_Tac_cfgVctRegs;

/**************************************************************************\
* Register Overlay Structure for MST_STATS
\**************************************************************************/
typedef struct  {
    volatile Uint32 MST0;
    volatile Uint32 MST1;
    volatile Uint32 MST2;
    volatile Uint32 RSVD0;
} CSL_Tac_cfgMstStatsRegs;

/**************************************************************************\
* Register Overlay Structure for the Front End
\**************************************************************************/
typedef struct  {
    volatile Uint32 FE_PID;
    volatile Uint32 FE_ENA;
    volatile Uint32 FE_STAT;
    volatile Uint32 RSVD1;
    CSL_Tac_cfgWar_bufRegs WAR_BUF[5];
    volatile Uint32 CPM_START_AD;
    volatile Uint32 CPM_SIZE;
    volatile Uint32 CPM_WR_PTR;
    volatile Uint32 RSVD2;
    volatile Uint32 FE_SW_RESET;
    volatile Uint32 RSVD3[3];
    volatile Uint32 FE_HEAD_PRIO;
    volatile Uint32 FE_DATA_PRIO;
    volatile Uint32 FE_WARN_PRIO;
    volatile Uint32 FE_CPM_PRIO;
    volatile Uint32 RSVD4[4];
    volatile Uint32 FE_TRANS_CFG;
    volatile Uint32 FE_TRANS_INT;
    volatile Uint32 RSVD5[22];
    CSL_Tac_cfgMitRegs MIT[16];
    volatile Uint32 RSVD6[32];
    volatile Uint32 FE_WR_TRANS_STAT;
    volatile Uint32 RSVD7[895];
} CSL_Tac_cfgFeRegs;

/**************************************************************************\
* Register Overlay Structure
\**************************************************************************/
typedef struct  {
    CSL_Tac_cfgFeRegs FE[3];
    volatile Uint32 RSVD0[5120];
    volatile Uint32 BETI_CTRL;
    volatile Uint32 BETI_STAT;
    volatile Uint32 BETI_WCFG;
    volatile Uint32 BETI_WST;
    volatile Uint32 BETI_WINT;
    volatile Uint32 BETI_DEF_ANT;
    volatile Uint32 RSVD1[2];
    volatile Uint32 BETI_SPC;
    volatile Uint32 BETI_SW_ITE_START;
    volatile Uint32 RSVD2[502];
    CSL_Tac_cfgAcmRegs ACM[64];
    CSL_Tac_cfgVctRegs VCT[32];
    volatile Uint32 BEII_CTRL;
    volatile Uint32 RSVD3;
    volatile Uint32 BEII_IRS0;
    volatile Uint32 BEII_IRS1;
    volatile Uint32 BEII_ICS0;
    volatile Uint32 BEII_ICS1;
    volatile Uint32 BEII_IES0;
    volatile Uint32 BEII_IES1;
    volatile Uint32 BEII_IE0;
    volatile Uint32 BEII_IE1;
    volatile Uint32 BEII_IECS0;
    volatile Uint32 BEII_IECS1;
    volatile Uint32 BEII_EOI;
    volatile Uint32 RSVD4[1011];
    volatile Uint32 CFG_TOT;
    volatile Uint32 CFG_WRIT;
    volatile Uint32 CFG_READ;
    volatile Uint32 RSVD5;
    volatile Uint32 SLV_TOT;
    volatile Uint32 SLV_WRIT;
    volatile Uint32 SLV_READ;
    volatile Uint32 RSVD6;
    CSL_Tac_cfgMstStatsRegs MST_STATS[3];
} CSL_Tac_cfgRegs;

/**************************************************************************\
* Field Definition Macros
\**************************************************************************/

/* WAR_BUF0 */

#define CSL_TAC_CFG_WAR_BUF0_START_AD_MASK (0xFFFFFFFFu)
#define CSL_TAC_CFG_WAR_BUF0_START_AD_SHIFT (0x00000000u)
#define CSL_TAC_CFG_WAR_BUF0_START_AD_RESETVAL (0x00000000u)


#define CSL_TAC_CFG_WAR_BUF0_RESETVAL    (0x00000000u)

/* WAR_BUF1 */


#define CSL_TAC_CFG_WAR_BUF1_SIZE_MASK   (0x0000FFFFu)
#define CSL_TAC_CFG_WAR_BUF1_SIZE_SHIFT  (0x00000000u)
#define CSL_TAC_CFG_WAR_BUF1_SIZE_RESETVAL (0x00000000u)


#define CSL_TAC_CFG_WAR_BUF1_RESETVAL    (0x00000000u)

/* WAR_BUF2 */


#define CSL_TAC_CFG_WAR_BUF2_WR_PTR_MASK (0x0000FFFFu)
#define CSL_TAC_CFG_WAR_BUF2_WR_PTR_SHIFT (0x00000000u)
#define CSL_TAC_CFG_WAR_BUF2_WR_PTR_RESETVAL (0x00000000u)

#define CSL_TAC_CFG_WAR_BUF2_RESETVAL    (0x00000000u)

/* MIT0 */

#define CSL_TAC_CFG_MIT0_FRAME_ID_MASK (0x3FFC0000u)
#define CSL_TAC_CFG_MIT0_FRAME_ID_SHIFT (0x00000012u)
#define CSL_TAC_CFG_MIT0_FRAME_ID_RESETVAL (0x00000000u)

#define CSL_TAC_CFG_MIT0_HEADER_FLAG_MASK (0x00020000u)
#define CSL_TAC_CFG_MIT0_HEADER_FLAG_SHIFT (0x00000011u)
#define CSL_TAC_CFG_MIT0_HEADER_FLAG_RESETVAL (0x00000000u)
/*----HEADER_FLAG Tokens----*/
#define CSL_TAC_CFG_MIT0_HEADER_FLAG_DATA (0x00000000u)
#define CSL_TAC_CFG_MIT0_HEADER_FLAG_HEADER (0x00000001u)

#define CSL_TAC_CFG_MIT0_CHANNEL_KIND_MASK (0x0001E000u)
#define CSL_TAC_CFG_MIT0_CHANNEL_KIND_SHIFT (0x0000000Du)
#define CSL_TAC_CFG_MIT0_CHANNEL_KIND_RESETVAL (0x00000000u)

#define CSL_TAC_CFG_MIT0_SPREADER_IDX_MASK (0x00001FF0u)
#define CSL_TAC_CFG_MIT0_SPREADER_IDX_SHIFT (0x00000004u)
#define CSL_TAC_CFG_MIT0_SPREADER_IDX_RESETVAL (0x00000000u)

#define CSL_TAC_CFG_MIT0_SGCP_ID_MASK (0x0000000Eu)
#define CSL_TAC_CFG_MIT0_SGCP_ID_SHIFT   (0x00000001u)
#define CSL_TAC_CFG_MIT0_SGCP_ID_RESETVAL (0x00000000u)

#define CSL_TAC_CFG_MIT0_TRANS_STAT_MASK (0x00000001u)
#define CSL_TAC_CFG_MIT0_TRANS_STAT_SHIFT (0x00000000u)
#define CSL_TAC_CFG_MIT0_TRANS_STAT_RESETVAL (0x00000000u)
/*----TRANS_STAT Tokens----*/
#define CSL_TAC_CFG_MIT0_TRANS_STAT_IDLE (0x00000000u)
#define CSL_TAC_CFG_MIT0_TRANS_STAT_PENDING (0x00000001u)

#define CSL_TAC_CFG_MIT0_RESETVAL        (0x00000000u)

/* MIT1 */


#define CSL_TAC_CFG_MIT1_SIG_TASK_IDX_MASK (0x00001FF0u)
#define CSL_TAC_CFG_MIT1_SIG_TASK_IDX_SHIFT (0x00000004u)
#define CSL_TAC_CFG_MIT1_SIG_TASK_IDX_RESETVAL (0x00000000u)
#define CSL_TAC_CFG_MIT1_OPTION_MASK (0x0000000Fu)
#define CSL_TAC_CFG_MIT1_OPTION_SHIFT (0x00000000u)
#define CSL_TAC_CFG_MIT1_OPTION_RESETVAL (0x00000000u)

#define CSL_TAC_CFG_MIT1_RESETVAL        (0x00000000u)

/* ACM0 */

#define CSL_TAC_CFG_ACM0_I_PART_MASK     (0xFFFF0000u)
#define CSL_TAC_CFG_ACM0_I_PART_SHIFT    (0x00000010u)
#define CSL_TAC_CFG_ACM0_I_PART_RESETVAL (0x00000000u)

#define CSL_TAC_CFG_ACM0_Q_PART_MASK     (0x0000FFFFu)
#define CSL_TAC_CFG_ACM0_Q_PART_SHIFT    (0x00000000u)
#define CSL_TAC_CFG_ACM0_Q_PART_RESETVAL (0x00000000u)

#define CSL_TAC_CFG_ACM0_RESETVAL        (0x00000000u)

/* ACM1 */


#define CSL_TAC_CFG_ACM1_TCELL_MASK      (0x00007FF0u)
#define CSL_TAC_CFG_ACM1_TCELL_SHIFT     (0x00000004u)
#define CSL_TAC_CFG_ACM1_TCELL_RESETVAL  (0x00000000u)

#define CSL_TAC_CFG_ACM1_SAT_DYN_RANGE_MASK (0x0000000Fu)
#define CSL_TAC_CFG_ACM1_SAT_DYN_RANGE_SHIFT (0x00000000u)
#define CSL_TAC_CFG_ACM1_SAT_DYN_RANGE_RESETVAL (0x00000000u)

#define CSL_TAC_CFG_ACM1_RESETVAL        (0x00000000u)

/* ACM2 */

#define CSL_TAC_CFG_ACM2_VAM_SHIFTER_VALUE_MASK (0xF8000000u)
#define CSL_TAC_CFG_ACM2_VAM_SHIFTER_VALUE_SHIFT (0x0000001Bu)
#define CSL_TAC_CFG_ACM2_VAM_SHIFTER_VALUE_RESETVAL (0x00000000u)

#define CSL_TAC_CFG_ACM2_VAM_COEFF_SET_ID_MASK (0x07C00000u)
#define CSL_TAC_CFG_ACM2_VAM_COEFF_SET_ID_SHIFT (0x00000016u)
#define CSL_TAC_CFG_ACM2_VAM_COEFF_SET_ID_RESETVAL (0x00000000u)

#define CSL_TAC_CFG_ACM2_VAM_ENABLE_FLAG_MASK (0x00200000u)
#define CSL_TAC_CFG_ACM2_VAM_ENABLE_FLAG_SHIFT (0x00000015u)
#define CSL_TAC_CFG_ACM2_VAM_ENABLE_FLAG_RESETVAL (0x00000000u)
/*----STREAM_STATE Tokens----*/
#define CSL_TAC_CFG_ACM2_VAM_ENABLE_FLAG_DISABLE (0x00000000u)
#define CSL_TAC_CFG_ACM2_VAM_ENABLE_FLAG_ENABLE (0x00000001u)

#define CSL_TAC_CFG_ACM2_EXT_STREAM_ID_MASK (0x001E0000u)
#define CSL_TAC_CFG_ACM2_EXT_STREAM_ID_SHIFT (0x00000011u)
#define CSL_TAC_CFG_ACM2_EXT_STREAM_ID_RESETVAL (0x00000000u)

#define CSL_TAC_CFG_ACM2_EXT_AGGR_FLG_MASK (0x00010000u)
#define CSL_TAC_CFG_ACM2_EXT_AGGR_FLG_SHIFT (0x00000010u)
#define CSL_TAC_CFG_ACM2_EXT_AGGR_FLG_RESETVAL (0x00000000u)
/*----EXT_AGGR_FLG Tokens----*/
#define CSL_TAC_CFG_ACM2_EXT_AGGR_FLG_DISABLE (0x00000000u)
#define CSL_TAC_CFG_ACM2_EXT_AGGR_FLG_ENABLE (0x00000001u)

#define CSL_TAC_CFG_ACM2_STREAM_STATE_MASK (0x00004000u)
#define CSL_TAC_CFG_ACM2_STREAM_STATE_SHIFT (0x0000000Eu)
#define CSL_TAC_CFG_ACM2_STREAM_STATE_RESETVAL (0x00000000u)
/*----STREAM_STATE Tokens----*/
#define CSL_TAC_CFG_ACM2_STREAM_STATE_IDLE (0x00000000u)
#define CSL_TAC_CFG_ACM2_STREAM_STATE_ACTIVE (0x00000001u)

#define CSL_TAC_CFG_ACM2_FRAME_ID_MASK   (0x00003FFCu)
#define CSL_TAC_CFG_ACM2_FRAME_ID_SHIFT  (0x00000002u)
#define CSL_TAC_CFG_ACM2_FRAME_ID_RESETVAL (0x00000000u)

#define CSL_TAC_CFG_ACM2_REQ_TYPE_MASK   (0x00000003u)
#define CSL_TAC_CFG_ACM2_REQ_TYPE_SHIFT  (0x00000000u)
#define CSL_TAC_CFG_ACM2_REQ_TYPE_RESETVAL (0x00000000u)
/*----REQ_TYPE Tokens----*/
#define CSL_TAC_CFG_ACM2_REQ_TYPE_IMMEDIATE_STOP (0x00000000u)
#define CSL_TAC_CFG_ACM2_REQ_TYPE_TIMED_STOP (0x00000001u)
#define CSL_TAC_CFG_ACM2_REQ_TYPE_IMMEDIATE_START (0x00000002u)
#define CSL_TAC_CFG_ACM2_REQ_TYPE_TIMED_START (0x00000003u)

#define CSL_TAC_CFG_ACM2_RESETVAL        (0x00000000u)

/* ACM3 */

#define CSL_TAC_CFG_ACM3_VAM_ENABLE_STATUS_MASK   (0x00010000u)
#define CSL_TAC_CFG_ACM3_VAM_ENABLE_STATUS_SHIFT  (0x00000010u)
#define CSL_TAC_CFG_ACM3_VAM_ENABLE_STATUS_RESETVAL (0x00000000u)

#define CSL_TAC_CFG_ACM3_VCT_UPDATE_REQ_FRAME_ID_MASK   (0x0000FFF0u)
#define CSL_TAC_CFG_ACM3_VCT_UPDATE_REQ_FRAME_ID_SHIFT  (0x00000004u)
#define CSL_TAC_CFG_ACM3_VCT_UPDATE_REQ_FRAME_ID_RESETVAL (0x00000000u)

#define CSL_TAC_CFG_ACM3_VCT_UPDATE_REQ_SLOT_ID_MASK   (0x0000000Fu)
#define CSL_TAC_CFG_ACM3_VCT_UPDATE_REQ_SLOT_ID_SHIFT  (0x00000000u)
#define CSL_TAC_CFG_ACM3_VCT_UPDATE_REQ_SLOT_ID_RESETVAL (0x00000000u)

#define CSL_TAC_CFG_ACM3_RESETVAL        (0x00000000u)

/* VCT0 */

#define CSL_TAC_CFG_VCT0_NEW_C11_I_PART_MASK   (0xFFFF0000u)
#define CSL_TAC_CFG_VCT0_NEW_C11_I_PART_SHIFT  (0x00000010u)
#define CSL_TAC_CFG_VCT0_NEW_C11_I_PART_RESETVAL (0x00000000u)

#define CSL_TAC_CFG_VCT0_NEW_C11_Q_PART_MASK   (0x0000FFFFu)
#define CSL_TAC_CFG_VCT0_NEW_C11_Q_PART_SHIFT  (0x00000000u)
#define CSL_TAC_CFG_VCT0_NEW_C11_Q_PART_RESETVAL (0x00000000u)

#define CSL_TAC_CFG_VCT0_RESETVAL        (0x00000000u)

/* VCT1 */

#define CSL_TAC_CFG_VCT1_NEW_C12_I_PART_MASK   (0xFFFF0000u)
#define CSL_TAC_CFG_VCT1_NEW_C12_I_PART_SHIFT  (0x00000010u)
#define CSL_TAC_CFG_VCT1_NEW_C12_I_PART_RESETVAL (0x00000000u)

#define CSL_TAC_CFG_VCT1_NEW_C12_Q_PART_MASK   (0x0000FFFFu)
#define CSL_TAC_CFG_VCT1_NEW_C12_Q_PART_SHIFT  (0x00000000u)
#define CSL_TAC_CFG_VCT1_NEW_C12_Q_PART_RESETVAL (0x00000000u)

#define CSL_TAC_CFG_VCT1_RESETVAL        (0x00000000u)

/* VCT2 */

#define CSL_TAC_CFG_VCT2_NEW_C21_I_PART_MASK   (0xFFFF0000u)
#define CSL_TAC_CFG_VCT2_NEW_C21_I_PART_SHIFT  (0x00000010u)
#define CSL_TAC_CFG_VCT2_NEW_C21_I_PART_RESETVAL (0x00000000u)

#define CSL_TAC_CFG_VCT2_NEW_C21_Q_PART_MASK   (0x0000FFFFu)
#define CSL_TAC_CFG_VCT2_NEW_C21_Q_PART_SHIFT  (0x00000000u)
#define CSL_TAC_CFG_VCT2_NEW_C21_Q_PART_RESETVAL (0x00000000u)

#define CSL_TAC_CFG_VCT2_RESETVAL        (0x00000000u)

/* VCT3 */

#define CSL_TAC_CFG_VCT3_NEW_C22_I_PART_MASK   (0xFFFF0000u)
#define CSL_TAC_CFG_VCT3_NEW_C22_I_PART_SHIFT  (0x00000010u)
#define CSL_TAC_CFG_VCT3_NEW_C22_I_PART_RESETVAL (0x00000000u)

#define CSL_TAC_CFG_VCT3_NEW_C22_Q_PART_MASK   (0x0000FFFFu)
#define CSL_TAC_CFG_VCT3_NEW_C22_Q_PART_SHIFT  (0x00000000u)
#define CSL_TAC_CFG_VCT3_NEW_C22_Q_PART_RESETVAL (0x00000000u)

#define CSL_TAC_CFG_VCT3_RESETVAL        (0x00000000u)

/* VCT4 */

#define CSL_TAC_CFG_VCT4_CURRENT_C11_I_PART_MASK   (0xFFFF0000u)
#define CSL_TAC_CFG_VCT4_CURRENT_C11_I_PART_SHIFT  (0x00000010u)
#define CSL_TAC_CFG_VCT4_CURRENT_C11_I_PART_RESETVAL (0x00000000u)

#define CSL_TAC_CFG_VCT4_CURRENT_C11_Q_PART_MASK   (0x0000FFFFu)
#define CSL_TAC_CFG_VCT4_CURRENT_C11_Q_PART_SHIFT  (0x00000000u)
#define CSL_TAC_CFG_VCT4_CURRENT_C11_Q_PART_RESETVAL (0x00000000u)

#define CSL_TAC_CFG_VCT4_RESETVAL        (0x00000000u)

/* VCT5 */

#define CSL_TAC_CFG_VCT5_CURRENT_C12_I_PART_MASK   (0xFFFF0000u)
#define CSL_TAC_CFG_VCT5_CURRENT_C12_I_PART_SHIFT  (0x00000010u)
#define CSL_TAC_CFG_VCT5_CURRENT_C12_I_PART_RESETVAL (0x00000000u)

#define CSL_TAC_CFG_VCT5_CURRENT_C12_Q_PART_MASK   (0x0000FFFFu)
#define CSL_TAC_CFG_VCT5_CURRENT_C12_Q_PART_SHIFT  (0x00000000u)
#define CSL_TAC_CFG_VCT5_CURRENT_C12_Q_PART_RESETVAL (0x00000000u)

#define CSL_TAC_CFG_VCT5_RESETVAL        (0x00000000u)

/* VCT6 */

#define CSL_TAC_CFG_VCT6_CURRENT_C21_I_PART_MASK   (0xFFFF0000u)
#define CSL_TAC_CFG_VCT6_CURRENT_C21_I_PART_SHIFT  (0x00000010u)
#define CSL_TAC_CFG_VCT6_CURRENT_C21_I_PART_RESETVAL (0x00000000u)

#define CSL_TAC_CFG_VCT6_CURRENT_C21_Q_PART_MASK   (0x0000FFFFu)
#define CSL_TAC_CFG_VCT6_CURRENT_C21_Q_PART_SHIFT  (0x00000000u)
#define CSL_TAC_CFG_VCT6_CURRENT_C21_Q_PART_RESETVAL (0x00000000u)

#define CSL_TAC_CFG_VCT6_RESETVAL        (0x00000000u)

/* VCT7 */

#define CSL_TAC_CFG_VCT7_CURRENT_C22_I_PART_MASK   (0xFFFF0000u)
#define CSL_TAC_CFG_VCT7_CURRENT_C22_I_PART_SHIFT  (0x00000010u)
#define CSL_TAC_CFG_VCT7_CURRENT_C22_I_PART_RESETVAL (0x00000000u)

#define CSL_TAC_CFG_VCT7_CURRENT_C22_Q_PART_MASK   (0x0000FFFFu)
#define CSL_TAC_CFG_VCT7_CURRENT_C22_Q_PART_SHIFT  (0x00000000u)
#define CSL_TAC_CFG_VCT7_CURRENT_C22_Q_PART_RESETVAL (0x00000000u)

#define CSL_TAC_CFG_VCT7_RESETVAL        (0x00000000u)

/* MST0 */

#define CSL_TAC_CFG_MST0_TOTAL_ACC_NB_MASK (0x0000FFFFu)
#define CSL_TAC_CFG_MST0_TOTAL_ACC_NB_SHIFT (0x00000000u)
#define CSL_TAC_CFG_MST0_TOTAL_ACC_NB_RESETVAL (0x00000000u)

#define CSL_TAC_CFG_MST0_RESETVAL (0x00000000u)

/* MST1 */

#define CSL_TAC_CFG_MST1_WRITE_ACC_NB_MASK (0x0000FFFFu)
#define CSL_TAC_CFG_MST1_WRITE_ACC_NB_SHIFT (0x00000000u)
#define CSL_TAC_CFG_MST1_WRITE_ACC_NB_RESETVAL (0x00000000u)

#define CSL_TAC_CFG_MST1_RESETVAL (0x00000000u)

/* MST2 */

#define CSL_TAC_CFG_MST2_READ_ACC_NB_MASK (0x0000FFFFu)
#define CSL_TAC_CFG_MST2_READ_ACC_NB_SHIFT (0x00000000u)
#define CSL_TAC_CFG_MST2_READ_ACC_NB_RESETVAL (0x00000000u)

#define CSL_TAC_CFG_MST2_RESETVAL (0x00000000u)
/* FE_PID */

#define CSL_TAC_CFG_FE_PID_SCHEME_MASK   (0xC0000000u)
#define CSL_TAC_CFG_FE_PID_SCHEME_SHIFT  (0x0000001Eu)
#define CSL_TAC_CFG_FE_PID_SCHEME_RESETVAL (0x00000001u)


#define CSL_TAC_CFG_FE_PID_PID_MASK      (0x0FFF0000u)
#define CSL_TAC_CFG_FE_PID_PID_SHIFT     (0x00000010u)
#define CSL_TAC_CFG_FE_PID_PID_RESETVAL  (0x00000807u)

#define CSL_TAC_CFG_FE_PID_RTL_REV_NB_MASK (0x0000F800u)
#define CSL_TAC_CFG_FE_PID_RTL_REV_NB_SHIFT (0x0000000Bu)
#define CSL_TAC_CFG_FE_PID_RTL_REV_NB_RESETVAL (0x00000001u)

#define CSL_TAC_CFG_FE_PID_MAJ_REV_NB_MASK (0x00000700u)
#define CSL_TAC_CFG_FE_PID_MAJ_REV_NB_SHIFT (0x00000008u)
#define CSL_TAC_CFG_FE_PID_MAJ_REV_NB_RESETVAL (0x00000002u)

#define CSL_TAC_CFG_FE_PID_CUS_REV_NB_MASK (0x000000C0u)
#define CSL_TAC_CFG_FE_PID_CUS_REV_NB_SHIFT (0x00000006u)
#define CSL_TAC_CFG_FE_PID_CUS_REV_NB_RESETVAL (0x00000000u)

#define CSL_TAC_CFG_FE_PID_MIN_REV_NB_MASK (0x0000003Fu)
#define CSL_TAC_CFG_FE_PID_MIN_REV_NB_SHIFT (0x00000000u)
#define CSL_TAC_CFG_FE_PID_MIN_REV_NB_RESETVAL (0x00000001u)

#define CSL_TAC_CFG_FE_PID_RESETVAL (0x48070A01u)

/* FE_ENA */


#define CSL_TAC_CFG_FE_ENA_ENABLE_MASK   (0x00000001u)
#define CSL_TAC_CFG_FE_ENA_ENABLE_SHIFT  (0x00000000u)
#define CSL_TAC_CFG_FE_ENA_ENABLE_RESETVAL (0x00000000u)
/*----ENABLE Tokens----*/
#define CSL_TAC_CFG_FE_ENA_ENABLE_DISABLE (0x00000000u)
#define CSL_TAC_CFG_FE_ENA_ENABLE_ENABLE (0x00000001u)

#define CSL_TAC_CFG_FE_ENA_RESETVAL      (0x00000000u)

/* FE_STAT */


#define CSL_TAC_CFG_FE_STAT_STATUS_MASK  (0x00000001u)
#define CSL_TAC_CFG_FE_STAT_STATUS_SHIFT (0x00000000u)
#define CSL_TAC_CFG_FE_STAT_STATUS_RESETVAL (0x00000000u)
/*----STATUS Tokens----*/
#define CSL_TAC_CFG_FE_STAT_STATUS_DISABLED (0x00000000u)
#define CSL_TAC_CFG_FE_STAT_STATUS_ENABLED (0x00000001u)

#define CSL_TAC_CFG_FE_STAT_RESETVAL     (0x00000000u)

/* CPM_START_AD */

#define CSL_TAC_CFG_CPM_START_AD_START_AD_MASK (0xFFFFFFFFu)
#define CSL_TAC_CFG_CPM_START_AD_START_AD_SHIFT (0x00000000u)
#define CSL_TAC_CFG_CPM_START_AD_START_AD_RESETVAL (0x00000000u)


#define CSL_TAC_CFG_CPM_START_AD_RESETVAL (0x00000000u)

/* CPM_SIZE */


#define CSL_TAC_CFG_CPM_SIZE_SIZE_MASK   (0x0000FFFFu)
#define CSL_TAC_CFG_CPM_SIZE_SIZE_SHIFT  (0x00000000u)
#define CSL_TAC_CFG_CPM_SIZE_SIZE_RESETVAL (0x00000000u)


#define CSL_TAC_CFG_CPM_SIZE_RESETVAL    (0x00000000u)

/* CPM_WR_PTR */


#define CSL_TAC_CFG_CPM_WR_PTR_WR_PTR_MASK (0x0000FFFFu)
#define CSL_TAC_CFG_CPM_WR_PTR_WR_PTR_SHIFT (0x00000000u)
#define CSL_TAC_CFG_CPM_WR_PTR_WR_PTR_RESETVAL (0x00000000u)

#define CSL_TAC_CFG_CPM_WR_PTR_RESETVAL  (0x00000000u)

/* FE_SW_RESET */


#define CSL_TAC_CFG_FE_SW_RESET_RESET_MASK (0x00000001u)
#define CSL_TAC_CFG_FE_SW_RESET_RESET_SHIFT (0x00000000u)
#define CSL_TAC_CFG_FE_SW_RESET_RESET_RESETVAL (0x00000000u)
/*----RESET Tokens----*/
#define CSL_TAC_CFG_FE_SW_RESET_RESET_NO_RESET (0x00000000u)
#define CSL_TAC_CFG_FE_SW_RESET_RESET_RESET (0x00000001u)

#define CSL_TAC_CFG_FE_SW_RESET_RESETVAL (0x00000000u)

/* FE_HEAD_PRIO */


#define CSL_TAC_CFG_FE_HEAD_PRIO_PRIORITY_MASK (0x00000007u)
#define CSL_TAC_CFG_FE_HEAD_PRIO_PRIORITY_SHIFT (0x00000000u)
#define CSL_TAC_CFG_FE_HEAD_PRIO_PRIORITY_RESETVAL (0x00000007u)

#define CSL_TAC_CFG_FE_HEAD_PRIO_RESETVAL (0x00000007u)

/* FE_DATA_PRIO */


#define CSL_TAC_CFG_FE_DATA_PRIO_PRIORITY_MASK (0x00000007u)
#define CSL_TAC_CFG_FE_DATA_PRIO_PRIORITY_SHIFT (0x00000000u)
#define CSL_TAC_CFG_FE_DATA_PRIO_PRIORITY_RESETVAL (0x00000007u)

#define CSL_TAC_CFG_FE_DATA_PRIO_RESETVAL (0x00000007u)

/* FE_WARN_PRIO */


#define CSL_TAC_CFG_FE_WARN_PRIO_PRIORITY_MASK (0x00000007u)
#define CSL_TAC_CFG_FE_WARN_PRIO_PRIORITY_SHIFT (0x00000000u)
#define CSL_TAC_CFG_FE_WARN_PRIO_PRIORITY_RESETVAL (0x00000007u)

#define CSL_TAC_CFG_FE_WARN_PRIO_RESETVAL (0x00000007u)

/* FE_CPM_PRIO */


#define CSL_TAC_CFG_FE_CPM_PRIO_PRIORITY_MASK (0x00000007u)
#define CSL_TAC_CFG_FE_CPM_PRIO_PRIORITY_SHIFT (0x00000000u)
#define CSL_TAC_CFG_FE_CPM_PRIO_PRIORITY_RESETVAL (0x00000007u)

#define CSL_TAC_CFG_FE_CPM_PRIO_RESETVAL (0x00000007u)

/* FE_TRANS_CFG */


#define CSL_TAC_CFG_FE_TRANS_CFG_INIT_VALUE_MASK (0x00001FFEu)
#define CSL_TAC_CFG_FE_TRANS_CFG_INIT_VALUE_SHIFT (0x00000001u)
#define CSL_TAC_CFG_FE_TRANS_CFG_INIT_VALUE_RESETVAL (0x00000000u)

#define CSL_TAC_CFG_FE_TRANS_CFG_ENABLE_FLAG_MASK (0x00000001u)
#define CSL_TAC_CFG_FE_TRANS_CFG_ENABLE_FLAG_SHIFT (0x00000000u)
#define CSL_TAC_CFG_FE_TRANS_CFG_ENABLE_FLAG_RESETVAL (0x00000000u)
/*----ENABLE_FLAG Tokens----*/
#define CSL_TAC_CFG_FE_TRANS_CFG_ENABLE_FLAG_DISABLE (0x00000000u)
#define CSL_TAC_CFG_FE_TRANS_CFG_ENABLE_FLAG_ENABLE (0x00000001u)

#define CSL_TAC_CFG_FE_TRANS_CFG_RESETVAL (0x00000000u)

/* FE_TRANS_INT */


#define CSL_TAC_CFG_FE_TRANS_INT_MASTER_ID_MASK (0x0000FF00u)
#define CSL_TAC_CFG_FE_TRANS_INT_MASTER_ID_SHIFT (0x00000008u)
#define CSL_TAC_CFG_FE_TRANS_INT_MASTER_ID_RESETVAL (0x00000000u)


#define CSL_TAC_CFG_FE_TRANS_INT_TRANS_KIND_MASK (0x00000020u)
#define CSL_TAC_CFG_FE_TRANS_INT_TRANS_KIND_SHIFT (0x00000005u)
#define CSL_TAC_CFG_FE_TRANS_INT_TRANS_KIND_RESETVAL (0x00000000u)
/*----TRANS_KIND Tokens----*/
#define CSL_TAC_CFG_FE_TRANS_INT_TRANS_KIND_WRITE (0x00000000u)
#define CSL_TAC_CFG_FE_TRANS_INT_TRANS_KIND_READ (0x00000001u)

#define CSL_TAC_CFG_FE_TRANS_INT_TRANS_ID_MASK (0x0000001Eu)
#define CSL_TAC_CFG_FE_TRANS_INT_TRANS_ID_SHIFT (0x00000001u)
#define CSL_TAC_CFG_FE_TRANS_INT_TRANS_ID_RESETVAL (0x00000000u)

#define CSL_TAC_CFG_FE_TRANS_INT_ERROR_FLAG_MASK (0x00000001u)
#define CSL_TAC_CFG_FE_TRANS_INT_ERROR_FLAG_SHIFT (0x00000000u)
#define CSL_TAC_CFG_FE_TRANS_INT_ERROR_FLAG_RESETVAL (0x00000000u)
/*----ERROR_FLAG Tokens----*/
#define CSL_TAC_CFG_FE_TRANS_INT_ERROR_FLAG_NO_ERROR (0x00000000u)
#define CSL_TAC_CFG_FE_TRANS_INT_ERROR_FLAG_ERROR (0x00000001u)

#define CSL_TAC_CFG_FE_TRANS_INT_RESETVAL (0x00000000u)

/* FE_WR_TRANS_STAT */


#define CSL_TAC_CFG_FE_WR_TRANS_STAT_TRANS_KIND_MASK (0x00000010u)
#define CSL_TAC_CFG_FE_WR_TRANS_STAT_TRANS_KIND_SHIFT (0x00000004u)
#define CSL_TAC_CFG_FE_WR_TRANS_STAT_TRANS_KIND_RESETVAL (0x00000000u)
/*----TRANS_KIND Tokens----*/
#define CSL_TAC_CFG_FE_WR_TRANS_STAT_TRANS_KIND_CPM (0x00000000u)
#define CSL_TAC_CFG_FE_WR_TRANS_STAT_TRANS_KIND_WARNING (0x00000001u)


#define CSL_TAC_CFG_FE_WR_TRANS_STAT_SGCP_ID_MASK (0x0000000Eu)
#define CSL_TAC_CFG_FE_WR_TRANS_STAT_SGCP_ID_SHIFT (0x00000001u)
#define CSL_TAC_CFG_FE_WR_TRANS_STAT_SGCP_ID_RESETVAL (0x00000000u)

#define CSL_TAC_CFG_FE_WR_TRANS_STAT_TRANS_STAT_MASK (0x00000001u)
#define CSL_TAC_CFG_FE_WR_TRANS_STAT_TRANS_STAT_SHIFT (0x00000000u)
#define CSL_TAC_CFG_FE_WR_TRANS_STAT_TRANS_STAT_RESETVAL (0x00000000u)
/*----TRANS_STAT Tokens----*/
#define CSL_TAC_CFG_FE_WR_TRANS_STAT_TRANS_STAT_IDLE (0x00000000u)
#define CSL_TAC_CFG_FE_WR_TRANS_STAT_TRANS_STAT_PENDING (0x00000001u)

#define CSL_TAC_CFG_FE_WR_TRANS_STAT_RESETVAL (0x00000000u)

/* BETI_CTRL */


#define CSL_TAC_CFG_BETI_CTRL_ENABLE_MASK (0x00000001u)
#define CSL_TAC_CFG_BETI_CTRL_ENABLE_SHIFT (0x00000000u)
#define CSL_TAC_CFG_BETI_CTRL_ENABLE_RESETVAL (0x00000000u)
/*----ENABLE Tokens----*/
#define CSL_TAC_CFG_BETI_CTRL_ENABLE_DISABLE (0x00000000u)
#define CSL_TAC_CFG_BETI_CTRL_ENABLE_ENABLE (0x00000001u)

#define CSL_TAC_CFG_BETI_CTRL_RESETVAL   (0x00000000u)

/* BETI_STAT */

#define CSL_TAC_CFG_BETI_STAT_SGCP5_STATUS_MASK (0x00000020u)
#define CSL_TAC_CFG_BETI_STAT_SGCP5_STATUS_SHIFT (0x00000005u)
#define CSL_TAC_CFG_BETI_STAT_SGCP5_STATUS_RESETVAL (0x00000000u)
/*----SGCP5_STATUS Tokens----*/
#define CSL_TAC_CFG_BETI_STAT_SGCP5_STATUS_IDLE (0x00000000u)
#define CSL_TAC_CFG_BETI_STAT_SGCP5_STATUS_BUSY (0x00000001u)

#define CSL_TAC_CFG_BETI_STAT_SGCP4_STATUS_MASK (0x00000010u)
#define CSL_TAC_CFG_BETI_STAT_SGCP4_STATUS_SHIFT (0x00000004u)
#define CSL_TAC_CFG_BETI_STAT_SGCP4_STATUS_RESETVAL (0x00000000u)
/*----SGCP4_STATUS Tokens----*/
#define CSL_TAC_CFG_BETI_STAT_SGCP4_STATUS_IDLE (0x00000000u)
#define CSL_TAC_CFG_BETI_STAT_SGCP4_STATUS_BUSY (0x00000001u)

#define CSL_TAC_CFG_BETI_STAT_SGCP3_STATUS_MASK (0x00000008u)
#define CSL_TAC_CFG_BETI_STAT_SGCP3_STATUS_SHIFT (0x00000003u)
#define CSL_TAC_CFG_BETI_STAT_SGCP3_STATUS_RESETVAL (0x00000000u)
/*----SGCP3_STATUS Tokens----*/
#define CSL_TAC_CFG_BETI_STAT_SGCP3_STATUS_IDLE (0x00000000u)
#define CSL_TAC_CFG_BETI_STAT_SGCP3_STATUS_BUSY (0x00000001u)

#define CSL_TAC_CFG_BETI_STAT_SGCP2_STATUS_MASK (0x00000004u)
#define CSL_TAC_CFG_BETI_STAT_SGCP2_STATUS_SHIFT (0x00000002u)
#define CSL_TAC_CFG_BETI_STAT_SGCP2_STATUS_RESETVAL (0x00000000u)
/*----SGCP2_STATUS Tokens----*/
#define CSL_TAC_CFG_BETI_STAT_SGCP2_STATUS_IDLE (0x00000000u)
#define CSL_TAC_CFG_BETI_STAT_SGCP2_STATUS_BUSY (0x00000001u)

#define CSL_TAC_CFG_BETI_STAT_SGCP1_STATUS_MASK (0x00000002u)
#define CSL_TAC_CFG_BETI_STAT_SGCP1_STATUS_SHIFT (0x00000001u)
#define CSL_TAC_CFG_BETI_STAT_SGCP1_STATUS_RESETVAL (0x00000000u)
/*----SGCP1_STATUS Tokens----*/
#define CSL_TAC_CFG_BETI_STAT_SGCP1_STATUS_IDLE (0x00000000u)
#define CSL_TAC_CFG_BETI_STAT_SGCP1_STATUS_BUSY (0x00000001u)

#define CSL_TAC_CFG_BETI_STAT_SGCP0_STATUS_MASK (0x00000001u)
#define CSL_TAC_CFG_BETI_STAT_SGCP0_STATUS_SHIFT (0x00000000u)
#define CSL_TAC_CFG_BETI_STAT_SGCP0_STATUS_RESETVAL (0x00000000u)
/*----SGCP0_STATUS Tokens----*/
#define CSL_TAC_CFG_BETI_STAT_SGCP0_STATUS_IDLE (0x00000000u)
#define CSL_TAC_CFG_BETI_STAT_SGCP0_STATUS_BUSY (0x00000001u)

#define CSL_TAC_CFG_BETI_STAT_RESETVAL   (0x00000000u)

/* BETI_WCFG */


#define CSL_TAC_CFG_BETI_WCFG_BE_WD_CFG_MASK (0x0000FFFFu)
#define CSL_TAC_CFG_BETI_WCFG_BE_WD_CFG_SHIFT (0x00000000u)
#define CSL_TAC_CFG_BETI_WCFG_BE_WD_CFG_RESETVAL (0x00000000u)

#define CSL_TAC_CFG_BETI_WCFG_RESETVAL   (0x00000000u)

/* BETI_WST */


#define CSL_TAC_CFG_BETI_WST_BE_WD_STAT_MASK (0x0000FFFFu)
#define CSL_TAC_CFG_BETI_WST_BE_WD_STAT_SHIFT (0x00000000u)
#define CSL_TAC_CFG_BETI_WST_BE_WD_STAT_RESETVAL (0x00000000u)

#define CSL_TAC_CFG_BETI_WST_RESETVAL    (0x00000000u)

/* BETI_WINT */


#define CSL_TAC_CFG_BETI_WINT_INT_STAT_MASK (0x00000001u)
#define CSL_TAC_CFG_BETI_WINT_INT_STAT_SHIFT (0x00000000u)
#define CSL_TAC_CFG_BETI_WINT_INT_STAT_RESETVAL (0x00000000u)
/*----INT_STAT Tokens----*/
#define CSL_TAC_CFG_BETI_WINT_INT_STAT_NO_INT (0x00000000u)
#define CSL_TAC_CFG_BETI_WINT_INT_STAT_INT_GENERATED (0x00000001u)

#define CSL_TAC_CFG_BETI_WINT_RESETVAL   (0x00000000u)

/* BETI_DEF_ANT */

#define CSL_TAC_CFG_BETI_DEF_ANT_I_PART_MASK (0xFFFF0000u)
#define CSL_TAC_CFG_BETI_DEF_ANT_I_PART_SHIFT (0x00000010u)
#define CSL_TAC_CFG_BETI_DEF_ANT_I_PART_RESETVAL (0x00000000u)

#define CSL_TAC_CFG_BETI_DEF_ANT_Q_PART_MASK (0x0000FFFFu)
#define CSL_TAC_CFG_BETI_DEF_ANT_Q_PART_SHIFT (0x00000000u)
#define CSL_TAC_CFG_BETI_DEF_ANT_Q_PART_RESETVAL (0x00000000u)

#define CSL_TAC_CFG_BETI_DEF_ANT_RESETVAL (0x00000000u)

/* BETI_SPC */


#define CSL_TAC_CFG_BETI_SPC_IQ_SWAP_MASK (0x00010000u)
#define CSL_TAC_CFG_BETI_SPC_IQ_SWAP_SHIFT (0x00000010u)
#define CSL_TAC_CFG_BETI_SPC_IQ_SWAP_RESETVAL (0x00000000u)
/*----IQ_SWAP Tokens----*/
#define CSL_TAC_CFG_BETI_SPC_IQ_SWAP_NO_SWAP (0x00000000u)
#define CSL_TAC_CFG_BETI_SPC_IQ_SWAP_SWAPPING (0x00000001u)


#define CSL_TAC_CFG_BETI_SPC_ACC_MODE_MASK (0x00000001u)
#define CSL_TAC_CFG_BETI_SPC_ACC_MODE_SHIFT (0x00000000u)
#define CSL_TAC_CFG_BETI_SPC_ACC_MODE_RESETVAL (0x00000000u)
/*----ACC_MODE Tokens----*/
#define CSL_TAC_CFG_BETI_SPC_ACC_MODE_SLOT_MODE (0x00000000u)
#define CSL_TAC_CFG_BETI_SPC_ACC_MODE_SYMBOL_MODE (0x00000001u)

#define CSL_TAC_CFG_BETI_SPC_RESETVAL    (0x00000000u)

/* BETI_SW_ITE_START */

#define CSL_TAC_CFG_BETI_SW_ITE_START_ITE_START_MASK (0x00000001u)
#define CSL_TAC_CFG_BETI_SW_ITE_START_ITE_START_SHIFT (0x00000000u)
#define CSL_TAC_CFG_BETI_SW_ITE_START_ITE_START_RESETVAL (0x00000000u)
/*----ITE_START Tokens----*/
#define CSL_TAC_CFG_BETI_SW_ITE_START_ITE_START_NO_TRIGGER (0x00000000u)
#define CSL_TAC_CFG_BETI_SW_ITE_START_ITE_START_TRIGGER (0x00000001u)

#define CSL_TAC_CFG_BETI_SW_ITE_START_RESETVAL (0x00000000u)

/* BEII_CTRL */

#define CSL_TAC_CFG_BEII_CTRL_ENABLE_MASK (0x00000001u)
#define CSL_TAC_CFG_BEII_CTRL_ENABLE_SHIFT (0x00000000u)
#define CSL_TAC_CFG_BEII_CTRL_ENABLE_RESETVAL (0x00000000u)
/*----ENABLE Tokens----*/
#define CSL_TAC_CFG_BEII_CTRL_ENABLE_DISABLE (0x00000000u)
#define CSL_TAC_CFG_BEII_CTRL_ENABLE_ENABLE (0x00000001u)

#define CSL_TAC_CFG_BEII_CTRL_RESETVAL   (0x00000000u)

/* BEII_IRS0 */

#define CSL_TAC_CFG_BEII_IRS0_SGCP5_IB_WR_MISS_STAT_MASK (0x00800000u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP5_IB_WR_MISS_STAT_SHIFT (0x00000017u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP5_IB_WR_MISS_STAT_RESETVAL (0x00000000u)
/*----SGCP5_IB_WR_MISS_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IRS0_SGCP5_IB_WR_MISS_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP5_IB_WR_MISS_STAT_ACTIVE (0x00000001u)

#define CSL_TAC_CFG_BEII_IRS0_SGCP5_SEQ_STAT_MASK (0x00400000u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP5_SEQ_STAT_SHIFT (0x00000016u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP5_SEQ_STAT_RESETVAL (0x00000000u)
/*----SGCP5_SEQ_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IRS0_SGCP5_SEQ_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP5_SEQ_STAT_ACTIVE (0x00000001u)

#define CSL_TAC_CFG_BEII_IRS0_SGCP5_FIFO_OVER_STAT_MASK (0x00200000u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP5_FIFO_OVER_STAT_SHIFT (0x00000015u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP5_FIFO_OVER_STAT_RESETVAL (0x00000000u)
/*----SGCP5_FIFO_OVER_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IRS0_SGCP5_FIFO_OVER_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP5_FIFO_OVER_STAT_ACTIVE (0x00000001u)

#define CSL_TAC_CFG_BEII_IRS0_SGCP5_CYC_OVER_STAT_MASK (0x00100000u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP5_CYC_OVER_STAT_SHIFT (0x00000014u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP5_CYC_OVER_STAT_RESETVAL (0x00000000u)
/*----SGCP5_CYC_OVER_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IRS0_SGCP5_CYC_OVER_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP5_CYC_OVER_STAT_ACTIVE (0x00000001u)


#define CSL_TAC_CFG_BEII_IRS0_SGCP4_IB_WR_MISS_STAT_MASK (0x00080000u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP4_IB_WR_MISS_STAT_SHIFT (0x00000013u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP4_IB_WR_MISS_STAT_RESETVAL (0x00000000u)
/*----SGCP4_IB_WR_MISS_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IRS0_SGCP4_IB_WR_MISS_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP4_IB_WR_MISS_STAT_ACTIVE (0x00000001u)

#define CSL_TAC_CFG_BEII_IRS0_SGCP4_SEQ_STAT_MASK (0x00040000u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP4_SEQ_STAT_SHIFT (0x00000012u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP4_SEQ_STAT_RESETVAL (0x00000000u)
/*----SGCP4_SEQ_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IRS0_SGCP4_SEQ_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP4_SEQ_STAT_ACTIVE (0x00000001u)

#define CSL_TAC_CFG_BEII_IRS0_SGCP4_FIFO_OVER_STAT_MASK (0x00020000u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP4_FIFO_OVER_STAT_SHIFT (0x00000011u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP4_FIFO_OVER_STAT_RESETVAL (0x00000000u)
/*----SGCP4_FIFO_OVER_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IRS0_SGCP4_FIFO_OVER_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP4_FIFO_OVER_STAT_ACTIVE (0x00000001u)

#define CSL_TAC_CFG_BEII_IRS0_SGCP4_CYC_OVER_STAT_MASK (0x00010000u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP4_CYC_OVER_STAT_SHIFT (0x00000010u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP4_CYC_OVER_STAT_RESETVAL (0x00000000u)
/*----SGCP4_CYC_OVER_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IRS0_SGCP4_CYC_OVER_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP4_CYC_OVER_STAT_ACTIVE (0x00000001u)



#define CSL_TAC_CFG_BEII_IRS0_SGCP3_IB_WR_MISS_STAT_MASK (0x00008000u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP3_IB_WR_MISS_STAT_SHIFT (0x0000000Fu)
#define CSL_TAC_CFG_BEII_IRS0_SGCP3_IB_WR_MISS_STAT_RESETVAL (0x00000000u)
/*----SGCP3_IB_WR_MISS_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IRS0_SGCP3_IB_WR_MISS_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP3_IB_WR_MISS_STAT_ACTIVE (0x00000001u)

#define CSL_TAC_CFG_BEII_IRS0_SGCP3_SEQ_STAT_MASK (0x00004000u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP3_SEQ_STAT_SHIFT (0x0000000Eu)
#define CSL_TAC_CFG_BEII_IRS0_SGCP3_SEQ_STAT_RESETVAL (0x00000000u)
/*----SGCP3_SEQ_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IRS0_SGCP3_SEQ_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP3_SEQ_STAT_ACTIVE (0x00000001u)

#define CSL_TAC_CFG_BEII_IRS0_SGCP3_FIFO_OVER_STAT_MASK (0x00002000u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP3_FIFO_OVER_STAT_SHIFT (0x0000000Du)
#define CSL_TAC_CFG_BEII_IRS0_SGCP3_FIFO_OVER_STAT_RESETVAL (0x00000000u)
/*----SGCP3_FIFO_OVER_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IRS0_SGCP3_FIFO_OVER_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP3_FIFO_OVER_STAT_ACTIVE (0x00000001u)

#define CSL_TAC_CFG_BEII_IRS0_SGCP3_CYC_OVER_STAT_MASK (0x00001000u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP3_CYC_OVER_STAT_SHIFT (0x0000000Cu)
#define CSL_TAC_CFG_BEII_IRS0_SGCP3_CYC_OVER_STAT_RESETVAL (0x00000000u)
/*----SGCP3_CYC_OVER_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IRS0_SGCP3_CYC_OVER_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP3_CYC_OVER_STAT_ACTIVE (0x00000001u)


#define CSL_TAC_CFG_BEII_IRS0_SGCP2_IB_WR_MISS_STAT_MASK (0x00000800u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP2_IB_WR_MISS_STAT_SHIFT (0x0000000Bu)
#define CSL_TAC_CFG_BEII_IRS0_SGCP2_IB_WR_MISS_STAT_RESETVAL (0x00000000u)
/*----SGCP2_IB_WR_MISS_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IRS0_SGCP2_IB_WR_MISS_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP2_IB_WR_MISS_STAT_ACTIVE (0x00000001u)

#define CSL_TAC_CFG_BEII_IRS0_SGCP2_SEQ_STAT_MASK (0x00000400u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP2_SEQ_STAT_SHIFT (0x0000000Au)
#define CSL_TAC_CFG_BEII_IRS0_SGCP2_SEQ_STAT_RESETVAL (0x00000000u)
/*----SGCP2_SEQ_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IRS0_SGCP2_SEQ_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP2_SEQ_STAT_ACTIVE (0x00000001u)

#define CSL_TAC_CFG_BEII_IRS0_SGCP2_FIFO_OVER_STAT_MASK (0x00000200u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP2_FIFO_OVER_STAT_SHIFT (0x00000009u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP2_FIFO_OVER_STAT_RESETVAL (0x00000000u)
/*----SGCP2_FIFO_OVER_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IRS0_SGCP2_FIFO_OVER_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP2_FIFO_OVER_STAT_ACTIVE (0x00000001u)

#define CSL_TAC_CFG_BEII_IRS0_SGCP2_CYC_OVER_STAT_MASK (0x00000100u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP2_CYC_OVER_STAT_SHIFT (0x00000008u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP2_CYC_OVER_STAT_RESETVAL (0x00000000u)
/*----SGCP2_CYC_OVER_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IRS0_SGCP2_CYC_OVER_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP2_CYC_OVER_STAT_ACTIVE (0x00000001u)



#define CSL_TAC_CFG_BEII_IRS0_SGCP1_IB_WR_MISS_STAT_MASK (0x00000080u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP1_IB_WR_MISS_STAT_SHIFT (0x00000007u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP1_IB_WR_MISS_STAT_RESETVAL (0x00000000u)
/*----SGCP1_IB_WR_MISS_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IRS0_SGCP1_IB_WR_MISS_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP1_IB_WR_MISS_STAT_ACTIVE (0x00000001u)

#define CSL_TAC_CFG_BEII_IRS0_SGCP1_SEQ_STAT_MASK (0x00000040u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP1_SEQ_STAT_SHIFT (0x00000006u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP1_SEQ_STAT_RESETVAL (0x00000000u)
/*----SGCP1_SEQ_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IRS0_SGCP1_SEQ_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP1_SEQ_STAT_ACTIVE (0x00000001u)

#define CSL_TAC_CFG_BEII_IRS0_SGCP1_FIFO_OVER_STAT_MASK (0x00000020u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP1_FIFO_OVER_STAT_SHIFT (0x00000005u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP1_FIFO_OVER_STAT_RESETVAL (0x00000000u)
/*----SGCP1_FIFO_OVER_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IRS0_SGCP1_FIFO_OVER_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP1_FIFO_OVER_STAT_ACTIVE (0x00000001u)

#define CSL_TAC_CFG_BEII_IRS0_SGCP1_CYC_OVER_STAT_MASK (0x00000010u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP1_CYC_OVER_STAT_SHIFT (0x00000004u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP1_CYC_OVER_STAT_RESETVAL (0x00000000u)
/*----SGCP1_CYC_OVER_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IRS0_SGCP1_CYC_OVER_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP1_CYC_OVER_STAT_ACTIVE (0x00000001u)


#define CSL_TAC_CFG_BEII_IRS0_SGCP0_IB_WR_MISS_STAT_MASK (0x00000008u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP0_IB_WR_MISS_STAT_SHIFT (0x00000003u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP0_IB_WR_MISS_STAT_RESETVAL (0x00000000u)
/*----SGCP0_IB_WR_MISS_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IRS0_SGCP0_IB_WR_MISS_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP0_IB_WR_MISS_STAT_ACTIVE (0x00000001u)

#define CSL_TAC_CFG_BEII_IRS0_SGCP0_SEQ_STAT_MASK (0x00000004u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP0_SEQ_STAT_SHIFT (0x00000002u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP0_SEQ_STAT_RESETVAL (0x00000000u)
/*----SGCP0_SEQ_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IRS0_SGCP0_SEQ_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP0_SEQ_STAT_ACTIVE (0x00000001u)

#define CSL_TAC_CFG_BEII_IRS0_SGCP0_FIFO_OVER_STAT_MASK (0x00000002u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP0_FIFO_OVER_STAT_SHIFT (0x00000001u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP0_FIFO_OVER_STAT_RESETVAL (0x00000000u)
/*----SGCP0_FIFO_OVER_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IRS0_SGCP0_FIFO_OVER_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP0_FIFO_OVER_STAT_ACTIVE (0x00000001u)

#define CSL_TAC_CFG_BEII_IRS0_SGCP0_CYC_OVER_STAT_MASK (0x00000001u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP0_CYC_OVER_STAT_SHIFT (0x00000000u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP0_CYC_OVER_STAT_RESETVAL (0x00000000u)
/*----SGCP0_CYC_OVER_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IRS0_SGCP0_CYC_OVER_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IRS0_SGCP0_CYC_OVER_STAT_ACTIVE (0x00000001u)

#define CSL_TAC_CFG_BEII_IRS0_RESETVAL    (0x00000000u)

/* BEII_IRS1 */


#define CSL_TAC_CFG_BEII_IRS1_BE_WD_STAT_MASK (0x00000010u)
#define CSL_TAC_CFG_BEII_IRS1_BE_WD_STAT_SHIFT (0x00000004u)
#define CSL_TAC_CFG_BEII_IRS1_BE_WD_STAT_RESETVAL (0x00000000u)
/*----BE_WD_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IRS1_BE_WD_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IRS1_BE_WD_STAT_ACTIVE (0x00000001u)

#define CSL_TAC_CFG_BEII_IRS1_FE2_TRANS_STAT_MASK (0x00000004u)
#define CSL_TAC_CFG_BEII_IRS1_FE2_TRANS_STAT_SHIFT (0x00000002u)
#define CSL_TAC_CFG_BEII_IRS1_FE2_TRANS_STAT_RESETVAL (0x00000000u)
/*----FE2_TRANS_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IRS1_FE2_TRANS_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IRS1_FE2_TRANS_STAT_ACTIVE (0x00000001u)

#define CSL_TAC_CFG_BEII_IRS1_FE1_TRANS_STAT_MASK (0x00000002u)
#define CSL_TAC_CFG_BEII_IRS1_FE1_TRANS_STAT_SHIFT (0x00000001u)
#define CSL_TAC_CFG_BEII_IRS1_FE1_TRANS_STAT_RESETVAL (0x00000000u)
/*----FE1_TRANS_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IRS1_FE1_TRANS_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IRS1_FE1_TRANS_STAT_ACTIVE (0x00000001u)

#define CSL_TAC_CFG_BEII_IRS1_FE0_TRANS_STAT_MASK (0x00000001u)
#define CSL_TAC_CFG_BEII_IRS1_FE0_TRANS_STAT_SHIFT (0x00000000u)
#define CSL_TAC_CFG_BEII_IRS1_FE0_TRANS_STAT_RESETVAL (0x00000000u)
/*----FE0_TRANS_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IRS1_FE0_TRANS_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IRS1_FE0_TRANS_STAT_ACTIVE (0x00000001u)

#define CSL_TAC_CFG_BEII_IRS1_RESETVAL    (0x00000000u)

/* BEII_ICS0 */

#define CSL_TAC_CFG_BEII_ICS0_SGCP5_IB_WR_MISS_CLR_MASK (0x00800000u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP5_IB_WR_MISS_CLR_SHIFT (0x00000017u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP5_IB_WR_MISS_CLR_RESETVAL (0x00000000u)
/*----SGCP5_IB_WR_MISS_CLR Tokens----*/
#define CSL_TAC_CFG_BEII_ICS0_SGCP5_IB_WR_MISS_CLR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP5_IB_WR_MISS_CLR_CLEAR (0x00000001u)

#define CSL_TAC_CFG_BEII_ICS0_SGCP5_SEQ_CLR_MASK (0x00400000u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP5_SEQ_CLR_SHIFT (0x00000016u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP5_SEQ_CLR_RESETVAL (0x00000000u)
/*----SGCP5_SEQ_CLR Tokens----*/
#define CSL_TAC_CFG_BEII_ICS0_SGCP5_SEQ_CLR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP5_SEQ_CLR_CLEAR (0x00000001u)

#define CSL_TAC_CFG_BEII_ICS0_SGCP5_FIFO_OVER_CLR_MASK (0x00200000u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP5_FIFO_OVER_CLR_SHIFT (0x00000015u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP5_FIFO_OVER_CLR_RESETVAL (0x00000000u)
/*----SGCP5_FIFO_OVER_CLR Tokens----*/
#define CSL_TAC_CFG_BEII_ICS0_SGCP5_FIFO_OVER_CLR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP5_FIFO_OVER_CLR_CLEAR (0x00000001u)

#define CSL_TAC_CFG_BEII_ICS0_SGCP5_CYC_OVER_CLR_MASK (0x00100000u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP5_CYC_OVER_CLR_SHIFT (0x00000014u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP5_CYC_OVER_CLR_RESETVAL (0x00000000u)
/*----SGCP5_CYC_OVER_CLR Tokens----*/
#define CSL_TAC_CFG_BEII_ICS0_SGCP5_CYC_OVER_CLR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP5_CYC_OVER_CLR_CLEAR (0x00000001u)


#define CSL_TAC_CFG_BEII_ICS0_SGCP4_IB_WR_MISS_CLR_MASK (0x00080000u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP4_IB_WR_MISS_CLR_SHIFT (0x00000013u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP4_IB_WR_MISS_CLR_RESETVAL (0x00000000u)
/*----SGCP4_IB_WR_MISS_CLR Tokens----*/
#define CSL_TAC_CFG_BEII_ICS0_SGCP4_IB_WR_MISS_CLR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP4_IB_WR_MISS_CLR_CLEAR (0x00000001u)

#define CSL_TAC_CFG_BEII_ICS0_SGCP4_SEQ_CLR_MASK (0x00040000u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP4_SEQ_CLR_SHIFT (0x00000012u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP4_SEQ_CLR_RESETVAL (0x00000000u)
/*----SGCP4_SEQ_CLR Tokens----*/
#define CSL_TAC_CFG_BEII_ICS0_SGCP4_SEQ_CLR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP4_SEQ_CLR_CLEAR (0x00000001u)

#define CSL_TAC_CFG_BEII_ICS0_SGCP4_FIFO_OVER_CLR_MASK (0x00020000u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP4_FIFO_OVER_CLR_SHIFT (0x00000011u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP4_FIFO_OVER_CLR_RESETVAL (0x00000000u)
/*----SGCP4_FIFO_OVER_CLR Tokens----*/
#define CSL_TAC_CFG_BEII_ICS0_SGCP4_FIFO_OVER_CLR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP4_FIFO_OVER_CLR_CLEAR (0x00000001u)

#define CSL_TAC_CFG_BEII_ICS0_SGCP4_CYC_OVER_CLR_MASK (0x00010000u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP4_CYC_OVER_CLR_SHIFT (0x00000010u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP4_CYC_OVER_CLR_RESETVAL (0x00000000u)
/*----SGCP4_CYC_OVER_CLR Tokens----*/
#define CSL_TAC_CFG_BEII_ICS0_SGCP4_CYC_OVER_CLR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP4_CYC_OVER_CLR_CLEAR (0x00000001u)


#define CSL_TAC_CFG_BEII_ICS0_SGCP3_IB_WR_MISS_CLR_MASK (0x00008000u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP3_IB_WR_MISS_CLR_SHIFT (0x0000000Fu)
#define CSL_TAC_CFG_BEII_ICS0_SGCP3_IB_WR_MISS_CLR_RESETVAL (0x00000000u)
/*----SGCP3_IB_WR_MISS_CLR Tokens----*/
#define CSL_TAC_CFG_BEII_ICS0_SGCP3_IB_WR_MISS_CLR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP3_IB_WR_MISS_CLR_CLEAR (0x00000001u)

#define CSL_TAC_CFG_BEII_ICS0_SGCP3_SEQ_CLR_MASK (0x00004000u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP3_SEQ_CLR_SHIFT (0x0000000Eu)
#define CSL_TAC_CFG_BEII_ICS0_SGCP3_SEQ_CLR_RESETVAL (0x00000000u)
/*----SGCP3_SEQ_CLR Tokens----*/
#define CSL_TAC_CFG_BEII_ICS0_SGCP3_SEQ_CLR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP3_SEQ_CLR_CLEAR (0x00000001u)

#define CSL_TAC_CFG_BEII_ICS0_SGCP3_FIFO_OVER_CLR_MASK (0x00002000u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP3_FIFO_OVER_CLR_SHIFT (0x0000000Du)
#define CSL_TAC_CFG_BEII_ICS0_SGCP3_FIFO_OVER_CLR_RESETVAL (0x00000000u)
/*----SGCP3_FIFO_OVER_CLR Tokens----*/
#define CSL_TAC_CFG_BEII_ICS0_SGCP3_FIFO_OVER_CLR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP3_FIFO_OVER_CLR_CLEAR (0x00000001u)

#define CSL_TAC_CFG_BEII_ICS0_SGCP3_CYC_OVER_CLR_MASK (0x00001000u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP3_CYC_OVER_CLR_SHIFT (0x0000000Cu)
#define CSL_TAC_CFG_BEII_ICS0_SGCP3_CYC_OVER_CLR_RESETVAL (0x00000000u)
/*----SGCP3_CYC_OVER_CLR Tokens----*/
#define CSL_TAC_CFG_BEII_ICS0_SGCP3_CYC_OVER_CLR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP3_CYC_OVER_CLR_CLEAR (0x00000001u)


#define CSL_TAC_CFG_BEII_ICS0_SGCP2_IB_WR_MISS_CLR_MASK (0x00000800u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP2_IB_WR_MISS_CLR_SHIFT (0x0000000Bu)
#define CSL_TAC_CFG_BEII_ICS0_SGCP2_IB_WR_MISS_CLR_RESETVAL (0x00000000u)
/*----SGCP2_IB_WR_MISS_CLR Tokens----*/
#define CSL_TAC_CFG_BEII_ICS0_SGCP2_IB_WR_MISS_CLR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP2_IB_WR_MISS_CLR_CLEAR (0x00000001u)

#define CSL_TAC_CFG_BEII_ICS0_SGCP2_SEQ_CLR_MASK (0x00000400u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP2_SEQ_CLR_SHIFT (0x0000000Au)
#define CSL_TAC_CFG_BEII_ICS0_SGCP2_SEQ_CLR_RESETVAL (0x00000000u)
/*----SGCP2_SEQ_CLR Tokens----*/
#define CSL_TAC_CFG_BEII_ICS0_SGCP2_SEQ_CLR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP2_SEQ_CLR_CLEAR (0x00000001u)

#define CSL_TAC_CFG_BEII_ICS0_SGCP2_FIFO_OVER_CLR_MASK (0x00000200u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP2_FIFO_OVER_CLR_SHIFT (0x00000009u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP2_FIFO_OVER_CLR_RESETVAL (0x00000000u)
/*----SGCP2_FIFO_OVER_CLR Tokens----*/
#define CSL_TAC_CFG_BEII_ICS0_SGCP2_FIFO_OVER_CLR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP2_FIFO_OVER_CLR_CLEAR (0x00000001u)

#define CSL_TAC_CFG_BEII_ICS0_SGCP2_CYC_OVER_CLR_MASK (0x00000100u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP2_CYC_OVER_CLR_SHIFT (0x00000008u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP2_CYC_OVER_CLR_RESETVAL (0x00000000u)
/*----SGCP2_CYC_OVER_CLR Tokens----*/
#define CSL_TAC_CFG_BEII_ICS0_SGCP2_CYC_OVER_CLR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP2_CYC_OVER_CLR_CLEAR (0x00000001u)


#define CSL_TAC_CFG_BEII_ICS0_SGCP1_IB_WR_MISS_CLR_MASK (0x00000080u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP1_IB_WR_MISS_CLR_SHIFT (0x00000007u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP1_IB_WR_MISS_CLR_RESETVAL (0x00000000u)
/*----SGCP1_IB_WR_MISS_CLR Tokens----*/
#define CSL_TAC_CFG_BEII_ICS0_SGCP1_IB_WR_MISS_CLR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP1_IB_WR_MISS_CLR_CLEAR (0x00000001u)

#define CSL_TAC_CFG_BEII_ICS0_SGCP1_SEQ_CLR_MASK (0x00000040u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP1_SEQ_CLR_SHIFT (0x00000006u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP1_SEQ_CLR_RESETVAL (0x00000000u)
/*----SGCP1_SEQ_CLR Tokens----*/
#define CSL_TAC_CFG_BEII_ICS0_SGCP1_SEQ_CLR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP1_SEQ_CLR_CLEAR (0x00000001u)

#define CSL_TAC_CFG_BEII_ICS0_SGCP1_FIFO_OVER_CLR_MASK (0x00000020u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP1_FIFO_OVER_CLR_SHIFT (0x00000005u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP1_FIFO_OVER_CLR_RESETVAL (0x00000000u)
/*----SGCP1_FIFO_OVER_CLR Tokens----*/
#define CSL_TAC_CFG_BEII_ICS0_SGCP1_FIFO_OVER_CLR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP1_FIFO_OVER_CLR_CLEAR (0x00000001u)

#define CSL_TAC_CFG_BEII_ICS0_SGCP1_CYC_OVER_CLR_MASK (0x00000010u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP1_CYC_OVER_CLR_SHIFT (0x00000004u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP1_CYC_OVER_CLR_RESETVAL (0x00000000u)
/*----SGCP1_CYC_OVER_CLR Tokens----*/
#define CSL_TAC_CFG_BEII_ICS0_SGCP1_CYC_OVER_CLR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP1_CYC_OVER_CLR_CLEAR (0x00000001u)


#define CSL_TAC_CFG_BEII_ICS0_SGCP0_IB_WR_MISS_CLR_MASK (0x00000008u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP0_IB_WR_MISS_CLR_SHIFT (0x00000003u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP0_IB_WR_MISS_CLR_RESETVAL (0x00000000u)
/*----SGCP0_IB_WR_MISS_CLR Tokens----*/
#define CSL_TAC_CFG_BEII_ICS0_SGCP0_IB_WR_MISS_CLR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP0_IB_WR_MISS_CLR_CLEAR (0x00000001u)

#define CSL_TAC_CFG_BEII_ICS0_SGCP0_SEQ_CLR_MASK (0x00000004u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP0_SEQ_CLR_SHIFT (0x00000002u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP0_SEQ_CLR_RESETVAL (0x00000000u)
/*----SGCP0_SEQ_CLR Tokens----*/
#define CSL_TAC_CFG_BEII_ICS0_SGCP0_SEQ_CLR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP0_SEQ_CLR_CLEAR (0x00000001u)

#define CSL_TAC_CFG_BEII_ICS0_SGCP0_FIFO_OVER_CLR_MASK (0x00000002u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP0_FIFO_OVER_CLR_SHIFT (0x00000001u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP0_FIFO_OVER_CLR_RESETVAL (0x00000000u)
/*----SGCP0_FIFO_OVER_CLR Tokens----*/
#define CSL_TAC_CFG_BEII_ICS0_SGCP0_FIFO_OVER_CLR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP0_FIFO_OVER_CLR_CLEAR (0x00000001u)

#define CSL_TAC_CFG_BEII_ICS0_SGCP0_CYC_OVER_CLR_MASK (0x00000001u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP0_CYC_OVER_CLR_SHIFT (0x00000000u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP0_CYC_OVER_CLR_RESETVAL (0x00000000u)
/*----SGCP0_CYC_OVER_CLR Tokens----*/
#define CSL_TAC_CFG_BEII_ICS0_SGCP0_CYC_OVER_CLR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_ICS0_SGCP0_CYC_OVER_CLR_CLEAR (0x00000001u)

#define CSL_TAC_CFG_BEII_ICS0_RESETVAL    (0x00000000u)

/* BEII_ICS1 */

#define CSL_TAC_CFG_BEII_ICS1_BE_WD_CLR_MASK (0x00000010u)
#define CSL_TAC_CFG_BEII_ICS1_BE_WD_CLR_SHIFT (0x00000004u)
#define CSL_TAC_CFG_BEII_ICS1_BE_WD_CLR_RESETVAL (0x00000000u)
/*----BE_WD_CLR Tokens----*/
#define CSL_TAC_CFG_BEII_ICS1_BE_WD_CLR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_ICS1_BE_WD_CLR_CLEAR (0x00000001u)

#define CSL_TAC_CFG_BEII_ICS1_FE2_TRANS_CLR_MASK (0x00000004u)
#define CSL_TAC_CFG_BEII_ICS1_FE2_TRANS_CLR_SHIFT (0x00000002u)
#define CSL_TAC_CFG_BEII_ICS1_FE2_TRANS_CLR_RESETVAL (0x00000000u)
/*----FE2_TRANS_CLR Tokens----*/
#define CSL_TAC_CFG_BEII_ICS1_FE2_TRANS_CLR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_ICS1_FE2_TRANS_CLR_CLEAR (0x00000001u)

#define CSL_TAC_CFG_BEII_ICS1_FE1_TRANS_CLR_MASK (0x00000002u)
#define CSL_TAC_CFG_BEII_ICS1_FE1_TRANS_CLR_SHIFT (0x00000001u)
#define CSL_TAC_CFG_BEII_ICS1_FE1_TRANS_CLR_RESETVAL (0x00000000u)
/*----FE1_TRANS_CLR Tokens----*/
#define CSL_TAC_CFG_BEII_ICS1_FE1_TRANS_CLR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_ICS1_FE1_TRANS_CLR_CLEAR (0x00000001u)

#define CSL_TAC_CFG_BEII_ICS1_FE0_TRANS_CLR_MASK (0x00000001u)
#define CSL_TAC_CFG_BEII_ICS1_FE0_TRANS_CLR_SHIFT (0x00000000u)
#define CSL_TAC_CFG_BEII_ICS1_FE0_TRANS_CLR_RESETVAL (0x00000000u)
/*----FE0_TRANS_CLR Tokens----*/
#define CSL_TAC_CFG_BEII_ICS1_FE0_TRANS_CLR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_ICS1_FE0_TRANS_CLR_CLEAR (0x00000001u)

#define CSL_TAC_CFG_BEII_ICS1_RESETVAL    (0x00000000u)

/* BEII_IES0 */

#define CSL_TAC_CFG_BEII_IES0_SGCP5_IB_WR_MISS_STAT_MASK (0x00800000u)
#define CSL_TAC_CFG_BEII_IES0_SGCP5_IB_WR_MISS_STAT_SHIFT (0x00000017u)
#define CSL_TAC_CFG_BEII_IES0_SGCP5_IB_WR_MISS_STAT_RESETVAL (0x00000000u)
/*----SGCP5_IB_WR_MISS_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IES0_SGCP5_IB_WR_MISS_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IES0_SGCP5_IB_WR_MISS_STAT_ACTIVE (0x00000001u)

#define CSL_TAC_CFG_BEII_IES0_SGCP5_SEQ_STAT_MASK (0x00400000u)
#define CSL_TAC_CFG_BEII_IES0_SGCP5_SEQ_STAT_SHIFT (0x00000016u)
#define CSL_TAC_CFG_BEII_IES0_SGCP5_SEQ_STAT_RESETVAL (0x00000000u)
/*----SGCP5_SEQ_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IES0_SGCP5_SEQ_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IES0_SGCP5_SEQ_STAT_ACTIVE (0x00000001u)

#define CSL_TAC_CFG_BEII_IES0_SGCP5_FIFO_OVER_STAT_MASK (0x00200000u)
#define CSL_TAC_CFG_BEII_IES0_SGCP5_FIFO_OVER_STAT_SHIFT (0x00000015u)
#define CSL_TAC_CFG_BEII_IES0_SGCP5_FIFO_OVER_STAT_RESETVAL (0x00000000u)
/*----SGCP5_FIFO_OVER_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IES0_SGCP5_FIFO_OVER_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IES0_SGCP5_FIFO_OVER_STAT_ACTIVE (0x00000001u)

#define CSL_TAC_CFG_BEII_IES0_SGCP5_CYC_OVER_STAT_MASK (0x00100000u)
#define CSL_TAC_CFG_BEII_IES0_SGCP5_CYC_OVER_STAT_SHIFT (0x00000014u)
#define CSL_TAC_CFG_BEII_IES0_SGCP5_CYC_OVER_STAT_RESETVAL (0x00000000u)
/*----SGCP5_CYC_OVER_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IES0_SGCP5_CYC_OVER_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IES0_SGCP5_CYC_OVER_STAT_ACTIVE (0x00000001u)


#define CSL_TAC_CFG_BEII_IES0_SGCP4_IB_WR_MISS_STAT_MASK (0x00080000u)
#define CSL_TAC_CFG_BEII_IES0_SGCP4_IB_WR_MISS_STAT_SHIFT (0x00000013u)
#define CSL_TAC_CFG_BEII_IES0_SGCP4_IB_WR_MISS_STAT_RESETVAL (0x00000000u)
/*----SGCP4_IB_WR_MISS_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IES0_SGCP4_IB_WR_MISS_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IES0_SGCP4_IB_WR_MISS_STAT_ACTIVE (0x00000001u)

#define CSL_TAC_CFG_BEII_IES0_SGCP4_SEQ_STAT_MASK (0x00040000u)
#define CSL_TAC_CFG_BEII_IES0_SGCP4_SEQ_STAT_SHIFT (0x00000012u)
#define CSL_TAC_CFG_BEII_IES0_SGCP4_SEQ_STAT_RESETVAL (0x00000000u)
/*----SGCP4_SEQ_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IES0_SGCP4_SEQ_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IES0_SGCP4_SEQ_STAT_ACTIVE (0x00000001u)

#define CSL_TAC_CFG_BEII_IES0_SGCP4_FIFO_OVER_STAT_MASK (0x00020000u)
#define CSL_TAC_CFG_BEII_IES0_SGCP4_FIFO_OVER_STAT_SHIFT (0x00000011u)
#define CSL_TAC_CFG_BEII_IES0_SGCP4_FIFO_OVER_STAT_RESETVAL (0x00000000u)
/*----SGCP4_FIFO_OVER_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IES0_SGCP4_FIFO_OVER_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IES0_SGCP4_FIFO_OVER_STAT_ACTIVE (0x00000001u)

#define CSL_TAC_CFG_BEII_IES0_SGCP4_CYC_OVER_STAT_MASK (0x00010000u)
#define CSL_TAC_CFG_BEII_IES0_SGCP4_CYC_OVER_STAT_SHIFT (0x00000010u)
#define CSL_TAC_CFG_BEII_IES0_SGCP4_CYC_OVER_STAT_RESETVAL (0x00000000u)
/*----SGCP4_CYC_OVER_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IES0_SGCP4_CYC_OVER_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IES0_SGCP4_CYC_OVER_STAT_ACTIVE (0x00000001u)


#define CSL_TAC_CFG_BEII_IES0_SGCP3_IB_WR_MISS_STAT_MASK (0x00008000u)
#define CSL_TAC_CFG_BEII_IES0_SGCP3_IB_WR_MISS_STAT_SHIFT (0x0000000Fu)
#define CSL_TAC_CFG_BEII_IES0_SGCP3_IB_WR_MISS_STAT_RESETVAL (0x00000000u)
/*----SGCP3_IB_WR_MISS_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IES0_SGCP3_IB_WR_MISS_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IES0_SGCP3_IB_WR_MISS_STAT_ACTIVE (0x00000001u)

#define CSL_TAC_CFG_BEII_IES0_SGCP3_SEQ_STAT_MASK (0x00004000u)
#define CSL_TAC_CFG_BEII_IES0_SGCP3_SEQ_STAT_SHIFT (0x0000000Eu)
#define CSL_TAC_CFG_BEII_IES0_SGCP3_SEQ_STAT_RESETVAL (0x00000000u)
/*----SGCP3_SEQ_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IES0_SGCP3_SEQ_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IES0_SGCP3_SEQ_STAT_ACTIVE (0x00000001u)

#define CSL_TAC_CFG_BEII_IES0_SGCP3_FIFO_OVER_STAT_MASK (0x00002000u)
#define CSL_TAC_CFG_BEII_IES0_SGCP3_FIFO_OVER_STAT_SHIFT (0x0000000Du)
#define CSL_TAC_CFG_BEII_IES0_SGCP3_FIFO_OVER_STAT_RESETVAL (0x00000000u)
/*----SGCP3_FIFO_OVER_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IES0_SGCP3_FIFO_OVER_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IES0_SGCP3_FIFO_OVER_STAT_ACTIVE (0x00000001u)

#define CSL_TAC_CFG_BEII_IES0_SGCP3_CYC_OVER_STAT_MASK (0x00001000u)
#define CSL_TAC_CFG_BEII_IES0_SGCP3_CYC_OVER_STAT_SHIFT (0x0000000Cu)
#define CSL_TAC_CFG_BEII_IES0_SGCP3_CYC_OVER_STAT_RESETVAL (0x00000000u)
/*----SGCP3_CYC_OVER_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IES0_SGCP3_CYC_OVER_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IES0_SGCP3_CYC_OVER_STAT_ACTIVE (0x00000001u)


#define CSL_TAC_CFG_BEII_IES0_SGCP2_IB_WR_MISS_STAT_MASK (0x00000800u)
#define CSL_TAC_CFG_BEII_IES0_SGCP2_IB_WR_MISS_STAT_SHIFT (0x0000000Bu)
#define CSL_TAC_CFG_BEII_IES0_SGCP2_IB_WR_MISS_STAT_RESETVAL (0x00000000u)
/*----SGCP2_IB_WR_MISS_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IES0_SGCP2_IB_WR_MISS_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IES0_SGCP2_IB_WR_MISS_STAT_ACTIVE (0x00000001u)

#define CSL_TAC_CFG_BEII_IES0_SGCP2_SEQ_STAT_MASK (0x00000400u)
#define CSL_TAC_CFG_BEII_IES0_SGCP2_SEQ_STAT_SHIFT (0x0000000Au)
#define CSL_TAC_CFG_BEII_IES0_SGCP2_SEQ_STAT_RESETVAL (0x00000000u)
/*----SGCP2_SEQ_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IES0_SGCP2_SEQ_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IES0_SGCP2_SEQ_STAT_ACTIVE (0x00000001u)

#define CSL_TAC_CFG_BEII_IES0_SGCP2_FIFO_OVER_STAT_MASK (0x00000200u)
#define CSL_TAC_CFG_BEII_IES0_SGCP2_FIFO_OVER_STAT_SHIFT (0x00000009u)
#define CSL_TAC_CFG_BEII_IES0_SGCP2_FIFO_OVER_STAT_RESETVAL (0x00000000u)
/*----SGCP2_FIFO_OVER_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IES0_SGCP2_FIFO_OVER_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IES0_SGCP2_FIFO_OVER_STAT_ACTIVE (0x00000001u)

#define CSL_TAC_CFG_BEII_IES0_SGCP2_CYC_OVER_STAT_MASK (0x00000100u)
#define CSL_TAC_CFG_BEII_IES0_SGCP2_CYC_OVER_STAT_SHIFT (0x00000008u)
#define CSL_TAC_CFG_BEII_IES0_SGCP2_CYC_OVER_STAT_RESETVAL (0x00000000u)
/*----SGCP2_CYC_OVER_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IES0_SGCP2_CYC_OVER_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IES0_SGCP2_CYC_OVER_STAT_ACTIVE (0x00000001u)


#define CSL_TAC_CFG_BEII_IES0_SGCP1_IB_WR_MISS_STAT_MASK (0x00000080u)
#define CSL_TAC_CFG_BEII_IES0_SGCP1_IB_WR_MISS_STAT_SHIFT (0x00000007u)
#define CSL_TAC_CFG_BEII_IES0_SGCP1_IB_WR_MISS_STAT_RESETVAL (0x00000000u)
/*----SGCP1_IB_WR_MISS_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IES0_SGCP1_IB_WR_MISS_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IES0_SGCP1_IB_WR_MISS_STAT_ACTIVE (0x00000001u)

#define CSL_TAC_CFG_BEII_IES0_SGCP1_SEQ_STAT_MASK (0x00000040u)
#define CSL_TAC_CFG_BEII_IES0_SGCP1_SEQ_STAT_SHIFT (0x00000006u)
#define CSL_TAC_CFG_BEII_IES0_SGCP1_SEQ_STAT_RESETVAL (0x00000000u)
/*----SGCP1_SEQ_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IES0_SGCP1_SEQ_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IES0_SGCP1_SEQ_STAT_ACTIVE (0x00000001u)

#define CSL_TAC_CFG_BEII_IES0_SGCP1_FIFO_OVER_STAT_MASK (0x00000020u)
#define CSL_TAC_CFG_BEII_IES0_SGCP1_FIFO_OVER_STAT_SHIFT (0x00000005u)
#define CSL_TAC_CFG_BEII_IES0_SGCP1_FIFO_OVER_STAT_RESETVAL (0x00000000u)
/*----SGCP1_FIFO_OVER_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IES0_SGCP1_FIFO_OVER_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IES0_SGCP1_FIFO_OVER_STAT_ACTIVE (0x00000001u)

#define CSL_TAC_CFG_BEII_IES0_SGCP1_CYC_OVER_STAT_MASK (0x00000010u)
#define CSL_TAC_CFG_BEII_IES0_SGCP1_CYC_OVER_STAT_SHIFT (0x00000004u)
#define CSL_TAC_CFG_BEII_IES0_SGCP1_CYC_OVER_STAT_RESETVAL (0x00000000u)
/*----SGCP1_CYC_OVER_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IES0_SGCP1_CYC_OVER_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IES0_SGCP1_CYC_OVER_STAT_ACTIVE (0x00000001u)


#define CSL_TAC_CFG_BEII_IES0_SGCP0_IB_WR_MISS_STAT_MASK (0x00000008u)
#define CSL_TAC_CFG_BEII_IES0_SGCP0_IB_WR_MISS_STAT_SHIFT (0x00000003u)
#define CSL_TAC_CFG_BEII_IES0_SGCP0_IB_WR_MISS_STAT_RESETVAL (0x00000000u)
/*----SGCP0_IB_WR_MISS_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IES0_SGCP0_IB_WR_MISS_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IES0_SGCP0_IB_WR_MISS_STAT_ACTIVE (0x00000001u)

#define CSL_TAC_CFG_BEII_IES0_SGCP0_SEQ_STAT_MASK (0x00000004u)
#define CSL_TAC_CFG_BEII_IES0_SGCP0_SEQ_STAT_SHIFT (0x00000002u)
#define CSL_TAC_CFG_BEII_IES0_SGCP0_SEQ_STAT_RESETVAL (0x00000000u)
/*----SGCP0_SEQ_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IES0_SGCP0_SEQ_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IES0_SGCP0_SEQ_STAT_ACTIVE (0x00000001u)

#define CSL_TAC_CFG_BEII_IES0_SGCP0_FIFO_OVER_STAT_MASK (0x00000002u)
#define CSL_TAC_CFG_BEII_IES0_SGCP0_FIFO_OVER_STAT_SHIFT (0x00000001u)
#define CSL_TAC_CFG_BEII_IES0_SGCP0_FIFO_OVER_STAT_RESETVAL (0x00000000u)
/*----SGCP0_FIFO_OVER_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IES0_SGCP0_FIFO_OVER_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IES0_SGCP0_FIFO_OVER_STAT_ACTIVE (0x00000001u)

#define CSL_TAC_CFG_BEII_IES0_SGCP0_CYC_OVER_STAT_MASK (0x00000001u)
#define CSL_TAC_CFG_BEII_IES0_SGCP0_CYC_OVER_STAT_SHIFT (0x00000000u)
#define CSL_TAC_CFG_BEII_IES0_SGCP0_CYC_OVER_STAT_RESETVAL (0x00000000u)
/*----SGCP0_CYC_OVER_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IES0_SGCP0_CYC_OVER_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IES0_SGCP0_CYC_OVER_STAT_ACTIVE (0x00000001u)

#define CSL_TAC_CFG_BEII_IES0_RESETVAL    (0x00000000u)

/* BEII_IES1 */


#define CSL_TAC_CFG_BEII_IES1_BE_WD_STAT_MASK (0x00000010u)
#define CSL_TAC_CFG_BEII_IES1_BE_WD_STAT_SHIFT (0x00000004u)
#define CSL_TAC_CFG_BEII_IES1_BE_WD_STAT_RESETVAL (0x00000000u)
/*----BE_WD_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IES1_BE_WD_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IES1_BE_WD_STAT_ACTIVE (0x00000001u)

#define CSL_TAC_CFG_BEII_IES1_FE2_TRANS_STAT_MASK (0x00000004u)
#define CSL_TAC_CFG_BEII_IES1_FE2_TRANS_STAT_SHIFT (0x00000002u)
#define CSL_TAC_CFG_BEII_IES1_FE2_TRANS_STAT_RESETVAL (0x00000000u)
/*----FE2_TRANS_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IES1_FE2_TRANS_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IES1_FE2_TRANS_STAT_ACTIVE (0x00000001u)

#define CSL_TAC_CFG_BEII_IES1_FE1_TRANS_STAT_MASK (0x00000002u)
#define CSL_TAC_CFG_BEII_IES1_FE1_TRANS_STAT_SHIFT (0x00000001u)
#define CSL_TAC_CFG_BEII_IES1_FE1_TRANS_STAT_RESETVAL (0x00000000u)
/*----FE1_TRANS_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IES1_FE1_TRANS_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IES1_FE1_TRANS_STAT_ACTIVE (0x00000001u)

#define CSL_TAC_CFG_BEII_IES1_FE0_TRANS_STAT_MASK (0x00000001u)
#define CSL_TAC_CFG_BEII_IES1_FE0_TRANS_STAT_SHIFT (0x00000000u)
#define CSL_TAC_CFG_BEII_IES1_FE0_TRANS_STAT_RESETVAL (0x00000000u)
/*----FE0_TRANS_STAT Tokens----*/
#define CSL_TAC_CFG_BEII_IES1_FE0_TRANS_STAT_INACTIVE (0x00000000u)
#define CSL_TAC_CFG_BEII_IES1_FE0_TRANS_STAT_ACTIVE (0x00000001u)

#define CSL_TAC_CFG_BEII_IES1_RESETVAL    (0x00000000u)

/* BEII_IE0 */

#define CSL_TAC_CFG_BEII_IE0_SGCP5_IB_WR_MISS_ENA_MASK (0x00800000u)
#define CSL_TAC_CFG_BEII_IE0_SGCP5_IB_WR_MISS_ENA_SHIFT (0x00000017u)
#define CSL_TAC_CFG_BEII_IE0_SGCP5_IB_WR_MISS_ENA_RESETVAL (0x00000000u)
/*----SGCP5_IB_WR_MISS_ENA Tokens----*/
#define CSL_TAC_CFG_BEII_IE0_SGCP5_IB_WR_MISS_ENA_DISABLE (0x00000000u)
#define CSL_TAC_CFG_BEII_IE0_SGCP5_IB_WR_MISS_ENA_ENABLE (0x00000001u)

#define CSL_TAC_CFG_BEII_IE0_SGCP5_SEQ_ENA_MASK (0x00400000u)
#define CSL_TAC_CFG_BEII_IE0_SGCP5_SEQ_ENA_SHIFT (0x00000016u)
#define CSL_TAC_CFG_BEII_IE0_SGCP5_SEQ_ENA_RESETVAL (0x00000000u)
/*----SGCP5_SEQ_ENA Tokens----*/
#define CSL_TAC_CFG_BEII_IE0_SGCP5_SEQ_ENA_DISABLE (0x00000000u)
#define CSL_TAC_CFG_BEII_IE0_SGCP5_SEQ_ENA_ENABLE (0x00000001u)

#define CSL_TAC_CFG_BEII_IE0_SGCP5_FIFO_OVER_ENA_MASK (0x00200000u)
#define CSL_TAC_CFG_BEII_IE0_SGCP5_FIFO_OVER_ENA_SHIFT (0x00000015u)
#define CSL_TAC_CFG_BEII_IE0_SGCP5_FIFO_OVER_ENA_RESETVAL (0x00000000u)
/*----SGCP5_FIFO_OVER_ENA Tokens----*/
#define CSL_TAC_CFG_BEII_IE0_SGCP5_FIFO_OVER_ENA_DISABLE (0x00000000u)
#define CSL_TAC_CFG_BEII_IE0_SGCP5_FIFO_OVER_ENA_ENABLE (0x00000001u)

#define CSL_TAC_CFG_BEII_IE0_SGCP5_CYC_OVER_ENA_MASK (0x00100000u)
#define CSL_TAC_CFG_BEII_IE0_SGCP5_CYC_OVER_ENA_SHIFT (0x00000014u)
#define CSL_TAC_CFG_BEII_IE0_SGCP5_CYC_OVER_ENA_RESETVAL (0x00000000u)
/*----SGCP5_CYC_OVER_ENA Tokens----*/
#define CSL_TAC_CFG_BEII_IE0_SGCP5_CYC_OVER_ENA_DISABLE (0x00000000u)
#define CSL_TAC_CFG_BEII_IE0_SGCP5_CYC_OVER_ENA_ENABLE (0x00000001u)


#define CSL_TAC_CFG_BEII_IE0_SGCP4_IB_WR_MISS_ENA_MASK (0x00080000u)
#define CSL_TAC_CFG_BEII_IE0_SGCP4_IB_WR_MISS_ENA_SHIFT (0x00000013u)
#define CSL_TAC_CFG_BEII_IE0_SGCP4_IB_WR_MISS_ENA_RESETVAL (0x00000000u)
/*----SGCP4_IB_WR_MISS_ENA Tokens----*/
#define CSL_TAC_CFG_BEII_IE0_SGCP4_IB_WR_MISS_ENA_DISABLE (0x00000000u)
#define CSL_TAC_CFG_BEII_IE0_SGCP4_IB_WR_MISS_ENA_ENABLE (0x00000001u)

#define CSL_TAC_CFG_BEII_IE0_SGCP4_SEQ_ENA_MASK (0x00040000u)
#define CSL_TAC_CFG_BEII_IE0_SGCP4_SEQ_ENA_SHIFT (0x00000012u)
#define CSL_TAC_CFG_BEII_IE0_SGCP4_SEQ_ENA_RESETVAL (0x00000000u)
/*----SGCP4_SEQ_ENA Tokens----*/
#define CSL_TAC_CFG_BEII_IE0_SGCP4_SEQ_ENA_DISABLE (0x00000000u)
#define CSL_TAC_CFG_BEII_IE0_SGCP4_SEQ_ENA_ENABLE (0x00000001u)

#define CSL_TAC_CFG_BEII_IE0_SGCP4_FIFO_OVER_ENA_MASK (0x00020000u)
#define CSL_TAC_CFG_BEII_IE0_SGCP4_FIFO_OVER_ENA_SHIFT (0x00000011u)
#define CSL_TAC_CFG_BEII_IE0_SGCP4_FIFO_OVER_ENA_RESETVAL (0x00000000u)
/*----SGCP4_FIFO_OVER_ENA Tokens----*/
#define CSL_TAC_CFG_BEII_IE0_SGCP4_FIFO_OVER_ENA_DISABLE (0x00000000u)
#define CSL_TAC_CFG_BEII_IE0_SGCP4_FIFO_OVER_ENA_ENABLE (0x00000001u)

#define CSL_TAC_CFG_BEII_IE0_SGCP4_CYC_OVER_ENA_MASK (0x00010000u)
#define CSL_TAC_CFG_BEII_IE0_SGCP4_CYC_OVER_ENA_SHIFT (0x00000010u)
#define CSL_TAC_CFG_BEII_IE0_SGCP4_CYC_OVER_ENA_RESETVAL (0x00000000u)
/*----SGCP4_CYC_OVER_ENA Tokens----*/
#define CSL_TAC_CFG_BEII_IE0_SGCP4_CYC_OVER_ENA_DISABLE (0x00000000u)
#define CSL_TAC_CFG_BEII_IE0_SGCP4_CYC_OVER_ENA_ENABLE (0x00000001u)


#define CSL_TAC_CFG_BEII_IE0_SGCP3_IB_WR_MISS_ENA_MASK (0x00008000u)
#define CSL_TAC_CFG_BEII_IE0_SGCP3_IB_WR_MISS_ENA_SHIFT (0x0000000Fu)
#define CSL_TAC_CFG_BEII_IE0_SGCP3_IB_WR_MISS_ENA_RESETVAL (0x00000000u)
/*----SGCP3_IB_WR_MISS_ENA Tokens----*/
#define CSL_TAC_CFG_BEII_IE0_SGCP3_IB_WR_MISS_ENA_DISABLE (0x00000000u)
#define CSL_TAC_CFG_BEII_IE0_SGCP3_IB_WR_MISS_ENA_ENABLE (0x00000001u)

#define CSL_TAC_CFG_BEII_IE0_SGCP3_SEQ_ENA_MASK (0x00004000u)
#define CSL_TAC_CFG_BEII_IE0_SGCP3_SEQ_ENA_SHIFT (0x0000000Eu)
#define CSL_TAC_CFG_BEII_IE0_SGCP3_SEQ_ENA_RESETVAL (0x00000000u)
/*----SGCP3_SEQ_ENA Tokens----*/
#define CSL_TAC_CFG_BEII_IE0_SGCP3_SEQ_ENA_DISABLE (0x00000000u)
#define CSL_TAC_CFG_BEII_IE0_SGCP3_SEQ_ENA_ENABLE (0x00000001u)

#define CSL_TAC_CFG_BEII_IE0_SGCP3_FIFO_OVER_ENA_MASK (0x00002000u)
#define CSL_TAC_CFG_BEII_IE0_SGCP3_FIFO_OVER_ENA_SHIFT (0x0000000Du)
#define CSL_TAC_CFG_BEII_IE0_SGCP3_FIFO_OVER_ENA_RESETVAL (0x00000000u)
/*----SGCP3_FIFO_OVER_ENA Tokens----*/
#define CSL_TAC_CFG_BEII_IE0_SGCP3_FIFO_OVER_ENA_DISABLE (0x00000000u)
#define CSL_TAC_CFG_BEII_IE0_SGCP3_FIFO_OVER_ENA_ENABLE (0x00000001u)

#define CSL_TAC_CFG_BEII_IE0_SGCP3_CYC_OVER_ENA_MASK (0x00001000u)
#define CSL_TAC_CFG_BEII_IE0_SGCP3_CYC_OVER_ENA_SHIFT (0x0000000Cu)
#define CSL_TAC_CFG_BEII_IE0_SGCP3_CYC_OVER_ENA_RESETVAL (0x00000000u)
/*----SGCP3_CYC_OVER_ENA Tokens----*/
#define CSL_TAC_CFG_BEII_IE0_SGCP3_CYC_OVER_ENA_DISABLE (0x00000000u)
#define CSL_TAC_CFG_BEII_IE0_SGCP3_CYC_OVER_ENA_ENABLE (0x00000001u)


#define CSL_TAC_CFG_BEII_IE0_SGCP2_IB_WR_MISS_ENA_MASK (0x00000800u)
#define CSL_TAC_CFG_BEII_IE0_SGCP2_IB_WR_MISS_ENA_SHIFT (0x0000000Bu)
#define CSL_TAC_CFG_BEII_IE0_SGCP2_IB_WR_MISS_ENA_RESETVAL (0x00000000u)
/*----SGCP2_IB_WR_MISS_ENA Tokens----*/
#define CSL_TAC_CFG_BEII_IE0_SGCP2_IB_WR_MISS_ENA_DISABLE (0x00000000u)
#define CSL_TAC_CFG_BEII_IE0_SGCP2_IB_WR_MISS_ENA_ENABLE (0x00000001u)

#define CSL_TAC_CFG_BEII_IE0_SGCP2_SEQ_ENA_MASK (0x00000400u)
#define CSL_TAC_CFG_BEII_IE0_SGCP2_SEQ_ENA_SHIFT (0x0000000Au)
#define CSL_TAC_CFG_BEII_IE0_SGCP2_SEQ_ENA_RESETVAL (0x00000000u)
/*----SGCP2_SEQ_ENA Tokens----*/
#define CSL_TAC_CFG_BEII_IE0_SGCP2_SEQ_ENA_DISABLE (0x00000000u)
#define CSL_TAC_CFG_BEII_IE0_SGCP2_SEQ_ENA_ENABLE (0x00000001u)

#define CSL_TAC_CFG_BEII_IE0_SGCP2_FIFO_OVER_ENA_MASK (0x00000200u)
#define CSL_TAC_CFG_BEII_IE0_SGCP2_FIFO_OVER_ENA_SHIFT (0x00000009u)
#define CSL_TAC_CFG_BEII_IE0_SGCP2_FIFO_OVER_ENA_RESETVAL (0x00000000u)
/*----SGCP2_FIFO_OVER_ENA Tokens----*/
#define CSL_TAC_CFG_BEII_IE0_SGCP2_FIFO_OVER_ENA_DISABLE (0x00000000u)
#define CSL_TAC_CFG_BEII_IE0_SGCP2_FIFO_OVER_ENA_ENABLE (0x00000001u)

#define CSL_TAC_CFG_BEII_IE0_SGCP2_CYC_OVER_ENA_MASK (0x00000100u)
#define CSL_TAC_CFG_BEII_IE0_SGCP2_CYC_OVER_ENA_SHIFT (0x00000008u)
#define CSL_TAC_CFG_BEII_IE0_SGCP2_CYC_OVER_ENA_RESETVAL (0x00000000u)
/*----SGCP2_CYC_OVER_ENA Tokens----*/
#define CSL_TAC_CFG_BEII_IE0_SGCP2_CYC_OVER_ENA_DISABLE (0x00000000u)
#define CSL_TAC_CFG_BEII_IE0_SGCP2_CYC_OVER_ENA_ENABLE (0x00000001u)


#define CSL_TAC_CFG_BEII_IE0_SGCP1_IB_WR_MISS_ENA_MASK (0x00000080u)
#define CSL_TAC_CFG_BEII_IE0_SGCP1_IB_WR_MISS_ENA_SHIFT (0x00000007u)
#define CSL_TAC_CFG_BEII_IE0_SGCP1_IB_WR_MISS_ENA_RESETVAL (0x00000000u)
/*----SGCP1_IB_WR_MISS_ENA Tokens----*/
#define CSL_TAC_CFG_BEII_IE0_SGCP1_IB_WR_MISS_ENA_DISABLE (0x00000000u)
#define CSL_TAC_CFG_BEII_IE0_SGCP1_IB_WR_MISS_ENA_ENABLE (0x00000001u)

#define CSL_TAC_CFG_BEII_IE0_SGCP1_SEQ_ENA_MASK (0x00000040u)
#define CSL_TAC_CFG_BEII_IE0_SGCP1_SEQ_ENA_SHIFT (0x00000006u)
#define CSL_TAC_CFG_BEII_IE0_SGCP1_SEQ_ENA_RESETVAL (0x00000000u)
/*----SGCP1_SEQ_ENA Tokens----*/
#define CSL_TAC_CFG_BEII_IE0_SGCP1_SEQ_ENA_DISABLE (0x00000000u)
#define CSL_TAC_CFG_BEII_IE0_SGCP1_SEQ_ENA_ENABLE (0x00000001u)

#define CSL_TAC_CFG_BEII_IE0_SGCP1_FIFO_OVER_ENA_MASK (0x00000020u)
#define CSL_TAC_CFG_BEII_IE0_SGCP1_FIFO_OVER_ENA_SHIFT (0x00000005u)
#define CSL_TAC_CFG_BEII_IE0_SGCP1_FIFO_OVER_ENA_RESETVAL (0x00000000u)
/*----SGCP1_FIFO_OVER_ENA Tokens----*/
#define CSL_TAC_CFG_BEII_IE0_SGCP1_FIFO_OVER_ENA_DISABLE (0x00000000u)
#define CSL_TAC_CFG_BEII_IE0_SGCP1_FIFO_OVER_ENA_ENABLE (0x00000001u)

#define CSL_TAC_CFG_BEII_IE0_SGCP1_CYC_OVER_ENA_MASK (0x00000010u)
#define CSL_TAC_CFG_BEII_IE0_SGCP1_CYC_OVER_ENA_SHIFT (0x00000004u)
#define CSL_TAC_CFG_BEII_IE0_SGCP1_CYC_OVER_ENA_RESETVAL (0x00000000u)
/*----SGCP1_CYC_OVER_ENA Tokens----*/
#define CSL_TAC_CFG_BEII_IE0_SGCP1_CYC_OVER_ENA_DISABLE (0x00000000u)
#define CSL_TAC_CFG_BEII_IE0_SGCP1_CYC_OVER_ENA_ENABLE (0x00000001u)


#define CSL_TAC_CFG_BEII_IE0_SGCP0_IB_WR_MISS_ENA_MASK (0x00000008u)
#define CSL_TAC_CFG_BEII_IE0_SGCP0_IB_WR_MISS_ENA_SHIFT (0x00000003u)
#define CSL_TAC_CFG_BEII_IE0_SGCP0_IB_WR_MISS_ENA_RESETVAL (0x00000000u)
/*----SGCP0_IB_WR_MISS_ENA Tokens----*/
#define CSL_TAC_CFG_BEII_IE0_SGCP0_IB_WR_MISS_ENA_DISABLE (0x00000000u)
#define CSL_TAC_CFG_BEII_IE0_SGCP0_IB_WR_MISS_ENA_ENABLE (0x00000001u)

#define CSL_TAC_CFG_BEII_IE0_SGCP0_SEQ_ENA_MASK (0x00000004u)
#define CSL_TAC_CFG_BEII_IE0_SGCP0_SEQ_ENA_SHIFT (0x00000002u)
#define CSL_TAC_CFG_BEII_IE0_SGCP0_SEQ_ENA_RESETVAL (0x00000000u)
/*----SGCP0_SEQ_ENA Tokens----*/
#define CSL_TAC_CFG_BEII_IE0_SGCP0_SEQ_ENA_DISABLE (0x00000000u)
#define CSL_TAC_CFG_BEII_IE0_SGCP0_SEQ_ENA_ENABLE (0x00000001u)

#define CSL_TAC_CFG_BEII_IE0_SGCP0_FIFO_OVER_ENA_MASK (0x00000002u)
#define CSL_TAC_CFG_BEII_IE0_SGCP0_FIFO_OVER_ENA_SHIFT (0x00000001u)
#define CSL_TAC_CFG_BEII_IE0_SGCP0_FIFO_OVER_ENA_RESETVAL (0x00000000u)
/*----SGCP0_FIFO_OVER_ENA Tokens----*/
#define CSL_TAC_CFG_BEII_IE0_SGCP0_FIFO_OVER_ENA_DISABLE (0x00000000u)
#define CSL_TAC_CFG_BEII_IE0_SGCP0_FIFO_OVER_ENA_ENABLE (0x00000001u)

#define CSL_TAC_CFG_BEII_IE0_SGCP0_CYC_OVER_ENA_MASK (0x00000001u)
#define CSL_TAC_CFG_BEII_IE0_SGCP0_CYC_OVER_ENA_SHIFT (0x00000000u)
#define CSL_TAC_CFG_BEII_IE0_SGCP0_CYC_OVER_ENA_RESETVAL (0x00000000u)
/*----SGCP0_CYC_OVER_ENA Tokens----*/
#define CSL_TAC_CFG_BEII_IE0_SGCP0_CYC_OVER_ENA_DISABLE (0x00000000u)
#define CSL_TAC_CFG_BEII_IE0_SGCP0_CYC_OVER_ENA_ENABLE (0x00000001u)

#define CSL_TAC_CFG_BEII_IE0_RESETVAL     (0x00000000u)

/* BEII_IE1 */


#define CSL_TAC_CFG_BEII_IE1_BE_WD_ENA_MASK (0x00000010u)
#define CSL_TAC_CFG_BEII_IE1_BE_WD_ENA_SHIFT (0x00000004u)
#define CSL_TAC_CFG_BEII_IE1_BE_WD_ENA_RESETVAL (0x00000000u)
/*----BE_WD_ENA Tokens----*/
#define CSL_TAC_CFG_BEII_IE1_BE_WD_ENA_DISABLE (0x00000000u)
#define CSL_TAC_CFG_BEII_IE1_BE_WD_ENA_ENABLE (0x00000001u)

#define CSL_TAC_CFG_BEII_IE1_FE2_TRANS_ENA_MASK (0x00000004u)
#define CSL_TAC_CFG_BEII_IE1_FE2_TRANS_ENA_SHIFT (0x00000002u)
#define CSL_TAC_CFG_BEII_IE1_FE2_TRANS_ENA_RESETVAL (0x00000000u)
/*----FE2_TRANS_ENA Tokens----*/
#define CSL_TAC_CFG_BEII_IE1_FE2_TRANS_ENA_DISABLE (0x00000000u)
#define CSL_TAC_CFG_BEII_IE1_FE2_TRANS_ENA_ENABLE (0x00000001u)

#define CSL_TAC_CFG_BEII_IE1_FE1_TRANS_ENA_MASK (0x00000002u)
#define CSL_TAC_CFG_BEII_IE1_FE1_TRANS_ENA_SHIFT (0x00000001u)
#define CSL_TAC_CFG_BEII_IE1_FE1_TRANS_ENA_RESETVAL (0x00000000u)
/*----FE1_TRANS_ENA Tokens----*/
#define CSL_TAC_CFG_BEII_IE1_FE1_TRANS_ENA_DISABLE (0x00000000u)
#define CSL_TAC_CFG_BEII_IE1_FE1_TRANS_ENA_ENABLE (0x00000001u)

#define CSL_TAC_CFG_BEII_IE1_FE0_TRANS_ENA_MASK (0x00000001u)
#define CSL_TAC_CFG_BEII_IE1_FE0_TRANS_ENA_SHIFT (0x00000000u)
#define CSL_TAC_CFG_BEII_IE1_FE0_TRANS_ENA_RESETVAL (0x00000000u)
/*----FE0_TRANS_ENA Tokens----*/
#define CSL_TAC_CFG_BEII_IE1_FE0_TRANS_ENA_DISABLE (0x00000000u)
#define CSL_TAC_CFG_BEII_IE1_FE0_TRANS_ENA_ENABLE (0x00000001u)

#define CSL_TAC_CFG_BEII_IE1_RESETVAL     (0x00000000u)


/* BEII_IECS0 */

#define CSL_TAC_CFG_BEII_IECS0_SGCP5_IB_WR_MISS_CLEAR_MASK (0x00800000u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP5_IB_WR_MISS_CLEAR_SHIFT (0x00000017u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP5_IB_WR_MISS_CLEAR_RESETVAL (0x00000000u)
/*----SGCP5_IB_WR_MISS_CLEAR Tokens----*/
#define CSL_TAC_CFG_BEII_IECS0_SGCP5_IB_WR_MISS_CLEAR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP5_IB_WR_MISS_CLEAR_CLEAR (0x00000001u)

#define CSL_TAC_CFG_BEII_IECS0_SGCP5_SEQ_CLEAR_MASK (0x00400000u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP5_SEQ_CLEAR_SHIFT (0x00000016u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP5_SEQ_CLEAR_RESETVAL (0x00000000u)
/*----SGCP5_SEQ_CLEAR Tokens----*/
#define CSL_TAC_CFG_BEII_IECS0_SGCP5_SEQ_CLEAR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP5_SEQ_CLEAR_CLEAR (0x00000001u)

#define CSL_TAC_CFG_BEII_IECS0_SGCP5_FIFO_OVER_CLEAR_MASK (0x00200000u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP5_FIFO_OVER_CLEAR_SHIFT (0x00000015u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP5_FIFO_OVER_CLEAR_RESETVAL (0x00000000u)
/*----SGCP5_FIFO_OVER_CLEAR Tokens----*/
#define CSL_TAC_CFG_BEII_IECS0_SGCP5_FIFO_OVER_CLEAR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP5_FIFO_OVER_CLEAR_CLEAR (0x00000001u)

#define CSL_TAC_CFG_BEII_IECS0_SGCP5_CYC_OVER_CLEAR_MASK (0x00100000u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP5_CYC_OVER_CLEAR_SHIFT (0x00000014u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP5_CYC_OVER_CLEAR_RESETVAL (0x00000000u)
/*----SGCP5_CYC_OVER_CLEAR Tokens----*/
#define CSL_TAC_CFG_BEII_IECS0_SGCP5_CYC_OVER_CLEAR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP5_CYC_OVER_CLEAR_CLEAR (0x00000001u)

#define CSL_TAC_CFG_BEII_IECS0_SGCP4_IB_WR_MISS_CLEAR_MASK (0x00080000u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP4_IB_WR_MISS_CLEAR_SHIFT (0x00000013u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP4_IB_WR_MISS_CLEAR_RESETVAL (0x00000000u)
/*----SGCP4_IB_WR_MISS_CLEAR Tokens----*/
#define CSL_TAC_CFG_BEII_IECS0_SGCP4_IB_WR_MISS_CLEAR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP4_IB_WR_MISS_CLEAR_CLEAR (0x00000001u)

#define CSL_TAC_CFG_BEII_IECS0_SGCP4_SEQ_CLEAR_MASK (0x00040000u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP4_SEQ_CLEAR_SHIFT (0x00000012u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP4_SEQ_CLEAR_RESETVAL (0x00000000u)
/*----SGCP4_SEQ_CLEAR Tokens----*/
#define CSL_TAC_CFG_BEII_IECS0_SGCP4_SEQ_CLEAR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP4_SEQ_CLEAR_CLEAR (0x00000001u)

#define CSL_TAC_CFG_BEII_IECS0_SGCP4_FIFO_OVER_CLEAR_MASK (0x00020000u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP4_FIFO_OVER_CLEAR_SHIFT (0x00000011u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP4_FIFO_OVER_CLEAR_RESETVAL (0x00000000u)
/*----SGCP4_FIFO_OVER_CLEAR Tokens----*/
#define CSL_TAC_CFG_BEII_IECS0_SGCP4_FIFO_OVER_CLEAR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP4_FIFO_OVER_CLEAR_CLEAR (0x00000001u)

#define CSL_TAC_CFG_BEII_IECS0_SGCP4_CYC_OVER_CLEAR_MASK (0x00010000u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP4_CYC_OVER_CLEAR_SHIFT (0x00000010u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP4_CYC_OVER_CLEAR_RESETVAL (0x00000000u)
/*----SGCP4_CYC_OVER_CLEAR Tokens----*/
#define CSL_TAC_CFG_BEII_IECS0_SGCP4_CYC_OVER_CLEAR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP4_CYC_OVER_CLEAR_CLEAR (0x00000001u)


#define CSL_TAC_CFG_BEII_IECS0_SGCP3_IB_WR_MISS_CLEAR_MASK (0x00008000u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP3_IB_WR_MISS_CLEAR_SHIFT (0x0000000Fu)
#define CSL_TAC_CFG_BEII_IECS0_SGCP3_IB_WR_MISS_CLEAR_RESETVAL (0x00000000u)
/*----SGCP3_IB_WR_MISS_CLEAR Tokens----*/
#define CSL_TAC_CFG_BEII_IECS0_SGCP3_IB_WR_MISS_CLEAR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP3_IB_WR_MISS_CLEAR_CLEAR (0x00000001u)

#define CSL_TAC_CFG_BEII_IECS0_SGCP3_SEQ_CLEAR_MASK (0x00004000u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP3_SEQ_CLEAR_SHIFT (0x0000000Eu)
#define CSL_TAC_CFG_BEII_IECS0_SGCP3_SEQ_CLEAR_RESETVAL (0x00000000u)
/*----SGCP3_SEQ_CLEAR Tokens----*/
#define CSL_TAC_CFG_BEII_IECS0_SGCP3_SEQ_CLEAR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP3_SEQ_CLEAR_CLEAR (0x00000001u)

#define CSL_TAC_CFG_BEII_IECS0_SGCP3_FIFO_OVER_CLEAR_MASK (0x00002000u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP3_FIFO_OVER_CLEAR_SHIFT (0x0000000Du)
#define CSL_TAC_CFG_BEII_IECS0_SGCP3_FIFO_OVER_CLEAR_RESETVAL (0x00000000u)
/*----SGCP3_FIFO_OVER_CLEAR Tokens----*/
#define CSL_TAC_CFG_BEII_IECS0_SGCP3_FIFO_OVER_CLEAR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP3_FIFO_OVER_CLEAR_CLEAR (0x00000001u)

#define CSL_TAC_CFG_BEII_IECS0_SGCP3_CYC_OVER_CLEAR_MASK (0x00001000u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP3_CYC_OVER_CLEAR_SHIFT (0x0000000Cu)
#define CSL_TAC_CFG_BEII_IECS0_SGCP3_CYC_OVER_CLEAR_RESETVAL (0x00000000u)
/*----SGCP3_CYC_OVER_CLEAR Tokens----*/
#define CSL_TAC_CFG_BEII_IECS0_SGCP3_CYC_OVER_CLEAR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP3_CYC_OVER_CLEAR_CLEAR (0x00000001u)


#define CSL_TAC_CFG_BEII_IECS0_SGCP2_IB_WR_MISS_CLEAR_MASK (0x00000800u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP2_IB_WR_MISS_CLEAR_SHIFT (0x0000000Bu)
#define CSL_TAC_CFG_BEII_IECS0_SGCP2_IB_WR_MISS_CLEAR_RESETVAL (0x00000000u)
/*----SGCP2_IB_WR_MISS_CLEAR Tokens----*/
#define CSL_TAC_CFG_BEII_IECS0_SGCP2_IB_WR_MISS_CLEAR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP2_IB_WR_MISS_CLEAR_CLEAR (0x00000001u)

#define CSL_TAC_CFG_BEII_IECS0_SGCP2_SEQ_CLEAR_MASK (0x00000400u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP2_SEQ_CLEAR_SHIFT (0x0000000Au)
#define CSL_TAC_CFG_BEII_IECS0_SGCP2_SEQ_CLEAR_RESETVAL (0x00000000u)
/*----SGCP2_SEQ_CLEAR Tokens----*/
#define CSL_TAC_CFG_BEII_IECS0_SGCP2_SEQ_CLEAR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP2_SEQ_CLEAR_CLEAR (0x00000001u)

#define CSL_TAC_CFG_BEII_IECS0_SGCP2_FIFO_OVER_CLEAR_MASK (0x00000200u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP2_FIFO_OVER_CLEAR_SHIFT (0x00000009u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP2_FIFO_OVER_CLEAR_RESETVAL (0x00000000u)
/*----SGCP2_FIFO_OVER_CLEAR Tokens----*/
#define CSL_TAC_CFG_BEII_IECS0_SGCP2_FIFO_OVER_CLEAR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP2_FIFO_OVER_CLEAR_CLEAR (0x00000001u)

#define CSL_TAC_CFG_BEII_IECS0_SGCP2_CYC_OVER_CLEAR_MASK (0x00000100u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP2_CYC_OVER_CLEAR_SHIFT (0x00000008u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP2_CYC_OVER_CLEAR_RESETVAL (0x00000000u)
/*----SGCP2_CYC_OVER_CLEAR Tokens----*/
#define CSL_TAC_CFG_BEII_IECS0_SGCP2_CYC_OVER_CLEAR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP2_CYC_OVER_CLEAR_CLEAR (0x00000001u)


#define CSL_TAC_CFG_BEII_IECS0_SGCP1_IB_WR_MISS_CLEAR_MASK (0x00000080u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP1_IB_WR_MISS_CLEAR_SHIFT (0x00000007u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP1_IB_WR_MISS_CLEAR_RESETVAL (0x00000000u)
/*----SGCP1_IB_WR_MISS_CLEAR Tokens----*/
#define CSL_TAC_CFG_BEII_IECS0_SGCP1_IB_WR_MISS_CLEAR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP1_IB_WR_MISS_CLEAR_CLEAR (0x00000001u)

#define CSL_TAC_CFG_BEII_IECS0_SGCP1_SEQ_CLEAR_MASK (0x00000040u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP1_SEQ_CLEAR_SHIFT (0x00000006u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP1_SEQ_CLEAR_RESETVAL (0x00000000u)
/*----SGCP1_SEQ_CLEAR Tokens----*/
#define CSL_TAC_CFG_BEII_IECS0_SGCP1_SEQ_CLEAR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP1_SEQ_CLEAR_CLEAR (0x00000001u)

#define CSL_TAC_CFG_BEII_IECS0_SGCP1_FIFO_OVER_CLEAR_MASK (0x00000020u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP1_FIFO_OVER_CLEAR_SHIFT (0x00000005u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP1_FIFO_OVER_CLEAR_RESETVAL (0x00000000u)
/*----SGCP1_FIFO_OVER_CLEAR Tokens----*/
#define CSL_TAC_CFG_BEII_IECS0_SGCP1_FIFO_OVER_CLEAR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP1_FIFO_OVER_CLEAR_CLEAR (0x00000001u)

#define CSL_TAC_CFG_BEII_IECS0_SGCP1_CYC_OVER_CLEAR_MASK (0x00000010u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP1_CYC_OVER_CLEAR_SHIFT (0x00000004u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP1_CYC_OVER_CLEAR_RESETVAL (0x00000000u)
/*----SGCP1_CYC_OVER_CLEAR Tokens----*/
#define CSL_TAC_CFG_BEII_IECS0_SGCP1_CYC_OVER_CLEAR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP1_CYC_OVER_CLEAR_CLEAR (0x00000001u)


#define CSL_TAC_CFG_BEII_IECS0_SGCP0_IB_WR_MISS_CLEAR_MASK (0x00000008u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP0_IB_WR_MISS_CLEAR_SHIFT (0x00000003u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP0_IB_WR_MISS_CLEAR_RESETVAL (0x00000000u)
/*----SGCP0_IB_WR_MISS_CLEAR Tokens----*/
#define CSL_TAC_CFG_BEII_IECS0_SGCP0_IB_WR_MISS_CLEAR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP0_IB_WR_MISS_CLEAR_CLEAR (0x00000001u)

#define CSL_TAC_CFG_BEII_IECS0_SGCP0_SEQ_CLEAR_MASK (0x00000004u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP0_SEQ_CLEAR_SHIFT (0x00000002u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP0_SEQ_CLEAR_RESETVAL (0x00000000u)
/*----SGCP0_SEQ_CLEAR Tokens----*/
#define CSL_TAC_CFG_BEII_IECS0_SGCP0_SEQ_CLEAR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP0_SEQ_CLEAR_CLEAR (0x00000001u)

#define CSL_TAC_CFG_BEII_IECS0_SGCP0_FIFO_OVER_CLEAR_MASK (0x00000002u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP0_FIFO_OVER_CLEAR_SHIFT (0x00000001u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP0_FIFO_OVER_CLEAR_RESETVAL (0x00000000u)
/*----SGCP0_FIFO_OVER_CLEAR Tokens----*/
#define CSL_TAC_CFG_BEII_IECS0_SGCP0_FIFO_OVER_CLEAR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP0_FIFO_OVER_CLEAR_CLEAR (0x00000001u)

#define CSL_TAC_CFG_BEII_IECS0_SGCP0_CYC_OVER_CLEAR_MASK (0x00000001u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP0_CYC_OVER_CLEAR_SHIFT (0x00000000u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP0_CYC_OVER_CLEAR_RESETVAL (0x00000000u)
/*----SGCP0_CYC_OVER_CLEAR Tokens----*/
#define CSL_TAC_CFG_BEII_IECS0_SGCP0_CYC_OVER_CLEAR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_IECS0_SGCP0_CYC_OVER_CLEAR_CLEAR (0x00000001u)

#define CSL_TAC_CFG_BEII_IECS0_RESETVAL   (0x00000000u)

/* BEII_IECS1 */


#define CSL_TAC_CFG_BEII_IECS1_BE_WD_CLEAR_MASK (0x00000010u)
#define CSL_TAC_CFG_BEII_IECS1_BE_WD_CLEAR_SHIFT (0x00000004u)
#define CSL_TAC_CFG_BEII_IECS1_BE_WD_CLEAR_RESETVAL (0x00000000u)
/*----BE_WD_CLEAR Tokens----*/
#define CSL_TAC_CFG_BEII_IECS1_BE_WD_CLEAR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_IECS1_BE_WD_CLEAR_CLEAR (0x00000001u)

#define CSL_TAC_CFG_BEII_IECS1_FE2_TRANS_CLEAR_MASK (0x00000004u)
#define CSL_TAC_CFG_BEII_IECS1_FE2_TRANS_CLEAR_SHIFT (0x00000002u)
#define CSL_TAC_CFG_BEII_IECS1_FE2_TRANS_CLEAR_RESETVAL (0x00000000u)
/*----FE2_TRANS_CLEAR Tokens----*/
#define CSL_TAC_CFG_BEII_IECS1_FE2_TRANS_CLEAR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_IECS1_FE2_TRANS_CLEAR_CLEAR (0x00000001u)

#define CSL_TAC_CFG_BEII_IECS1_FE1_TRANS_CLEAR_MASK (0x00000002u)
#define CSL_TAC_CFG_BEII_IECS1_FE1_TRANS_CLEAR_SHIFT (0x00000001u)
#define CSL_TAC_CFG_BEII_IECS1_FE1_TRANS_CLEAR_RESETVAL (0x00000000u)
/*----FE1_TRANS_CLEAR Tokens----*/
#define CSL_TAC_CFG_BEII_IECS1_FE1_TRANS_CLEAR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_IECS1_FE1_TRANS_CLEAR_CLEAR (0x00000001u)

#define CSL_TAC_CFG_BEII_IECS1_FE0_TRANS_CLEAR_MASK (0x00000001u)
#define CSL_TAC_CFG_BEII_IECS1_FE0_TRANS_CLEAR_SHIFT (0x00000000u)
#define CSL_TAC_CFG_BEII_IECS1_FE0_TRANS_CLEAR_RESETVAL (0x00000000u)
/*----FE0_TRANS_CLEAR Tokens----*/
#define CSL_TAC_CFG_BEII_IECS1_FE0_TRANS_CLEAR_NO_EFFECT (0x00000000u)
#define CSL_TAC_CFG_BEII_IECS1_FE0_TRANS_CLEAR_CLEAR (0x00000001u)

#define CSL_TAC_CFG_BEII_IECS1_RESETVAL   (0x00000000u)


/* BEII_EOI */

#define CSL_TAC_CFG_BEII_EOI_EOI_MASK    (0xFFFFFFFFu)
#define CSL_TAC_CFG_BEII_EOI_EOI_SHIFT   (0x00000000u)
#define CSL_TAC_CFG_BEII_EOI_EOI_RESETVAL (0x00000000u)

#define CSL_TAC_CFG_BEII_EOI_RESETVAL    (0x00000000u)

/* CFG_TOT */

#define CSL_TAC_CFG_CFG_TOT_TOT_ACC_NB_MASK (0x0000FFFFu)
#define CSL_TAC_CFG_CFG_TOT_TOT_ACC_NB_SHIFT (0x00000000u)
#define CSL_TAC_CFG_CFG_TOT_TOT_ACC_NB_RESETVAL (0x00000000u)

#define CSL_TAC_CFG_CFG_TOT_RESETVAL     (0x00000000u)

/* CFG_WRIT */


#define CSL_TAC_CFG_CFG_WRIT_WR_ACC_NB_MASK (0x0000FFFFu)
#define CSL_TAC_CFG_CFG_WRIT_WR_ACC_NB_SHIFT (0x00000000u)
#define CSL_TAC_CFG_CFG_WRIT_WR_ACC_NB_RESETVAL (0x00000000u)

#define CSL_TAC_CFG_CFG_WRIT_RESETVAL    (0x00000000u)

/* CFG_READ */


#define CSL_TAC_CFG_CFG_READ_RD_ACC_NB_MASK (0x0000FFFFu)
#define CSL_TAC_CFG_CFG_READ_RD_ACC_NB_SHIFT (0x00000000u)
#define CSL_TAC_CFG_CFG_READ_RD_ACC_NB_RESETVAL (0x00000000u)

#define CSL_TAC_CFG_CFG_READ_RESETVAL    (0x00000000u)

/* SLV_TOT */


#define CSL_TAC_CFG_SLV_TOT_TOT_ACC_NB_MASK (0x0000FFFFu)
#define CSL_TAC_CFG_SLV_TOT_TOT_ACC_NB_SHIFT (0x00000000u)
#define CSL_TAC_CFG_SLV_TOT_TOT_ACC_NB_RESETVAL (0x00000000u)

#define CSL_TAC_CFG_SLV_TOT_RESETVAL     (0x00000000u)

/* SLV_WRIT */


#define CSL_TAC_CFG_SLV_WRIT_WR_ACC_NB_MASK (0x0000FFFFu)
#define CSL_TAC_CFG_SLV_WRIT_WR_ACC_NB_SHIFT (0x00000000u)
#define CSL_TAC_CFG_SLV_WRIT_WR_ACC_NB_RESETVAL (0x00000000u)

#define CSL_TAC_CFG_SLV_WRIT_RESETVAL    (0x00000000u)

/* SLV_READ */


#define CSL_TAC_CFG_SLV_READ_RD_ACC_NB_MASK (0x0000FFFFu)
#define CSL_TAC_CFG_SLV_READ_RD_ACC_NB_SHIFT (0x00000000u)
#define CSL_TAC_CFG_SLV_READ_RD_ACC_NB_RESETVAL (0x00000000u)

#define CSL_TAC_CFG_SLV_READ_RESETVAL    (0x00000000u)

#endif
