/********************************************************************
 * Copyright (C) 2003-2013 Texas Instruments Incorporated.
 * 
 *  Redistribution and use in source and binary forms, with or without 
 *  modification, are permitted provided that the following conditions 
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright 
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the 
 *    documentation and/or other materials provided with the   
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
*********************************************************************
* file: cslr_xge_cpsw_ss_s.h
*
* Brief: This file contains the Register Description for xge_cpsw_ss_s
*
*********************************************************************/
#ifndef _CSLR_XGE_CPSW_SS_S_V0_H_
#define _CSLR_XGE_CPSW_SS_S_V0_H_

/* CSL Modification:
 *  The file has been modified from the AUTOGEN file for the following
 *  reasons:-
 *      a) Header files are included as per RTSC guidelines
 */

#include <ti/csl/cslr.h>
#include <ti/csl/tistdtypes.h>


/* Minimum unit = 1 byte */

/**************************************************************************\
* Register Overlay Structure for pcsr
\**************************************************************************/
typedef struct  {
    volatile Uint32 TX_CTL_REG;
    volatile Uint32 TX_STATUS_REG;
    volatile Uint32 RX_CTL_REG;
    volatile Uint32 RX_STATUS_REG;
    volatile Uint32 SEED_A_LO_REG;
    volatile Uint32 SEED_A_HI_REG;
    volatile Uint32 SEED_B_LO_REG;
    volatile Uint32 SEED_B_HI_REG;
    volatile Uint32 FEC_REG;
    volatile Uint32 CTL_REG;
    volatile Uint32 FEC_CNT_REG;
    volatile Uint32 ERR_FIFO_REG;
    volatile Uint8 RSVD0[80];
} CSL_Xge_cpsw_ss_sPcsrRegs;

/**************************************************************************\
* Register Overlay Structure
\**************************************************************************/
typedef struct  {
    volatile Uint32 IDVER_REG;
    volatile Uint32 SYNCE_COUNT_REG;
    volatile Uint32 SYNCE_MUX_REG;
    volatile Uint32 CONTROL_REG;
    volatile Uint8 RSVD0[1520];
    CSL_Xge_cpsw_ss_sPcsrRegs PCSR[2];
} CSL_Xge_cpsw_ss_sRegs;

/**************************************************************************\
* Field Definition Macros
\**************************************************************************/

/* tx_ctl_reg */

#define CSL_XGE_CPSW_SS_S_TX_CTL_REG_TX_SCR_LOOPBK_EN_MASK (0x00000001u)
#define CSL_XGE_CPSW_SS_S_TX_CTL_REG_TX_SCR_LOOPBK_EN_SHIFT (0x00000000u)
#define CSL_XGE_CPSW_SS_S_TX_CTL_REG_TX_SCR_LOOPBK_EN_RESETVAL (0x00000000u)

#define CSL_XGE_CPSW_SS_S_TX_CTL_REG_TX_LOOPBACK_EN_MASK (0x00000002u)
#define CSL_XGE_CPSW_SS_S_TX_CTL_REG_TX_LOOPBACK_EN_SHIFT (0x00000001u)
#define CSL_XGE_CPSW_SS_S_TX_CTL_REG_TX_LOOPBACK_EN_RESETVAL (0x00000000u)

#define CSL_XGE_CPSW_SS_S_TX_CTL_REG_TX_PRBS9_EN_MASK (0x00000004u)
#define CSL_XGE_CPSW_SS_S_TX_CTL_REG_TX_PRBS9_EN_SHIFT (0x00000002u)
#define CSL_XGE_CPSW_SS_S_TX_CTL_REG_TX_PRBS9_EN_RESETVAL (0x00000000u)

#define CSL_XGE_CPSW_SS_S_TX_CTL_REG_TX_PRBS31_EN_MASK (0x00000008u)
#define CSL_XGE_CPSW_SS_S_TX_CTL_REG_TX_PRBS31_EN_SHIFT (0x00000003u)
#define CSL_XGE_CPSW_SS_S_TX_CTL_REG_TX_PRBS31_EN_RESETVAL (0x00000000u)

#define CSL_XGE_CPSW_SS_S_TX_CTL_REG_TX_TEST_DAT_SEL_MASK (0x00000010u)
#define CSL_XGE_CPSW_SS_S_TX_CTL_REG_TX_TEST_DAT_SEL_SHIFT (0x00000004u)
#define CSL_XGE_CPSW_SS_S_TX_CTL_REG_TX_TEST_DAT_SEL_RESETVAL (0x00000000u)

#define CSL_XGE_CPSW_SS_S_TX_CTL_REG_TX_TEST_SEL_MASK (0x00000020u)
#define CSL_XGE_CPSW_SS_S_TX_CTL_REG_TX_TEST_SEL_SHIFT (0x00000005u)
#define CSL_XGE_CPSW_SS_S_TX_CTL_REG_TX_TEST_SEL_RESETVAL (0x00000000u)

#define CSL_XGE_CPSW_SS_S_TX_CTL_REG_TX_TEST_EN_MASK (0x00000040u)
#define CSL_XGE_CPSW_SS_S_TX_CTL_REG_TX_TEST_EN_SHIFT (0x00000006u)
#define CSL_XGE_CPSW_SS_S_TX_CTL_REG_TX_TEST_EN_RESETVAL (0x00000000u)

#define CSL_XGE_CPSW_SS_S_TX_CTL_REG_TX_SCR_BYPASS_MASK (0x00000080u)
#define CSL_XGE_CPSW_SS_S_TX_CTL_REG_TX_SCR_BYPASS_SHIFT (0x00000007u)
#define CSL_XGE_CPSW_SS_S_TX_CTL_REG_TX_SCR_BYPASS_RESETVAL (0x00000000u)

#define CSL_XGE_CPSW_SS_S_TX_CTL_REG_RESETVAL (0x00000000u)

/* tx_status_reg */

#define CSL_XGE_CPSW_SS_S_TX_STATUS_REG_TX_FAULT_MASK (0x00000001u)
#define CSL_XGE_CPSW_SS_S_TX_STATUS_REG_TX_FAULT_SHIFT (0x00000000u)
#define CSL_XGE_CPSW_SS_S_TX_STATUS_REG_TX_FAULT_RESETVAL (0x00000000u)

#define CSL_XGE_CPSW_SS_S_TX_STATUS_REG_RESETVAL (0x00000000u)

/* rx_ctl_reg */

#define CSL_XGE_CPSW_SS_S_RX_CTL_REG_RX_TPTER_CNT_RST_MASK (0x00000001u)
#define CSL_XGE_CPSW_SS_S_RX_CTL_REG_RX_TPTER_CNT_RST_SHIFT (0x00000000u)
#define CSL_XGE_CPSW_SS_S_RX_CTL_REG_RX_TPTER_CNT_RST_RESETVAL (0x00000000u)

#define CSL_XGE_CPSW_SS_S_RX_CTL_REG_RX_TEST_CNT_125US_MASK (0x00000002u)
#define CSL_XGE_CPSW_SS_S_RX_CTL_REG_RX_TEST_CNT_125US_SHIFT (0x00000001u)
#define CSL_XGE_CPSW_SS_S_RX_CTL_REG_RX_TEST_CNT_125US_RESETVAL (0x00000000u)

#define CSL_XGE_CPSW_SS_S_RX_CTL_REG_RX_TEST_CNT_PRE_MASK (0x00000004u)
#define CSL_XGE_CPSW_SS_S_RX_CTL_REG_RX_TEST_CNT_PRE_SHIFT (0x00000002u)
#define CSL_XGE_CPSW_SS_S_RX_CTL_REG_RX_TEST_CNT_PRE_RESETVAL (0x00000000u)

#define CSL_XGE_CPSW_SS_S_RX_CTL_REG_RX_BER_CNT_RST_MASK (0x00000008u)
#define CSL_XGE_CPSW_SS_S_RX_CTL_REG_RX_BER_CNT_RST_SHIFT (0x00000003u)
#define CSL_XGE_CPSW_SS_S_RX_CTL_REG_RX_BER_CNT_RST_RESETVAL (0x00000000u)

#define CSL_XGE_CPSW_SS_S_RX_CTL_REG_RX_ERR_BLK_CNT_RST_MASK (0x00000010u)
#define CSL_XGE_CPSW_SS_S_RX_CTL_REG_RX_ERR_BLK_CNT_RST_SHIFT (0x00000004u)
#define CSL_XGE_CPSW_SS_S_RX_CTL_REG_RX_ERR_BLK_CNT_RST_RESETVAL (0x00000000u)

#define CSL_XGE_CPSW_SS_S_RX_CTL_REG_RX_PRBS31_EN_MASK (0x00000020u)
#define CSL_XGE_CPSW_SS_S_RX_CTL_REG_RX_PRBS31_EN_SHIFT (0x00000005u)
#define CSL_XGE_CPSW_SS_S_RX_CTL_REG_RX_PRBS31_EN_RESETVAL (0x00000000u)

#define CSL_XGE_CPSW_SS_S_RX_CTL_REG_RX_TEST_DAT_SEL_MASK (0x00000040u)
#define CSL_XGE_CPSW_SS_S_RX_CTL_REG_RX_TEST_DAT_SEL_SHIFT (0x00000006u)
#define CSL_XGE_CPSW_SS_S_RX_CTL_REG_RX_TEST_DAT_SEL_RESETVAL (0x00000000u)

#define CSL_XGE_CPSW_SS_S_RX_CTL_REG_RX_TEST_EN_MASK (0x00000080u)
#define CSL_XGE_CPSW_SS_S_RX_CTL_REG_RX_TEST_EN_SHIFT (0x00000007u)
#define CSL_XGE_CPSW_SS_S_RX_CTL_REG_RX_TEST_EN_RESETVAL (0x00000000u)

#define CSL_XGE_CPSW_SS_S_RX_CTL_REG_RESETVAL (0x00000000u)

/* rx_status_reg */

#define CSL_XGE_CPSW_SS_S_RX_STATUS_REG_RX_TPT_ERR_CNT_MASK (0x0000FFFFu)
#define CSL_XGE_CPSW_SS_S_RX_STATUS_REG_RX_TPT_ERR_CNT_SHIFT (0x00000000u)
#define CSL_XGE_CPSW_SS_S_RX_STATUS_REG_RX_TPT_ERR_CNT_RESETVAL (0x00000000u)

#define CSL_XGE_CPSW_SS_S_RX_STATUS_REG_RX_ERR_BLK_CNT_MASK (0x00FF0000u)
#define CSL_XGE_CPSW_SS_S_RX_STATUS_REG_RX_ERR_BLK_CNT_SHIFT (0x00000010u)
#define CSL_XGE_CPSW_SS_S_RX_STATUS_REG_RX_ERR_BLK_CNT_RESETVAL (0x00000000u)

#define CSL_XGE_CPSW_SS_S_RX_STATUS_REG_RX_BER_CNT_MASK (0x3F000000u)
#define CSL_XGE_CPSW_SS_S_RX_STATUS_REG_RX_BER_CNT_SHIFT (0x00000018u)
#define CSL_XGE_CPSW_SS_S_RX_STATUS_REG_RX_BER_CNT_RESETVAL (0x00000000u)

#define CSL_XGE_CPSW_SS_S_RX_STATUS_REG_RX_BLOCK_LOCK_MASK (0x40000000u)
#define CSL_XGE_CPSW_SS_S_RX_STATUS_REG_RX_BLOCK_LOCK_SHIFT (0x0000001Eu)
#define CSL_XGE_CPSW_SS_S_RX_STATUS_REG_RX_BLOCK_LOCK_RESETVAL (0x00000000u)

#define CSL_XGE_CPSW_SS_S_RX_STATUS_REG_RX_HI_BER_MASK (0x80000000u)
#define CSL_XGE_CPSW_SS_S_RX_STATUS_REG_RX_HI_BER_SHIFT (0x0000001Fu)
#define CSL_XGE_CPSW_SS_S_RX_STATUS_REG_RX_HI_BER_RESETVAL (0x00000000u)

#define CSL_XGE_CPSW_SS_S_RX_STATUS_REG_RESETVAL (0x00000000u)

/* seed_a_lo_reg */

#define CSL_XGE_CPSW_SS_S_SEED_A_LO_REG_SEED_A_LO_MASK (0xFFFFFFFFu)
#define CSL_XGE_CPSW_SS_S_SEED_A_LO_REG_SEED_A_LO_SHIFT (0x00000000u)
#define CSL_XGE_CPSW_SS_S_SEED_A_LO_REG_SEED_A_LO_RESETVAL (0x00000000u)

#define CSL_XGE_CPSW_SS_S_SEED_A_LO_REG_RESETVAL (0x00000000u)

/* seed_a_hi_reg */

#define CSL_XGE_CPSW_SS_S_SEED_A_HI_REG_SEED_A_HI_MASK (0x03FFFFFFu)
#define CSL_XGE_CPSW_SS_S_SEED_A_HI_REG_SEED_A_HI_SHIFT (0x00000000u)
#define CSL_XGE_CPSW_SS_S_SEED_A_HI_REG_SEED_A_HI_RESETVAL (0x00000000u)

#define CSL_XGE_CPSW_SS_S_SEED_A_HI_REG_RESETVAL (0x00000000u)

/* seed_b_lo_reg */

#define CSL_XGE_CPSW_SS_S_SEED_B_LO_REG_SEED_B_LO_MASK (0xFFFFFFFFu)
#define CSL_XGE_CPSW_SS_S_SEED_B_LO_REG_SEED_B_LO_SHIFT (0x00000000u)
#define CSL_XGE_CPSW_SS_S_SEED_B_LO_REG_SEED_B_LO_RESETVAL (0x00000000u)

#define CSL_XGE_CPSW_SS_S_SEED_B_LO_REG_RESETVAL (0x00000000u)

/* seed_b_hi_reg */

#define CSL_XGE_CPSW_SS_S_SEED_B_HI_REG_SEED_B_HI_MASK (0x03FFFFFFu)
#define CSL_XGE_CPSW_SS_S_SEED_B_HI_REG_SEED_B_HI_SHIFT (0x00000000u)
#define CSL_XGE_CPSW_SS_S_SEED_B_HI_REG_SEED_B_HI_RESETVAL (0x00000000u)

#define CSL_XGE_CPSW_SS_S_SEED_B_HI_REG_RESETVAL (0x00000000u)

/* fec_reg */

#define CSL_XGE_CPSW_SS_S_FEC_REG_FEC_ENABLE_MASK (0x00000001u)
#define CSL_XGE_CPSW_SS_S_FEC_REG_FEC_ENABLE_SHIFT (0x00000000u)
#define CSL_XGE_CPSW_SS_S_FEC_REG_FEC_ENABLE_RESETVAL (0x00000000u)

#define CSL_XGE_CPSW_SS_S_FEC_REG_FEC_ENA_ERR_IND_MASK (0x00000002u)
#define CSL_XGE_CPSW_SS_S_FEC_REG_FEC_ENA_ERR_IND_SHIFT (0x00000001u)
#define CSL_XGE_CPSW_SS_S_FEC_REG_FEC_ENA_ERR_IND_RESETVAL (0x00000000u)

#define CSL_XGE_CPSW_SS_S_FEC_REG_RESETVAL (0x00000000u)

/* ctl_reg */

#define CSL_XGE_CPSW_SS_S_CTL_REG_PCSR_SIGNAL_OK_MASK (0x00000001u)
#define CSL_XGE_CPSW_SS_S_CTL_REG_PCSR_SIGNAL_OK_SHIFT (0x00000000u)
#define CSL_XGE_CPSW_SS_S_CTL_REG_PCSR_SIGNAL_OK_RESETVAL (0x00000000u)

#define CSL_XGE_CPSW_SS_S_CTL_REG_PCSR_SIGNAL_OK_EN_MASK (0x00000002u)
#define CSL_XGE_CPSW_SS_S_CTL_REG_PCSR_SIGNAL_OK_EN_SHIFT (0x00000001u)
#define CSL_XGE_CPSW_SS_S_CTL_REG_PCSR_SIGNAL_OK_EN_RESETVAL (0x00000000u)

#define CSL_XGE_CPSW_SS_S_CTL_REG_RESETVAL (0x00000000u)

/* fec_cnt_reg */

#define CSL_XGE_CPSW_SS_S_FEC_CNT_REG_RX_FEC_UNCORR_MASK (0x0000FFFFu)
#define CSL_XGE_CPSW_SS_S_FEC_CNT_REG_RX_FEC_UNCORR_SHIFT (0x00000000u)
#define CSL_XGE_CPSW_SS_S_FEC_CNT_REG_RX_FEC_UNCORR_RESETVAL (0x00000000u)

#define CSL_XGE_CPSW_SS_S_FEC_CNT_REG_RX_FEC_CORR_MASK (0xFFFF0000u)
#define CSL_XGE_CPSW_SS_S_FEC_CNT_REG_RX_FEC_CORR_SHIFT (0x00000010u)
#define CSL_XGE_CPSW_SS_S_FEC_CNT_REG_RX_FEC_CORR_RESETVAL (0x00000000u)

#define CSL_XGE_CPSW_SS_S_FEC_CNT_REG_RESETVAL (0x00000000u)

/* err_fifo_reg */

#define CSL_XGE_CPSW_SS_S_ERR_FIFO_REG_RX_ERR_FIFO_CTC_MASK (0x00000001u)
#define CSL_XGE_CPSW_SS_S_ERR_FIFO_REG_RX_ERR_FIFO_CTC_SHIFT (0x00000000u)
#define CSL_XGE_CPSW_SS_S_ERR_FIFO_REG_RX_ERR_FIFO_CTC_RESETVAL (0x00000000u)

#define CSL_XGE_CPSW_SS_S_ERR_FIFO_REG_RESETVAL (0x00000000u)

/* idver_reg */

#define CSL_XGE_CPSW_SS_S_IDVER_REG_MINOR_VER_MASK (0x000000FFu)
#define CSL_XGE_CPSW_SS_S_IDVER_REG_MINOR_VER_SHIFT (0x00000000u)
#define CSL_XGE_CPSW_SS_S_IDVER_REG_MINOR_VER_RESETVAL (0x00000000u)

#define CSL_XGE_CPSW_SS_S_IDVER_REG_MAJOR_VER_MASK (0x00000700u)
#define CSL_XGE_CPSW_SS_S_IDVER_REG_MAJOR_VER_SHIFT (0x00000008u)
#define CSL_XGE_CPSW_SS_S_IDVER_REG_MAJOR_VER_RESETVAL (0x00000001u)

#define CSL_XGE_CPSW_SS_S_IDVER_REG_RTL_VER_MASK (0x0000F800u)
#define CSL_XGE_CPSW_SS_S_IDVER_REG_RTL_VER_SHIFT (0x0000000Bu)
#define CSL_XGE_CPSW_SS_S_IDVER_REG_RTL_VER_RESETVAL (0x00000004u)

#define CSL_XGE_CPSW_SS_S_IDVER_REG_IDENT_MASK (0xFFFF0000u)
#define CSL_XGE_CPSW_SS_S_IDVER_REG_IDENT_SHIFT (0x00000010u)
#define CSL_XGE_CPSW_SS_S_IDVER_REG_IDENT_RESETVAL (0x00004EE4u)

#define CSL_XGE_CPSW_SS_S_IDVER_REG_RESETVAL (0x4EE42100u)

/* synce_count_reg */

#define CSL_XGE_CPSW_SS_S_SYNCE_COUNT_REG_SYNCE_CNT_MASK (0xFFFFFFFFu)
#define CSL_XGE_CPSW_SS_S_SYNCE_COUNT_REG_SYNCE_CNT_SHIFT (0x00000000u)
#define CSL_XGE_CPSW_SS_S_SYNCE_COUNT_REG_SYNCE_CNT_RESETVAL (0x00000000u)

#define CSL_XGE_CPSW_SS_S_SYNCE_COUNT_REG_RESETVAL (0x00000000u)

/* synce_mux_reg */

#define CSL_XGE_CPSW_SS_S_SYNCE_MUX_REG_SYNCE_SEL_MASK (0x00000003u)
#define CSL_XGE_CPSW_SS_S_SYNCE_MUX_REG_SYNCE_SEL_SHIFT (0x00000000u)
#define CSL_XGE_CPSW_SS_S_SYNCE_MUX_REG_SYNCE_SEL_RESETVAL (0x00000000u)

#define CSL_XGE_CPSW_SS_S_SYNCE_MUX_REG_RESETVAL (0x00000000u)

/* control_reg */

#define CSL_XGE_CPSW_SS_S_CONTROL_REG_XGMII1_MODE_MASK (0x00000001u)
#define CSL_XGE_CPSW_SS_S_CONTROL_REG_XGMII1_MODE_SHIFT (0x00000000u)
#define CSL_XGE_CPSW_SS_S_CONTROL_REG_XGMII1_MODE_RESETVAL (0x00000000u)

#define CSL_XGE_CPSW_SS_S_CONTROL_REG_XGMII2_MODE_MASK (0x00000002u)
#define CSL_XGE_CPSW_SS_S_CONTROL_REG_XGMII2_MODE_SHIFT (0x00000001u)
#define CSL_XGE_CPSW_SS_S_CONTROL_REG_XGMII2_MODE_RESETVAL (0x00000000u)

#define CSL_XGE_CPSW_SS_S_CONTROL_REG_EXT_EN_XGMII1_MASK (0x00000100u)
#define CSL_XGE_CPSW_SS_S_CONTROL_REG_EXT_EN_XGMII1_SHIFT (0x00000008u)
#define CSL_XGE_CPSW_SS_S_CONTROL_REG_EXT_EN_XGMII1_RESETVAL (0x00000000u)

#define CSL_XGE_CPSW_SS_S_CONTROL_REG_EXT_EN_XGMII2_MASK (0x00000200u)
#define CSL_XGE_CPSW_SS_S_CONTROL_REG_EXT_EN_XGMII2_SHIFT (0x00000009u)
#define CSL_XGE_CPSW_SS_S_CONTROL_REG_EXT_EN_XGMII2_RESETVAL (0x00000000u)

#define CSL_XGE_CPSW_SS_S_CONTROL_REG_EXT_EN_SL1_MASK (0x00010000u)
#define CSL_XGE_CPSW_SS_S_CONTROL_REG_EXT_EN_SL1_SHIFT (0x00000010u)
#define CSL_XGE_CPSW_SS_S_CONTROL_REG_EXT_EN_SL1_RESETVAL (0x00000000u)

#define CSL_XGE_CPSW_SS_S_CONTROL_REG_EXT_EN_SL2_MASK (0x00020000u)
#define CSL_XGE_CPSW_SS_S_CONTROL_REG_EXT_EN_SL2_SHIFT (0x00000011u)
#define CSL_XGE_CPSW_SS_S_CONTROL_REG_EXT_EN_SL2_RESETVAL (0x00000000u)

#define CSL_XGE_CPSW_SS_S_CONTROL_REG_RESETVAL (0x00000000u)

#endif
