/** 
 *   @file  fftc_testcfg_540.h
 *
 *   @brief  
 *      Header file containing FFTC Test vector details.
 *
 *      The format of the file contents are as follows:
 *          *   Line 1:                         Number of FFT data blocks in this
 *                                              packet configuration.
 *          *   Line 2 onwards (32 entries):    FFT configuration for the data, details
 *                                              below:
 *                  (01)    DFT sample size - each sample is again 4 bytes wide.
 *                          (Fftc_QLocalCfg.controlRegConfig.dftSize)
 *                  (02)    Not used
 *                  (03)    Not used
 *                  (04)    Not used
 *                  (05)    Dynamic Scaling Enable Boolean flag
 *                          (Fftc_QLocalCfg.scalingShiftingRegConfig.bDynamicScaleEnable)
 *                  (06)    Last Radix Stage Output Scaling value (only for static scaling)
 *                          (Fftc_QLocalCfg.scalingShiftingRegConfig.radixScalingValLast)
 *                  (07)    Radix Stage 0 Scaling value (only for static scaling)
 *                          (Fftc_QLocalCfg.scalingShiftingRegConfig.radixScalingVal[0])
 *                  (08)    Radix Stage 1 Scaling value (only for static scaling)
 *                          (Fftc_QLocalCfg.scalingShiftingRegConfig.radixScalingVal[1])
 *                  (09)    Radix Stage 2 Scaling value (only for static scaling)
 *                          (Fftc_QLocalCfg.scalingShiftingRegConfig.radixScalingVal[2])
 *                  (10)    Radix Stage 3 Scaling value (only for static scaling)
 *                          (Fftc_QLocalCfg.scalingShiftingRegConfig.radixScalingVal[3])
 *                  (11)    Radix Stage 4 Scaling value (only for static scaling)
 *                          (Fftc_QLocalCfg.scalingShiftingRegConfig.radixScalingVal[4])
 *                  (12)    Radix Stage 5 Scaling value (only for static scaling)
 *                          (Fftc_QLocalCfg.scalingShiftingRegConfig.radixScalingVal[5])
 *                  (13)    Radix Stage 6 Scaling value (only for static scaling)
 *                          (Fftc_QLocalCfg.scalingShiftingRegConfig.radixScalingVal[6])
 *                  (14)    Not used
 *                  (15)    Not used
 *                  (16)    Not used
 *                  (17)    Inverse FFT enable boolean flag
 *                          (Fftc_QLocalCfg.controlRegConfig.bInverseFFTEnable)
 *                  (18)    Emulate DSP 16x16 boolean flag - Not used currently
 *                          (Fftc_QLocalCfg.controlRegConfig.bEmulateDSP16x16)
 *                  (19)    Output Scaling Value
 *                          (Fftc_QLocalCfg.scalingShiftingRegConfig.outputScaleVal)
 *                  (20)    Input Shifting Boolean flag
 *                          (Fftc_QLocalCfg.scalingShiftingRegConfig.bInputFFTShift)
 *                  (21)    Output Shifting Boolean flag
 *                          (Fftc_QLocalCfg.scalingShiftingRegConfig.bOutputFFTShift)
 *                  (22)    Zero Pad Mode Enable boolean flag
 *                          (Fftc_QLocalCfg.controlRegConfig.bZeroPadEnable)
 *                  (23)    Zero Pad Mode (used only if zero padding enabled) 
 *                          (Fftc_QLocalCfg.controlRegConfig.zeroPadMode)
 *                  (24)    Zero Pad Factor (used only if zero padding enabled) 
 *                          (Fftc_QLocalCfg.controlRegConfig.zeroPadFactor)
 *                  (25)    LTE Frequency Shifting Enable boolean flag
 *                          (Fftc_QLocalCfg.freqShiftRegConfig.bFreqShiftEnable)
 *                  (26)    LTE Frequency Shift value (used only if LTE freq shifting enabled)
 *                          (Fftc_QLocalCfg.freqShiftRegConfig.freqShiftVal)
 *                  (27)    LTE Frequency Shift Table Index (used only if LTE freq shifting enabled)
 *                          (Fftc_QLocalCfg.freqShiftRegConfig.freqShiftIndex)
 *                  (28)    LTE Frequency Shift Multiplication factor (used only if LTE freq shifting enabled)
 *                          (Fftc_QLocalCfg.freqShiftRegConfig.freqShiftMultFactor)
 *                  (29)    LTE Frequency Shift Phase (used only if LTE freq shifting enabled)
 *                          (Fftc_QLocalCfg.freqShiftRegConfig.freqShiftInitPhase)
 *                  (30)    LTE Frequency Shift Direction (used only if LTE freq shifting enabled)
 *                          (Fftc_QLocalCfg.freqShiftRegConfig.freqShiftDirection)
 *                  (31)    Cyclic Prefix Addition Enable Boolean flag 
 *                          (Fftc_QLocalCfg.cyclicPrefixRegConfig.bCyclicPrefixAddEnable)
 *                  (32)    Cyclic Prefix Addition Value (Used only if cyclic prefix addition enabled) 
 *                          (Fftc_QLocalCfg.cyclicPrefixRegConfig.cyclicPrefixAddNum)
 *          *   Block Number
 *          *   FFT input data (sample size * 2 entries)
 *          *   Expected Block Exponent Value
 *          *   Expected Clipping Detect Value
 *          *   Expected Number of clock cycles to be taken for operation          
 *          *   Expected FFT output data - reference data to validate result from FFT engine.
 *              (sample size * 2 entries)
 * 
 *  \par
 *  ============================================================================
 *  @n   (C) Copyright 2009, Texas Instruments, Inc.
 * 
 *  Redistribution and use in source and binary forms, with or without 
 *  modification, are permitted provided that the following conditions 
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright 
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the 
 *    documentation and/or other materials provided with the   
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
*/

#ifndef _FFTC_TESTCFG_540_H_
#define _FFTC_TESTCFG_540_H_

Int16 inputConfig_540[] = {
3,
540,
16,
19,
15,
1,
0,
0,
0,
0,
0,
0,
0,
0,
1,
1,
1,
0,
0,
128,
0,
0,
0,
0,
1,
0,
0,
0,
0,
0,
0,
0,
0,
1,
5359,
-4692,
-8042,
160,
-6048,
4685,
528,
2375,
6093,
-13135,
3902,
5321,
5555,
4879,
-294,
-3538,
-3847,
-254,
3152,
-3585,
-822,
5014,
-556,
-4754,
2833,
6406,
4161,
-4167,
-2550,
-5593,
4317,
3126,
2303,
1438,
-118,
-6529,
3580,
-1716,
3247,
3682,
-8644,
-1212,
6996,
7955,
1130,
10798,
4160,
6710,
3099,
-9250,
8224,
2521,
5318,
-868,
-3962,
-4238,
1624,
-3015,
-21,
-1163,
3511,
2691,
14538,
10074,
55,
-586,
2759,
5063,
-2997,
-445,
4543,
-1130,
2576,
640,
-2493,
-1562,
-2915,
-2340,
5617,
-5535,
1652,
-3964,
5461,
-2962,
-4566,
1372,
1738,
-1703,
4352,
-3545,
645,
6092,
-1722,
-164,
4068,
-9449,
1440,
-7012,
-7920,
1859,
-5926,
2915,
3270,
6608,
-11598,
484,
1627,
4753,
3588,
3614,
3060,
-9848,
446,
2633,
3076,
-6433,
3545,
-4185,
-824,
-3134,
-3849,
2527,
7869,
-6098,
-3644,
6020,
-1104,
-990,
-2782,
-4144,
1689,
933,
2828,
96,
-7489,
3342,
-4285,
6028,
-2081,
4072,
706,
-2402,
-4148,
2314,
2422,
1991,
-976,
9225,
4675,
6466,
-500,
218,
-2073,
-11357,
-5409,
3150,
228,
3942,
1066,
4455,
148,
2171,
4148,
1603,
-369,
795,
-495,
5673,
-4750,
-10061,
4066,
-2995,
10018,
181,
612,
2305,
2922,
992,
-4524,
-3303,
1777,
5294,
3799,
1824,
5123,
5018,
-7546,
-10518,
1314,
3375,
-5976,
-6637,
60,
-9,
3046,
-5072,
-3080,
-1213,
3104,
-1440,
-3295,
2979,
-7299,
8177,
-4165,
-1780,
-254,
-2132,
7874,
-351,
-1638,
-852,
8201,
-527,
5019,
-1282,
926,
3792,
7248,
741,
-1695,
-6767,
-2045,
2667,
1135,
-2185,
2045,
7813,
5176,
-2394,
250,
2560,
1728,
-1047,
4310,
14,
-4246,
-54,
3468,
9564,
3075,
-2568,
-7711,
-4664,
4303,
-1039,
411,
-869,
-1514,
-126,
-5932,
-5782,
302,
3491,
-1006,
-6247,
5655,
9041,
3463,
-6756,
-6962,
-10790,
-6545,
8378,
-4197,
5107,
-3869,
2337,
-1401,
368,
19918,
4174,
18,
-1499,
-1071,
-743,
1177,
5928,
-4748,
589,
176,
1076,
-5454,
-1941,
-193,
2560,
3002,
2599,
2913,
3609,
-3932,
398,
2677,
-3463,
-320,
-2424,
-739,
6940,
-787,
-3311,
2558,
2600,
6143,
-4235,
7707,
10265,
1199,
943,
1703,
-4815,
-673,
6595,
4786,
-5842,
7551,
-3672,
1851,
2872,
11118,
-180,
-2196,
3450,
-4741,
11703,
2485,
-3270,
-1993,
-5530,
5030,
1040,
-3310,
-4960,
4446,
2905,
-170,
-427,
7251,
495,
2006,
4054,
-10877,
8416,
-9344,
-3053,
-265,
783,
-6265,
-181,
2794,
-2170,
4956,
-7250,
6967,
-8897,
-2981,
6346,
1672,
-4265,
1061,
-1659,
406,
1469,
-923,
-3835,
-2677,
-4212,
-872,
4053,
-11797,
-6430,
298,
-795,
5416,
-9600,
1611,
3137,
-1993,
-4185,
-1950,
966,
3920,
-13597,
2298,
-1116,
-1564,
3018,
2081,
7098,
-3475,
-8171,
136,
1247,
696,
2511,
-1258,
1339,
2304,
8654,
1891,
9012,
-2090,
2728,
-6010,
-2188,
-1916,
-2530,
4901,
-2782,
-5657,
2448,
-5758,
-588,
5076,
11745,
1156,
820,
4392,
3530,
-2381,
1111,
-1895,
2073,
4114,
893,
2679,
-2799,
4726,
597,
5050,
5812,
4819,
3735,
-3260,
-4154,
-467,
1879,
-1683,
-703,
3066,
-1010,
1327,
-1463,
1566,
379,
-3300,
5830,
1943,
6915,
2832,
309,
805,
-1698,
-1433,
2853,
6714,
3177,
3986,
1501,
-11677,
-255,
2337,
-1754,
8623,
2513,
-1917,
5876,
-3932,
-3450,
-1823,
-429,
-3516,
-8112,
1350,
-5881,
-5071,
-6718,
-110,
-2675,
-2982,
2718,
-9736,
8347,
2636,
1185,
209,
-936,
-4553,
8312,
2663,
4356,
-3897,
-2512,
-3151,
-6895,
-3101,
-5105,
8304,
128,
12789,
5352,
-2871,
1457,
-6665,
-1881,
-10521,
-7498,
-4967,
98,
2867,
1450,
-3840,
-619,
10851,
-3316,
-2182,
3756,
1267,
317,
8289,
-3878,
-167,
-799,
-2670,
122,
4025,
5952,
-10409,
1177,
-2919,
-2259,
4170,
-901,
-4803,
-4821,
5224,
-1980,
-900,
6423,
3660,
-8441,
-6084,
-599,
-3346,
2443,
-1085,
-2696,
-2687,
103,
5848,
-5178,
3126,
-1379,
-3007,
6200,
-2990,
4072,
3008,
1493,
-1362,
3978,
393,
3802,
-3597,
-3978,
-4138,
2612,
-2244,
-1628,
944,
-3380,
-4900,
-8298,
3262,
1945,
5258,
1618,
9383,
301,
-6851,
-5250,
-6811,
-7030,
2481,
-2584,
2725,
-7155,
7625,
318,
-4780,
-1580,
-5070,
1552,
-5129,
-1388,
790,
8286,
3334,
5909,
4795,
324,
-11997,
41,
11145,
-5431,
-523,
5721,
998,
4116,
1631,
-4215,
-7945,
-3539,
5842,
10518,
-2268,
17,
2234,
-3494,
4167,
-640,
-1708,
-4998,
-1783,
3522,
-812,
1959,
1894,
551,
2316,
8393,
-3675,
-2170,
2961,
-7328,
-2015,
-2517,
6279,
-12818,
946,
-2814,
-6036,
-429,
2568,
-2079,
-1116,
1268,
-5970,
3344,
-3110,
-107,
-2085,
-988,
7623,
3899,
136,
1817,
388,
-7814,
-1147,
1522,
2538,
-3062,
-5525,
-194,
-1862,
4108,
-3606,
-8125,
1766,
1676,
-329,
6751,
11905,
8523,
-6920,
2757,
-294,
-5330,
7830,
7194,
4447,
2635,
11638,
4542,
-2310,
-429,
-6377,
3205,
-7720,
-104,
-499,
-1783,
4387,
25,
4508,
-9036,
3310,
3411,
8403,
8963,
-7312,
310,
1704,
-5828,
-124,
-1343,
-7719,
3375,
3993,
-7061,
-2747,
-1699,
-9751,
1922,
-7916,
2308,
3753,
-4356,
4621,
-4459,
-5720,
4215,
1882,
-12446,
624,
2032,
140,
1786,
3680,
-2853,
1897,
-1393,
-2286,
-342,
-1264,
3818,
-2822,
2935,
351,
2323,
4324,
1860,
4127,
3089,
809,
-4017,
-364,
1299,
-299,
2993,
1211,
-5870,
2347,
1014,
13464,
5852,
692,
2447,
-3700,
365,
434,
-6164,
6096,
-6642,
-1782,
1441,
2557,
-6975,
-713,
-6270,
7776,
-1814,
1387,
-2533,
1344,
-6652,
-5849,
1958,
3469,
-1132,
-5892,
6428,
10340,
3068,
4598,
-955,
-2534,
-1915,
7989,
-1771,
3044,
-9967,
4409,
732,
4607,
5933,
-5921,
-3544,
-5683,
-5108,
7375,
-6570,
-5968,
2301,
-5610,
5140,
1429,
-830,
-3102,
1643,
-1913,
1896,
-4132,
7852,
-4018,
-1528,
-11398,
2581,
8765,
971,
-2967,
-5752,
-3479,
-6231,
7929,
-1625,
-4158,
-1166,
2175,
3394,
-2173,
-717,
3848,
-4482,
975,
8125,
133,
481,
-2224,
-2013,
1198,
3796,
-398,
-3633,
12754,
3914,
-9000,
365,
316,
-2242,
3487,
1194,
1680,
3485,
1014,
-4632,
-6138,
7365,
-707,
-7829,
-4020,
-1842,
4436,
-562,
9072,
-7887,
1701,
2667,
-6690,
4864,
-5331,
-4150,
2883,
3070,
-443,
-1230,
-2274,
-2826,
2012,
2326,
380,
4841,
5471,
7721,
1061,
5491,
7154,
-709,
-3553,
-5396,
-1172,
4424,
4758,
-7795,
-4036,
2558,
-356,
3425,
6890,
-4541,
-270,
847,
3108,
-1338,
2754,
168,
-2841,
4543,
3327,
2221,
-8101,
3442,
2539,
1725,
-3360,
5267,
5474,
998,
511,
-7966,
8150,
-397,
623,
1185,
9159,
5647,
-6628,
-4141,
788,
-6406,
3615,
5290,
-1698,
646,
2533,
249,
-1183,
211,
2289,
-2160,
-2607,
-1928,
4431,
-2096,
6304,
7700,
-3452,
-1401,
607,
4121,
-2043,
7066,
-4796,
-6620,
-2023,
-684,
2132,
5506,
-5186,
4217,
709,
-5354,
6634,
3893,
-4184,
-1963,
3507,
4364,
9187,
-5997,
7321,
4023,
3946,
851,
-4439,
3312,
-419,
-2595,
-1609,
3753,
927,
565,
-5481,
-1656,
-232,
-4536,
-1241,
1481,
4821,
5978,
2509,
1298,
-289,
-3871,
2490,
3160,
-3224,
2157,
-563,
-1506,
-4716,
8034,
2704,
-2718,
2134,
1806,
-2209,
2356,
4167,
554,
-9523,
4185,
5560,
6151,
8178,
6366,
3621,
-4596,
2880,
-7335,
586,
-4520,
-9955,
-3009,
-4108,
-9335,
4866,
-1050,
-61,
-9477,
-450,
-1369,
-3116,
-1066,
2652,
1115,
-4087,
-1580,
672,
9072,
-2763,
-2724,
-7373,
3516,
6918,
-471,
-2270,
-7431,
5516,
-5746,
1577,
-652,
-3441,
7943,
6018,
-862,
4057,
3709,
-1795,
1686,
-2738,
-4484,
-1074,
3409,
-3213,
1096,
-5026,
-2879,
3640,
870,
-7161,
-4778,
10067,
951,
6332,
-6880,
-2050,
-2389,
6976,
-5423,
4,
0,
461,
8949,
-5711,
2529,
-2791,
585,
6049,
-11322,
-7728,
-1063,
2724,
2045,
1359,
8576,
2591,
3403,
-4766,
-3023,
-14315,
6552,
-3433,
-316,
7247,
1080,
1211,
1998,
-3374,
-875,
-6734,
-10458,
-6820,
3186,
-12055,
-2350,
-8751,
5904,
825,
5617,
-2175,
12601,
6590,
3357,
118,
-6246,
2018,
-5877,
-8384,
-7448,
4458,
-1213,
-2185,
6165,
7355,
10251,
3053,
2703,
-2946,
-10420,
-10640,
-5509,
8131,
-14391,
-3209,
13629,
4665,
3415,
1432,
-3414,
-13901,
8834,
4058,
8465,
-6042,
-4417,
-9400,
2175,
-1501,
1957,
-5275,
-4438,
-3569,
-943,
-4781,
7815,
-4130,
4654,
-5339,
12161,
4168,
9053,
-9305,
11172,
-4981,
1355,
-15589,
13263,
-14168,
5547,
916,
-5741,
6950,
500,
-2666,
2747,
-1031,
3774,
1051,
507,
2645,
-14959,
-3599,
-18053,
7194,
-5432,
-4473,
14313,
3168,
-6543,
11581,
-2903,
-2037,
1630,
-6612,
-4722,
930,
-106,
-7451,
-7186,
2074,
14204,
-3686,
-386,
5489,
7676,
1047,
-3568,
98,
-13046,
11549,
6441,
-5858,
1213,
3633,
-757,
4383,
5419,
-12058,
-5742,
-3986,
2860,
-842,
2950,
-823,
8637,
2286,
2778,
4457,
5428,
-6309,
8002,
-3840,
6606,
-2876,
2131,
-11245,
909,
1249,
4308,
-5646,
5234,
13927,
-2391,
5761,
4012,
5049,
8894,
-1934,
1396,
9519,
11595,
10112,
-32,
6927,
6901,
-693,
1686,
-969,
-7959,
3457,
-3685,
-3864,
-10966,
5016,
763,
-6319,
9731,
14548,
4747,
-306,
-5594,
-6656,
3320,
-2272,
12692,
-7837,
11894,
-4748,
1965,
-987,
4636,
8925,
11779,
-10086,
10404,
3788,
4494,
12156,
4730,
8618,
-2108,
4609,
3774,
-3797,
16569,
-5545,
2255,
7643,
4002,
-6982,
-2412,
1356,
-1061,
-8547,
9133,
-2625,
1369,
-5204,
12211,
1663,
4321,
1317,
-6988,
-12211,
8306,
-15091,
7079,
2480,
1260,
12143,
143,
7751,
10094,
-1488,
-1512,
-3087,
-6824,
879,
4238,
4004,
4194,
-630,
5449,
6603,
-9140,
587,
2900,
2615,
-238,
-721,
7100,
-147,
4861,
3376,
1870,
6300,
-11889,
4174,
3238,
4249,
-6374,
3017,
36,
-16075,
-6471,
2812,
5617,
629,
-5381,
5132,
9250,
1402,
1540,
-10366,
-1019,
4215,
2273,
-4880,
-1506,
-9064,
1063,
10847,
-10819,
-4207,
-7304,
646,
1745,
-11354,
2768,
-8735,
-5516,
3512,
336,
-3833,
4522,
-4609,
838,
-14977,
1709,
3068,
3259,
1221,
4739,
-3945,
1159,
-6383,
8366,
-1762,
3043,
7229,
-552,
-1227,
2214,
12639,
1505,
9733,
5833,
-94,
-1654,
4390,
5216,
2454,
-6032,
5031,
-5154,
-7790,
12105,
3547,
3389,
16180,
2606,
1921,
10306,
-2012,
-12061,
-2608,
1501,
-3081,
6124,
-9537,
1052,
2895,
-1212,
-8106,
-5280,
-4824,
-9252,
5813,
9278,
1045,
9688,
-15543,
4186,
-3799,
4687,
4608,
3515,
-3884,
2470,
7149,
-8219,
-1502,
-3738,
-9736,
11068,
937,
1341,
-3861,
11252,
3021,
4323,
-4272,
-5230,
1341,
3278,
6317,
10889,
257,
-2543,
6712,
-11377,
-13075,
3743,
-5432,
10481,
-5049,
1346,
331,
-3787,
-1718,
-4298,
2332,
-4954,
9181,
-1000,
-3209,
7157,
-4283,
7754,
-11009,
3875,
-11906,
9993,
-8937,
-11168,
-4112,
-4498,
3983,
-4305,
14,
8772,
-3173,
637,
880,
-4985,
-4947,
8128,
665,
13107,
-2379,
18620,
2751,
2205,
-6675,
2804,
8071,
-7491,
18417,
2517,
3888,
1425,
-3668,
2604,
-2658,
3401,
-3538,
-1220,
6176,
9863,
1480,
-3553,
-3079,
4734,
-14841,
-8638,
3268,
5044,
-1776,
3126,
1036,
3432,
-3292,
1379,
1037,
-5562,
-6013,
-3530,
418,
3468,
-924,
902,
-7106,
3077,
-5930,
-11652,
-510,
-351,
1638,
-8106,
10532,
-682,
-970,
3677,
-4008,
8192,
-6117,
-7570,
4192,
4484,
-3603,
10253,
-2103,
-1547,
-11672,
-2585,
3653,
5866,
-3762,
8099,
-8102,
-11253,
-11753,
7634,
-3583,
-720,
6135,
15547,
4448,
5985,
3491,
-3294,
-8392,
-77,
3852,
4233,
-2058,
-5534,
-1591,
-1456,
-11083,
629,
-4304,
7193,
-7251,
-3687,
12130,
-8094,
-389,
1070,
-6789,
710,
2913,
3739,
-4642,
-9384,
-4390,
-14442,
6308,
2877,
7698,
5984,
2903,
-12519,
-2590,
-9003,
-435,
3212,
4923,
-1351,
-9327,
-5693,
-3487,
5207,
-8754,
-3369,
4043,
14302,
2350,
-12954,
-3429,
-2786,
-2410,
15369,
2709,
3642,
3418,
-8534,
7353,
-6709,
-8545,
-1967,
-3696,
11259,
-116,
5454,
12762,
1353,
-3277,
900,
-1045,
-3229,
6872,
3878,
-8371,
-447,
-6132,
-4286,
-10661,
-7071,
4668,
21245,
3571,
-1699,
3257,
-1380,
-9914,
303,
16347,
1554,
-2256,
2664,
5023,
-313,
-803,
-4597,
1935,
4783,
5152,
-1078,
3512,
13234,
6817,
976,
7624,
709,
13709,
-7123,
5132,
-4113,
-9377,
-1960,
4243,
-1132,
-141,
-9723,
-9924,
-1561,
-2718,
1336,
-1790,
-6935,
-8535,
530,
-10318,
-2928,
14129,
4561,
2474,
6645,
-12458,
-16534,
-4134,
-4553,
-6459,
-8361,
-1611,
-4338,
-4123,
-2220,
-2924,
-3025,
12423,
-1674,
-3500,
4149,
4580,
-5188,
7493,
-6460,
-16379,
9159,
256,
-6215,
4535,
-1256,
-8088,
3128,
4252,
3173,
-2511,
6089,
1898,
-4764,
1810,
5270,
-5732,
-257,
3736,
-2919,
-6830,
3990,
1452,
347,
4125,
10142,
-10684,
-6725,
-6344,
-1362,
-6812,
415,
232,
-6658,
-7052,
-14118,
8559,
293,
-9051,
-4795,
402,
-10201,
-11199,
5638,
-6222,
3364,
-10725,
-9149,
8337,
4145,
12203,
152,
-2350,
3106,
3526,
-4498,
7445,
2690,
2831,
-14922,
5257,
3868,
-4280,
4324,
2708,
-6366,
982,
4311,
-4084,
3857,
6178,
-11741,
7025,
5160,
1310,
10796,
6263,
-12963,
-7626,
6775,
14998,
-6300,
134,
3281,
-5078,
4975,
-1937,
-5445,
-4817,
6508,
-11443,
-4532,
-77,
11242,
-11075,
4695,
10840,
1966,
1869,
-12496,
-3181,
3242,
-20030,
-5488,
-3865,
-7704,
-11005,
3816,
8103,
3320,
-2017,
-7176,
-1723,
-4271,
-10268,
-1568,
-14546,
-9034,
-12455,
-718,
11564,
-4249,
1214,
7952,
5391,
-1200,
4004,
-5072,
8877,
4888,
5065,
-2674,
9347,
3176,
6688,
-7276,
1267,
-3549,
1474,
-3580,
6137,
9014,
916,
7579,
-4021,
-3016,
-2334,
-1759,
4747,
-5543,
6612,
-4793,
-1281,
1189,
4976,
4353,
-2737,
-1655,
9431,
-5567,
17561,
8282,
1143,
-9746,
2883,
-11794,
-2732,
7124,
-5106,
-6518,
17367,
4210,
1070,
-4066,
-9745,
176,
6241,
4697,
6861,
-13433,
4008,
-1434,
2936,
-2326,
-3871,
-586,
6772,
-1771,
-6492,
883,
-20052,
-368,
10378,
7964,
4140,
10177,
1799,
361,
-7068,
1613,
-4275,
-1417,
6032,
2750,
4835,
10360,
1043,
5668,
-6585,
-658,
-4501,
6115,
3973,
-193,
-3836,
1444,
9120,
-10752,
-5991,
-8748,
23,
12729,
-4563,
-3950,
-9743,
-5872,
11322,
-1996,
-2763,
10226,
-696,
-3757,
6981,
-2948,
857,
-9735,
-9205,
-2537,
-4091,
2497,
-1856,
4590,
-4711,
-1755,
2942,
-9187,
10964,
-699,
16004,
18138,
6687,
-10427,
-11218,
10310,
1737,
5939,
2497,
2604,
2551,
-4621,
-5809,
9234,
5534,
3484,
-3423,
16579,
-7067,
-5281,
-13849,
5454,
7870,
-6497,
2234,
6466,
6039,
-9383,
-6662,
-2021,
2376,
7032,
6542,
1708,
6047,
6040,
9608,
-6523,
-4979,
5946,
-12416,
-3586,
-13507,
-235,
-5822,
2568,
-4277,
554,
855,
-6591,
-9505,
1118,
-8065,
3128,
-9453,
-6677,
-114,
-3272,
4510,
-1837,
3106,
5132,
-4947,
-2214,
182,
-5838,
147,
-4708,
575,
6336,
8258,
-9094,
-5383,
-162,
20153,
228,
11463,
-7427,
11422,
424,
-15953,
-10154,
-1366,
5118,
-6818,
6080,
-7352,
-4333,
-3994,
1844,
7008,
-6196,
-918,
3549,
-7235,
-2898,
-12883,
3017,
-7130,
8775,
-6478,
-2064,
5785,
12411,
359,
4119,
278,
4554,
-318,
-12668,
649,
-13135,
-4951,
-6792,
-1405,
-2235,
13678,
10336,
558,
-11408,
4127,
-9339,
-8340,
-3995,
3601,
-13183,
-12907,
8676,
568,
2643,
-4196,
1284,
929,
-7467,
-2571,
-5108,
-9264,
3369,
555,
-1084,
2494,
6396,
-8330,
-7709,
-7460,
5846,
1840,
2651,
2636,
8988,
-3541,
-1571,
1289,
-10087,
4299,
-4249,
-4788,
6002,
-330,
-8179,
-300,
13169,
6149,
-4620,
-1885,
2,
-3023,
1852,
1409,
2782,
5767,
3849,
5153,
-4058,
10408,
4409,
10288,
1391,
-5972,
-7832,
-4502,
-697,
-4701,
-2640,
-3116,
1956,
2874,
-468,
8496,
-1996,
-2006,
775,
2663,
-1096,
6781,
-7872,
-2188,
-5022,
-5149,
4005,
5132,
-10695,
-232,
6881,
6045,
6651,
10314,
-2842,
-4684,
2003,
1864,
3814,
-5282,
4511,
-1795,
1889,
6878,
527,
4733,
-5860,
744,
-1491,
-7608,
-4094,
1344,
-242,
-4919,
7330,
1564,
382,
1772,
-549,
6070,
3752,
-1725,
2461,
5202,
1740,
-3636,
3490,
-3123,
-680,
448,
-9670,
-2909,
6702,
-8949,
2978,
-2368,
-3005,
-425,
10239,
-3047,
8388,
2854,
706,
1517,
1938,
-6884,
8999,
-3941,
-8244,
-1627,
383,
-5504,
430,
29,
6433,
-12144,
752,
-12075,
6442,
-2590,
-2525,
839,
-4899,
-345,
-3495,
-1985,
-6982,
737,
-6765,
-3705,
5812,
-446,
-14724,
-7998,
-2756,
-1642,
-1483,
-4823,
-3116,
-4099,
-897,
-11046,
-514,
483,
-1920,
-6604,
6902,
1197,
4818,
-2755,
2595,
12395,
1524,
4255,
10016,
-4858,
-5080,
-1336,
-4468,
3644,
1413,
2749,
-3923,
3380,
-2649,
-275,
-1753,
-1943,
4739,
-4136,
8919,
-2933,
-1171,
3770,
-3660,
1217,
1726,
-4643,
-9074,
-7197,
2255,
495,
-7978,
-4048,
560,
-8084,
7890,
5839,
6202,
5995,
-1786,
5173,
-6393,
8773,
-1982,
7438,
-4030,
1826,
7689,
366,
-4171,
-3092,
3321,
11302,
-5036,
-623,
-3695,
1479,
-7909,
-3245,
1240,
407,
1964,
-234,
4689,
3636,
2610,
2371,
11865,
2671,
-1402,
-4412,
4385,
6124,
2758,
-823,
-490,
6452,
1641,
4540,
646,
79,
7181,
-5488,
-2279,
794,
-6770,
2312,
3758,
1621,
4537,
-558,
1833,
-9524,
5957,
497,
1911,
5708,
-3248,
2011,
-4441,
-11181,
5726,
-1988,
3095,
762,
4401,
-2013,
-2534,
-13816,
3484,
-310,
3106,
83,
1739,
-4230,
-1995,
1541,
-7368,
-4619,
-3980,
-742,
-2893,
1142,
-7847,
8041,
2124,
-847,
2849,
2763,
1390,
1144,
7074,
5710,
3684,
-5282,
-4215,
-1154,
-4489,
7309,
10880,
-3219,
-4160,
2405,
2166,
5407,
-2507,
3346,
-2359,
3059,
1805,
634,
-4712,
-7269,
-8704,
1089,
42,
2700,
3118,
670,
1106,
9507,
-595,
-1880,
7645,
-4948,
-5105,
-3567,
885,
-911,
2788,
-3650,
-2940,
8789,
-3046,
4589,
-376,
2701,
8493,
-1171,
-1214,
-2458,
211,
-1697,
-702,
-845,
-2865,
-6924,
9844,
-1912,
-2176,
-1247,
-293,
-9610,
-13865,
-5674,
-607,
1421,
-4345,
4281,
2711,
-3552,
-2748,
-791,
6395,
-891,
-2876,
-1872,
2312,
213,
1340,
-698,
850,
-2962,
7919,
7097,
-3247,
1688,
1198,
-891,
-1708,
-5242,
1412,
3993,
124,
3811,
926,
364,
-2019,
-4904,
-2343,
4318,
-240,
-6074,
-1999,
6435,
-2749,
-1367,
2641,
-103,
3231,
-2993,
-791,
1830,
2243,
3115,
1383,
923,
-8651,
-2096,
327,
-1300,
4856,
-3212,
3483,
1241,
-10863,
-2181,
2076,
-1985,
5512,
-3172,
-4151,
-928,
5792,
1423,
2522,
-4193,
-407,
4550,
3637,
761,
-1451,
9125,
-1159,
-8072,
-1223,
-3965,
7965,
-1260,
-2047,
-1873,
269,
-3004,
-2403,
-4720,
-1892,
-3357,
6791,
350,
-3234,
-1403,
835,
8957,
-5166,
8084,
-6310,
-2526,
-5037,
1644,
-4922,
4744,
-3124,
663,
1759,
8262,
4384,
5285,
4322,
-807,
11401,
3324,
-2001,
-1343,
-8764,
3815,
548,
3748,
-5233,
2946,
956,
3463,
-5318,
4416,
5992,
1496,
10525,
6382,
-2135,
989,
85,
-2158,
3503,
-223,
-278,
4440,
6353,
2041,
-4137,
-4868,
-1133,
-5084,
-960,
-269,
11366,
-3510,
-3162,
2449,
-1454,
743,
3027,
1395,
-2465,
-1358,
-3672,
-1491,
2477,
-10090,
-2165,
4854,
3585,
-4751,
3490,
8197,
4701,
6292,
5437,
954,
2473,
-5595,
335,
-8794,
1314,
5836,
1580,
-5603,
-1238,
-5180,
-6463,
-2348,
8506,
-3450,
-5835,
-1256,
-1156,
1474,
-3597,
8754,
-2070,
-6173,
-1718,
4204,
7905,
6426,
-1432,
-1568,
5963,
-2039,
2441,
-11763,
-4123,
-1146,
-5768,
-4488,
4240,
-5533,
1634,
8655,
9091,
-3442,
5611,
5056,
981,
-1134,
4892,
4692,
6243,
638,
-4435,
3959,
-6674,
-644,
5137,
-7483,
-387,
-1559,
-5322,
-8010,
-5964,
-863,
7930,
2560,
4808,
1113,
1676,
2979,
7892,
2971,
-601,
4180,
-2572,
-68,
-1749,
6994,
6780,
-2094,
4562,
-1421,
-9132,
3003,
2199,
10207,
-517,
356,
-2899,
-5537,
1729,
-10146,
3185,
2902,
-3746,
-7677,
5396,
2145,
442,
1816,
328,
9553,
4206,
2814,
73,
494,
497,
-485,
-4556,
468,
7610,
-636,
-10972,
-799,
623,
-7837,
1919,
-247,
-4571,
-6164,
6717,
-2943,
4554,
7653,
8277,
-3190,
-7308,
-2198,
4955,
763,
-3651,
-12038,
-388,
-1996,
2021,
-193,
1888,
-331,
3954,
-8531,
2692,
-3568,
3661,
1882,
-1178,
-4057,
2754,
-1725,
-5660,
1961,
-6409,
5936,
-6520,
2003,
-6186,
-2501,
1673,
-4889,
3655,
5092,
2928,
-6854,
342,
-2920,
-5118,
-257,
6203,
-2146,
-5202,
8406,
9337,
-27,
-7714,
4103,
-10530,
-6300,
2721,
-1504,
4734,
-782,
-8728,
2450,
823,
-7681,
-5212,
5168,
2299,
-795,
-1003,
9246,
7197,
-413,
5096,
-2741,
2947,
3228,
686,
-3072,
-7885,
-2195,
1629,
7327,
-3096,
-2650,
-5024,
-3622,
6867,
3822,
290,
7355,
4536,
-6952,
-3334,
5087,
538,
-2084,
4212,
992,
-3358,
3005,
-8018,
111,
-4772,
-3963,
2009,
2739,
4609,
-2221,
-3280,
-4066,
-22,
2219,
6153,
1802,
-5053,
808,
-5514,
671,
4379,
8525,
1151,
1029,
-1005,
10259,
-3709,
-1645,
-3826,
84,
3447,
-2444,
5341,
2715,
-5267,
-737,
7441,
2934,
4489,
-1807,
-532,
-8517,
3462,
-1450,
-6175,
-677,
-1010,
2564,
-361,
-4906,
-98,
5860,
2351,
-8223,
1162,
519,
4465,
-3856,
2520,
2423,
-1429,
-636,
5867,
1012,
-3044,
-3343,
3314,
-9552,
4797,
14321,
3514,
-5901,
1692,
-1954,
-2433,
7152,
-206,
9018,
-55,
-5663,
-171,
-2338,
-8055,
2486,
4762,
6154,
1769,
-1790,
-2081,
-9602,
-4108,
5271,
3952,
-4595,
521,
-1508,
7270,
-1444,
-683,
-3845,
-758,
3747,
-2371,
-4905,
1052,
-376,
-1386,
-1796,
-5675,
-10136,
-3766,
4702,
5369,
-3777,
-3360,
-9169,
-1094,
-21,
-5642,
-7618,
-1852,
78,
3710,
-3006,
-6496,
-3484,
4717,
1929,
-2588,
6441,
5041,
-769,
3839,
-2743,
3418,
4595,
2438,
-4162,
-145,
-628,
2907,
7889,
-5003,
-8433,
3065,
-2902,
-7804,
-2101,
2370,
455,
-5980,
1689,
-974,
-7518,
2922,
-2467,
7278,
-1877,
-1906,
-5218,
-869,
3751,
412,
4495,
-4251,
3930,
5346,
-1967,
4768,
-1798,
-160,
1168,
-5717,
7877,
-6156,
-1173,
-4965,
762,
10164,
2766,
-10555,
5293,
-3923,
1050,
296,
1155,
-1861,
-7455,
-2339,
-9523,
1235,
-8962,
1319,
4764,
-98,
250,
-4531,
2131,
2350,
2756,
912,
6384,
-1451,
3822,
-2552,
3255,
1304,
-1942,
6382,
-8030,
-949,
-5379,
8796,
2245,
1997,
3453,
7572,
9976,
3538,
-3984,
-4075,
-6754,
4376,
2035,
248,
2766,
822,
-5470,
-5874,
-2968,
-3672,
1075,
-3770,
877,
3798,
-6131,
6130,
-1495,
3671,
-318,
-6414,
10240,
-2926,
7453,
5310,
330,
4357,
-1432,
4539,
-865,
1670,
2088,
-1107,
-774,
-2442,
257,
3944,
-101,
-1842,
-5544,
-264,
-2395,
1462,
952,
209,
3715,
-979,
-424,
1817,
-1188,
-4550,
817,
-11338,
3930,
1484,
-807,
-259,
-146,
-935,
2877,
2418,
-1264,
6338,
-4514,
1036,
-5665,
-2896,
697,
453,
-6723,
2269,
9244,
-2757,
8788,
5859,
4584,
3774,
-4042,
-4739,
-1008,
-1471,
3070,
-1808,
-2788,
-3294,
-861,
-4438,
-6222,
-1712,
1720,
-5937,
1580,
3195,
-4468,
-5130,
3784,
-4204,
2597,
2082,
7036,
-12274,
1418,
-2372,
-3347,
-5241,
-1633,
10953,
7787,
2079,
-1054,
1936,
-2655,
1587,
2324,
2491,
1609,
8388,
-1203,
-3614,
-5747,
-4844,
1351,
-538,
3631,
7792,
4176,
7756,
-7298,
2197,
-4522,
7090,
-103,
5681,
4371,
-269,
482,
-3930,
-265,
-5843,
4,
0,
461,
2030,
564,
1225,
9870,
-6148,
-3816,
-1667,
5495,
-687,
-5592,
-9666,
4543,
8319,
1201,
12411,
-4106,
11920,
-2135,
4591,
-1708,
-3601,
-1781,
-1128,
-279,
1781,
-4361,
4419,
1342,
410,
972,
-3862,
-6328,
-1829,
5589,
-9998,
-6751,
-12506,
-6189,
1963,
-254,
10981,
-4682,
-9540,
7893,
-2619,
5756,
1558,
399,
-2347,
-9140,
-3680,
4832,
-5701,
-3815,
5526,
14675,
5891,
610,
11107,
-157,
737,
9189,
9085,
11296,
3177,
5204,
-3439,
3047,
-4157,
-3217,
10809,
1159,
-297,
-11154,
12552,
-19481,
-444,
-13346,
-1790,
-6778,
-5884,
-3966,
6586,
4981,
3333,
-13611,
-1734,
190,
-10176,
1444,
5611,
-11652,
39,
293,
2847,
-2641,
1929,
1062,
16104,
-6427,
16988,
-6584,
2861,
3546,
-4381,
-7122,
8864,
-6718,
2408,
2497,
5069,
2879,
-5406,
16907,
-6595,
-3185,
-5073,
5023,
-11778,
-3770,
7994,
-7626,
-5689,
-8448,
10,
1758,
-2348,
-6883,
1577,
9439,
-9046,
-3683,
-6013,
13,
-8058,
-1585,
3726,
253,
6693,
4930,
195,
-5401,
2427,
5405,
-5773,
14963,
6767,
2793,
7449,
3162,
4338,
1217,
-4944,
-12798,
-3630,
-4373,
8659,
3699,
10914,
-10657,
3689,
7839,
-6069,
4958,
4052,
7685,
-1822,
-6455,
-3117,
3161,
2408,
-458,
-1533,
4554,
-6847,
941,
6940,
-5057,
11077,
5152,
6962,
-6214,
-8953,
-101,
-4042,
13156,
-2423,
1077,
-5328,
-4844,
-5492,
-5398,
7697,
-1227,
-1456,
4049,
3112,
4634,
-15745,
5187,
5227,
-3491,
-10345,
12517,
2569,
7189,
4682,
-3169,
-1651,
1698,
2470,
6248,
3678,
3209,
4601,
9826,
-181,
-631,
-2072,
1106,
5550,
-2225,
-8171,
-1729,
-7180,
-6349,
3807,
4673,
16048,
2410,
6372,
8077,
-3953,
-5622,
-4063,
-5106,
-459,
8859,
6167,
9203,
-877,
3982,
8519,
-4626,
-1406,
-662,
-2155,
905,
-6214,
7609,
-2200,
3852,
6329,
-11022,
-11351,
6662,
3679,
-3870,
391,
-8763,
1533,
-5828,
-2420,
-2835,
6648,
-6358,
1230,
7466,
7508,
527,
-5168,
-1394,
-2833,
1336,
4686,
2132,
9359,
-8740,
-352,
7547,
1453,
5601,
-3421,
-8314,
-1892,
5560,
-2907,
4644,
-10783,
8189,
-973,
176,
-7973,
1688,
1426,
3380,
-4044,
-3023,
-14638,
2107,
8663,
-5235,
-10299,
-1120,
-4257,
-10020,
2768,
-1586,
-5733,
3093,
5217,
-1332,
-10269,
-5156,
2928,
7749,
-8900,
-19414,
8424,
8458,
68,
11183,
-8378,
-1768,
11323,
4834,
-7399,
-3745,
10520,
-3709,
2554,
468,
1688,
4306,
-2891,
-7847,
6886,
851,
-4196,
-3690,
-7796,
5767,
10342,
2363,
8053,
-5232,
-1314,
2458,
14210,
1999,
9872,
-4752,
-12974,
-3792,
1038,
5396,
-5074,
6496,
-15839,
-1736,
-9019,
2169,
-8944,
-2953,
-3757,
4690,
13974,
-7265,
-2487,
2112,
13,
-7412,
-2300,
-8381,
4139,
-7350,
-5229,
-2608,
16359,
7898,
-1013,
-16,
-5506,
-11495,
-6514,
-8307,
-5273,
-8823,
-4359,
-1886,
-10314,
5433,
-1590,
-7092,
16791,
-7392,
5609,
-15538,
2179,
2948,
-4492,
-11097,
10210,
3346,
-5213,
-7280,
12323,
398,
-6818,
-3749,
-5374,
4708,
1955,
-17200,
-2458,
-201,
-7884,
14248,
8655,
871,
-3003,
-8529,
-1886,
3439,
7098,
-3353,
-4251,
-226,
6062,
11272,
-7102,
2509,
2427,
-3122,
-4565,
6980,
-3388,
827,
-5008,
1818,
2500,
9669,
95,
6633,
7717,
-9746,
6596,
1853,
2521,
-6154,
-1169,
-5964,
12101,
-3270,
-120,
764,
-4792,
-6937,
-2157,
3605,
-5698,
1415,
-5812,
-2851,
452,
10250,
8826,
-1512,
2599,
6702,
-258,
12178,
-3962,
-17397,
1727,
5561,
-4933,
-11858,
-282,
-8897,
2316,
-16113,
3438,
3074,
7618,
2704,
3960,
10465,
149,
-692,
591,
3720,
1842,
-5246,
-11153,
-1512,
-1012,
8443,
4945,
-8000,
9361,
-11614,
-5997,
-7153,
-12118,
-3573,
-2584,
-13699,
-8640,
7053,
-5206,
387,
3136,
5311,
-14814,
-998,
17735,
-6417,
-13932,
-7592,
-1963,
-10238,
-8836,
-2966,
1323,
9926,
-6651,
-8149,
18052,
1258,
1450,
-5259,
9472,
2153,
8596,
-5906,
-8511,
-6616,
7936,
1003,
1072,
8328,
9964,
-248,
-5399,
2122,
-3622,
10701,
-2603,
-4173,
4530,
-1801,
-5268,
-7990,
9513,
8667,
-5977,
10829,
5584,
-5192,
-7486,
-9151,
-7592,
802,
-1529,
-7591,
-14077,
-13397,
-14033,
-16538,
1193,
-5206,
-4618,
-7511,
6248,
-4653,
566,
-3583,
-4845,
-3238,
5152,
1189,
5465,
140,
-9974,
1262,
-6219,
-7982,
-7124,
4626,
524,
-2117,
-1960,
76,
-5565,
-7007,
-1196,
1276,
1265,
-2916,
-12511,
-1245,
-9189,
-11617,
7595,
2786,
4618,
3402,
-6742,
10027,
-10411,
-5560,
-2447,
-3624,
-5628,
2863,
9250,
5124,
-5871,
5213,
8053,
-3838,
5078,
-2721,
4178,
-12355,
-9191,
-9846,
-9169,
5531,
-4881,
-1189,
8064,
1165,
-1779,
15318,
6842,
-3837,
-4781,
9194,
3384,
8920,
6416,
-6280,
-3366,
3312,
2546,
7342,
-13761,
2815,
-439,
923,
-4811,
13047,
6225,
-2321,
-423,
485,
11682,
6370,
-2060,
2996,
-10924,
8963,
-12285,
5928,
2794,
-3958,
10923,
-5006,
-4484,
-920,
-6207,
-2036,
-441,
-7593,
6293,
-740,
4988,
3964,
-14939,
-2706,
10238,
-5158,
6010,
-3993,
9625,
9301,
2329,
8704,
4373,
768,
-10602,
-10710,
-8726,
-544,
-1286,
-1530,
-6616,
-3734,
-2208,
-1134,
-5512,
1543,
11602,
-550,
-8806,
1947,
-4030,
-1150,
-1549,
7096,
7100,
-4787,
662,
3169,
3381,
1193,
-4578,
-109,
-22680,
-13245,
267,
11296,
12223,
-7167,
-851,
1172,
-3804,
-1673,
-416,
3332,
-5352,
-8310,
-2653,
577,
-10833,
-815,
3617,
-2109,
-12951,
60,
5855,
3381,
-3221,
8590,
-5352,
1304,
-11718,
802,
-583,
-6268,
4239,
-1851,
8893,
1632,
-1255,
-12893,
4041,
-2368,
-11595,
1332,
-10637,
-2632,
3421,
-8557,
7529,
-5760,
-860,
596,
2000,
-12000,
-4962,
7572,
3449,
-4259,
4247,
6126,
-2673,
5928,
12347,
-1232,
7362,
-1299,
484,
8866,
22293,
16795,
-19301,
335,
1873,
8569,
1334,
-4034,
-2872,
8352,
-4179,
2279,
-10,
82,
5192,
6391,
-2474,
-16219,
3517,
-3024,
10461,
6535,
-8840,
-4395,
-6502,
4303,
-219,
859,
-21464,
-11246,
-7426,
-2563,
4488,
-1165,
-3682,
-424,
3184,
4574,
11234,
-4426,
-1404,
4442,
-2386,
-9352,
-10734,
-6374,
-5733,
-3324,
4045,
-4339,
-2806,
9741,
-5288,
2601,
-4162,
-6990,
5527,
11973,
-4188,
-5618,
2338,
-5689,
12175,
-1506,
-4378,
4207,
7325,
3187,
-6367,
3959,
254,
5404,
-11040,
-1299,
8022,
-14968,
-2529,
-3133,
-11449,
10046,
2002,
1752,
-9530,
5081,
6043,
-1370,
274,
-394,
1245,
-177,
-1610,
11589,
463,
4077,
6592,
-61,
5969,
3656,
5329,
2530,
4985,
-7036,
-6140,
-5787,
-369,
-6774,
7129,
-14206,
-5170,
-414,
-3744,
-7229,
9824,
8325,
2776,
617,
-1385,
-9855,
1032,
-2014,
1310,
3063,
-724,
955,
-9343,
8973,
-4756,
-888,
-1950,
-6611,
-54,
11474,
7675,
-3524,
5078,
6172,
953,
-4579,
-2776,
-223,
-2558,
4670,
-11644,
8456,
1035,
7887,
-7058,
9525,
3583,
-3366,
-7859,
10109,
1008,
-500,
4634,
-12042,
549,
2661,
-3809,
14475,
17782,
1938,
-3280,
5684,
-1368,
-292,
-3732,
-710,
5722,
5325,
1770,
-1099,
-3872,
-1347,
4448,
10356,
5502,
5194,
6793,
-3890,
-2282,
-6835,
-2295,
3334,
-9786,
907,
-8373,
-2533,
-7785,
-6462,
-2502,
2269,
4623,
-2783,
-3004,
-3511,
3616,
-6159,
-4108,
-11960,
-1449,
-3008,
-5800,
-3372,
-6305,
20223,
8532,
-1895,
-5711,
4262,
4267,
4987,
3912,
9145,
-1508,
-4421,
4111,
8438,
-6752,
7176,
-4534,
-14259,
3389,
-1783,
-2314,
9289,
3821,
10684,
3699,
7029,
-8188,
10918,
-11386,
4547,
-7278,
-4502,
-16500,
10442,
416,
-3680,
-5356,
1623,
1024,
-6112,
-1725,
289,
2749,
-3146,
-4971,
5816,
-1463,
-8155,
-1719,
-4888,
-2918,
4302,
1818,
9825,
-4686,
9394,
1507,
15459,
6606,
1118,
-16062,
-8663,
650,
6819,
7269,
8896,
1779,
-12279,
-5456,
-988,
-9295,
9516,
-1801,
667,
9549,
-1302,
7187,
1436,
-4173,
1016,
-914,
-1688,
8022,
-7089,
2073,
18,
10321,
13008,
-6092,
1739,
3,
-1374,
4821,
-1828,
-3665,
1239,
1585,
-5209,
-6369,
-1538,
9348,
-624,
-836,
-5793,
1391,
-3530,
-306,
-3133,
-5593,
-4305,
-6871,
-3307,
-3637,
685,
-3905,
816,
1496,
874,
4025,
9508,
3411,
3438,
-3782,
-8872,
3205,
-410,
-3001,
5199,
929,
2767,
5472,
7343,
-2350,
2004,
-3587,
-5331,
2281,
-4764,
1992,
-1603,
-4487,
1830,
-4899,
-2092,
-2567,
-5535,
-3840,
1539,
-1970,
1612,
-5167,
1875,
6045,
-3802,
2463,
-3715,
-2874,
-4462,
-657,
-5066,
12466,
956,
-538,
4249,
1236,
-3937,
3637,
1323,
8453,
1086,
-1072,
-4954,
2461,
2614,
-6219,
2761,
-1780,
-2807,
7274,
-12646,
-1588,
-4405,
2236,
2639,
9024,
2390,
4537,
-5861,
2799,
4586,
4671,
8200,
1214,
3145,
5688,
-3572,
8109,
1607,
1311,
-2700,
-3767,
2799,
-4945,
7348,
-1076,
-2832,
718,
714,
2067,
-1126,
4572,
-12155,
-3178,
-3421,
-4285,
-5459,
2504,
5838,
-2421,
-1629,
-988,
1557,
-1840,
564,
110,
-2871,
-2186,
5487,
-5546,
3257,
2184,
436,
437,
-5865,
986,
-1586,
5568,
-2391,
-13442,
-3220,
-882,
3499,
3631,
-3357,
-9364,
-4329,
1072,
-323,
1185,
-3755,
-3228,
-2035,
620,
2204,
-1076,
-5954,
421,
-3832,
-2581,
-5017,
6828,
2383,
-1189,
-2798,
7888,
-5571,
1352,
7964,
3375,
2283,
-5252,
-1320,
-801,
-3264,
4078,
5840,
3156,
-7106,
1434,
7529,
5601,
3115,
157,
-4135,
3096,
1505,
5784,
2784,
9490,
5844,
-7459,
3404,
-2607,
-441,
3779,
-7447,
196,
8091,
571,
3097,
-9652,
-933,
-2802,
5559,
-5323,
-2885,
5079,
-2153,
-2868,
4355,
5568,
-582,
-1648,
11769,
4192,
6898,
10058,
1611,
4259,
-1365,
156,
-7386,
181,
12314,
-2958,
-4607,
7786,
-6133,
2088,
-6763,
-4432,
-982,
910,
-3707,
4377,
-1208,
-2159,
9236,
1617,
-2705,
-11136,
2727,
4863,
-1415,
904,
-1551,
3988,
4452,
-9035,
-6498,
5634,
-2222,
-731,
-3157,
4196,
2222,
1509,
6150,
-226,
-610,
-7026,
-7331,
-1438,
5795,
923,
655,
-8092,
7980,
5409,
-5255,
1368,
8516,
-6460,
-5131,
2737,
-8221,
-2866,
3475,
2149,
-1483,
5847,
2324,
-4167,
1038,
859,
-1294,
3388,
-6859,
7372,
-5725,
-4917,
-2384,
-1016,
-4229,
-4460,
1471,
-745,
-2866,
3342,
-2426,
-1103,
-6443,
7966,
298,
1866,
3313,
-1298,
-3093,
-2853,
795,
5176,
-3506,
991,
-3373,
8433,
2813,
3427,
904,
595,
-199,
2953,
7670,
3340,
9503,
-800,
-6193,
-980,
10569,
-5231,
-2940,
-207,
-3154,
434,
-623,
61,
-5851,
-3004,
1607,
3782,
-9574,
12899,
2140,
-2441,
867,
-5442,
5307,
4478,
-1820,
-2598,
-6433,
5573,
6804,
4401,
6709,
-3597,
12873,
826,
7172,
930,
-4949,
-6380,
-4553,
166,
7786,
2157,
6180,
6632,
170,
2252,
4724,
-2259,
-6872,
2344,
13962,
1112,
-2356,
2502,
-2457,
-4959,
-6157,
1815,
-2778,
-2612,
-4017,
4022,
1503,
-5092,
545,
-3583,
3661,
-610,
-1777,
1867,
-2038,
-8345,
-8229,
-3338,
785,
-880,
-514,
-3997,
3342,
96,
5738,
-8855,
6609,
1988,
703,
3540,
2212,
-5318,
817,
-2596,
-1367,
-4929,
-3311,
999,
-6467,
-3108,
-3606,
-515,
556,
-1137,
1468,
1942,
-1126,
9799,
-6483,
1693,
-2991,
1965,
6557,
1758,
859,
-1142,
-1456,
-6269,
-1954,
-1183,
-1258,
-4189,
2200,
-7334,
-6161,
-4316,
-82,
-499,
-4739,
2335,
8459,
-2048,
6978,
-3272,
-1891,
589,
3155,
-717,
-1106,
2959,
-4551,
1723,
3137,
5272,
2343,
-6534,
2145,
3645,
3928,
202,
285,
99,
10,
-2531,
-1313,
2908,
1047,
4084,
-145,
5069,
-615,
-1462,
5500,
-2327,
-7054,
4192,
10793,
-1706,
-7171,
-1751,
265,
1408,
4370,
-5114,
-2279,
-2772,
38,
-1666,
6333,
-8643,
6261,
172,
3364,
-2790,
-4461,
-12232,
-2904,
565,
-4839,
-9627,
-5300,
-1705,
-5724,
-1750,
6894,
-10715,
-4291,
9233,
-802,
3046,
-3708,
2070,
-2221,
3737,
-1775,
-495,
1750,
1184,
7087,
-7622,
-6564,
4598,
1307,
7606,
-2861,
-9326,
1897,
-2510,
3921,
-2461,
7879,
4929,
-4198,
-5589,
-124,
-742,
7421,
421,
234,
3046,
773,
4708,
4085,
-3539,
220,
-74,
-5643,
7526,
7285,
-4832,
-542,
4749,
-3649,
6892,
2710,
-6206,
1140,
-3982,
1644,
-1504,
-1113,
79,
4046,
150,
-7369,
-326,
2593,
9290,
-3548,
-2490,
2748,
-303,
-3716,
-2535,
-8702,
3615,
-2051,
-4172,
-675,
7557,
-7830,
-1076,
7943,
-6641,
-1044,
-1823,
-5034,
-4813,
318,
349,
195,
391,
-1719,
7778,
-1751,
3291,
-4214,
6339,
-5165,
1997,
-12,
-6776,
-9827,
8503,
1680,
4478,
1368,
452,
-2452,
2056,
4966,
7717,
1643,
4323,
1390,
-8116,
4337,
1749,
-7582,
-1037,
-706,
-940,
-4045,
6628,
-4744,
6545,
-2208,
3666,
-6916,
-3727,
-2867,
-2517,
2792,
-4224,
-4887,
-912,
-5656,
-2008,
4916,
2649,
-1929,
3320,
-557,
-1372,
-4947,
7623,
5743,
1190,
10292,
-2144,
101,
3393,
-5739,
1498,
2153,
3606,
-8760,
2164,
-2015,
6784,
1014,
-6719,
2327,
24,
437,
4439,
6023,
3115,
3577,
4756,
1975,
3182,
25,
862,
-2278,
-1525,
-5589,
-757,
-68,
-3894,
6419,
-6731,
-6637,
12169,
5197,
432,
-537,
-686,
1624,
6287,
1364,
-810,
3838,
-3638,
4606,
9633,
2813,
-1019,
6672,
-7999,
-5365,
1382,
5559,
-2628,
3293,
9220,
2212,
-6643,
3739,
543,
6933,
-3701,
-1862,
2048,
-4390,
5284,
-3195,
-1402,
1137,
-2907,
-710,
-1562,
4425,
-4986,
-3660,
4771,
9999,
-5010,
-6814,
2000,
-945,
-2653,
-1045,
-5419,
-657,
1816,
5605,
5108,
-2512,
-5949,
-935,
-4877,
695,
1010,
7970,
1335,
3924,
4581,
-2249,
-5381,
1526,
5617,
1508,
2934,
6775,
-5768,
3646,
-151,
-9531,
-2245,
-226,
-5513,
-6941,
2477,
315,
1839,
9327,
6573,
-2036,
-2636,
-2032,
1165,
-5851,
4212,
-1798,
1285,
3641,
3426,
-1195,
-9178,
255,
-277,
-1323,
-1274,
-5258,
-4750,
2733,
-8226,
-3477,
5210,
-169,
3009,
1534,
1569,
-5843,
-2371,
189,
-2882,
-6892,
-3445,
11400,
-188,
-677,
-4421,
-9347,
-3163,
-5912,
11047,
7498,
-5765,
2003,
-6789,
-2454,
-440,
5302,
11104,
895,
1548,
-380,
-5250,
-6735,
255,
11870,
3827,
-3059,
-8319,
7314,
-2249,
2914,
6711,
-2320,
-3094,
-430,
-995,
-904,
6749,
-334,
234,
-2145,
1307,
-2179,
146,
-2926,
810,
2402,
343,
-810,
6672,
-4032,
783,
-464,
2378,
3866,
-637,
-3457,
-9346,
8668,
-2038,
-3357,
3539,
-483,
-725,
2901,
-8292,
2301,
-5958,
6076,
8312,
-904,
-281,
-3651,
-4220,
-284,
6657,
5559,
1423,
3025,
5524,
-2061,
5722,
-2326,
-1044,
-2732,
-3362,
-714,
-5332,
-3464,
-552,
-2211,
1734,
2545,
950,
5102,
822,
-2255,
8239,
2487,
-3707,
4195,
67,
7345,
-9423,
1183,
-2104,
229,
6797,
5707,
-524,
-9252,
-1240,
1578,
5443,
-5381,
5795,
155,
4045,
-1552,
1743,
7255,
1277,
-2730,
1312,
412,
7576,
5330,
1814,
-14523,
1747,
408,
6929,
1471,
-1903,
1776,
344,
-2547,
3201,
-6169,
-3856,
-8425,
5854,
-5183,
1283,
-8108,
2617,
-2240,
-5948,
-6842,
-8513,
-10080,
8052,
-5165,
6015,
-1334,
-8212,
-6070,
2112,
-3882,
3401,
1891,
203,
4069,
2261,
-651,
7071,
-4190,
2509,
2046,
-10829,
-4600,
1721,
-3666,
1105,
-641,
-7153,
-5392,
-898,
-9177,
-5647,
-3419,
-5883,
-2988,
3792,
-1935,
6258,
684,
7015,
-935,
-2385,
35,
1717,
-3576,
-5869,
-6336,
4780,
2747,
5890,
-639,
-6838,
-1495,
-3130,
-11838,
-6701,
-4740,
4362,
-852,
1941,
86,
-1769,
3113,
2040,
1805,
4177,
3298,
-2901,
-2286,
3721,
2160,
-45,
-2033,
-2468,
-1813,
-4526,
-685,
-487,
-1546,
2229,
-7755,
3584,
-3055,
908,
-2787,
-253,
664,
-4886,
8763,
7094,
-3759,
3476,
4449,
7853,
2356,
-7406,
6947,
-1095,
-558,
-624,
-5694,
4368,
3762,
2255,
6530,
-1435,
727,
4169,
-2856,
-202,
1890,
8235,
-635,
-2467,
-5075,
3995,
4,
0,
461,
-1569,
-1577,
1836,
-2594,
-16846,
-648,
6281,
-827,
-1312,
2424,
9720,
-8704,
-2030,
1000,
2430,
13304,
3903,
2963,
-7907,
4038,
7987,
-3659,
385,
-14037,
-9035,
-7832,
174,
5450,
-843,
-7144,
-4430,
5390,
-5879,
1380,
4695,
-6755,
-7185,
6325,
6681,
11682,
4280,
6986,
-4233,
2022,
-7891,
5043,
-807,
7347,
-6102,
2001,
-19871,
-3378,
1625,
1068,
1760,
276,
-5756,
2690,
575,
-6319,
-1422,
8396,
-1532,
-5356,
-4293,
7215,
-1842,
-6420,
-4766,
12785,
-396,
15107,
642,
-6578,
1233,
-2129,
8949,
-2010,
2378,
314,
6135,
4129,
3537,
-2339,
-9956,
5861,
963,
6873,
2139,
-3999,
-5190,
3165,
9268,
14279,
5900,
-7950,
1230,
-2421,
-15413,
4389,
2416,
1281,
-8048,
-7029,
2010,
9742,
-6694,
10968,
7221,
11293,
2075,
1757,
10667,
-453,
3336,
5410,
5046,
7516,
-4785,
1293,
-2875,
-4169,
-10803,
8023,
-4925,
13630,
3259,
7407,
5872,
-6251,
-6039,
6237,
555,
11769,
-238,
2203,
-1723,
1576,
-753,
-918,
4513,
793,
-3436,
-11298,
6517,
-5883,
-673,
-2854,
5286,
1030,
6998,
11167,
-4717,
-1888,
10113,
3755,
6092,
-5911,
-8572,
-3986,
3196,
-8109,
2268,
-4664,
6431,
-14312,
-3935,
-5686,
8614,
-8800,
-5706,
-3041,
7615,
14219,
-132,
12054,
1016,
-2901,
11988,
-274,
-3222,
-3155,
-348,
-4162,
-1446,
6406,
-10313,
-6827,
-11293,
2359,
-211,
2672,
-10041,
486,
4264,
6830,
3563,
-6761,
-8194,
-1055,
-7910,
-2357,
-2939,
5438,
-8174,
6241,
1002,
8402,
-16120,
8935,
5276,
2996,
8556,
-4148,
-10781,
10020,
11233,
-4132,
1391,
-7386,
-8684,
-12723,
-2606,
-13840,
2341,
-13379,
478,
3430,
-3914,
364,
-5257,
5744,
-2814,
1734,
-22638,
-8110,
10560,
4749,
-4375,
-2095,
-1614,
1877,
5962,
224,
3605,
-2842,
8007,
-4695,
-3018,
4338,
-5334,
-8785,
2486,
914,
970,
-4862,
1879,
1964,
3811,
-4692,
-8723,
-7969,
2917,
-6968,
-10778,
-7111,
1346,
5311,
1131,
-2487,
-3914,
7110,
-3437,
320,
3173,
-1364,
-653,
-12293,
3183,
-8665,
3582,
-8041,
1151,
11058,
-11269,
7925,
5520,
-5290,
11035,
11365,
9842,
8630,
-543,
-5857,
3269,
-2776,
4786,
970,
3872,
4783,
4819,
-2027,
115,
3516,
5494,
154,
7891,
-7444,
-3094,
2831,
-255,
-3049,
-13842,
155,
559,
-3331,
1145,
-2248,
-1678,
15306,
-10743,
91,
1076,
-4967,
620,
3640,
-3534,
-6235,
-6441,
5189,
-8942,
-7782,
-12669,
1221,
3681,
6963,
4338,
267,
-5642,
-12849,
6305,
-11395,
5454,
-835,
-3625,
-3852,
-7305,
1688,
-1575,
-5072,
-7875,
-2753,
-22,
12681,
5747,
-9527,
1386,
-4802,
-5657,
7313,
2878,
6676,
-3340,
3395,
-1114,
687,
-910,
-5068,
2317,
-6428,
6160,
-5825,
-4175,
576,
-10380,
-3830,
8304,
9922,
-8081,
-3103,
-6871,
-5920,
6161,
-16859,
7888,
-13849,
-7798,
14360,
-17316,
8754,
8123,
4116,
-15019,
9671,
-1740,
-6742,
489,
13639,
3412,
2218,
8761,
-10270,
-3833,
1318,
-13720,
-9516,
-2288,
7245,
-725,
4213,
-4704,
16542,
-9365,
1027,
4304,
6078,
-4870,
1565,
680,
5277,
7196,
10325,
9249,
7951,
1361,
-3961,
7355,
-1220,
5287,
-184,
-2935,
-4068,
10617,
3794,
13330,
5426,
-1737,
6935,
1736,
-6194,
-1332,
-10007,
2253,
7897,
-4811,
-1180,
-2222,
9014,
-5189,
-11234,
1313,
-8560,
-8935,
-3213,
6617,
-9001,
-7031,
12471,
2198,
-5234,
-10710,
6704,
-5029,
18620,
-8116,
-721,
-10903,
-151,
-2746,
-4523,
9361,
-2062,
5171,
-4733,
-3140,
3481,
6022,
-8464,
4086,
-10887,
5815,
2962,
11656,
-3905,
-2620,
17229,
-8391,
5015,
-106,
5593,
2848,
1070,
-4143,
-2551,
7450,
-2122,
687,
4179,
6828,
-973,
-6098,
1991,
-8180,
3426,
-1012,
2741,
2226,
4096,
-10329,
-1024,
920,
387,
-538,
-5897,
2975,
-6680,
-382,
734,
5897,
8860,
-6975,
-13091,
-7409,
12760,
8659,
7623,
-2841,
-2190,
14185,
1154,
2189,
2221,
-1986,
-2905,
4171,
4293,
-11021,
4912,
-5525,
-13810,
757,
-2655,
-1455,
11661,
11173,
-2187,
-8971,
2982,
-4971,
-3191,
-2570,
10692,
-403,
2386,
4275,
2119,
4421,
-5479,
-5419,
1398,
-2981,
5679,
11749,
1395,
-3746,
-16923,
8720,
-3069,
-5808,
-7539,
-7817,
1906,
-3036,
-1323,
154,
4518,
2585,
7280,
9467,
-6581,
7944,
7507,
711,
137,
-3126,
-11528,
3459,
-3216,
-1413,
-945,
1349,
-6879,
-4797,
8074,
-2387,
7212,
1075,
-3197,
-1030,
-132,
1262,
-9315,
3331,
3496,
-9476,
-5974,
5003,
-4238,
2373,
33,
1558,
-3613,
10032,
3654,
4717,
-2976,
-4895,
-3561,
766,
2560,
-9713,
5356,
546,
10929,
-12843,
11413,
6754,
-1285,
312,
612,
1828,
6392,
-9455,
16226,
4293,
-6573,
5312,
13606,
-6523,
-7015,
-254,
-4595,
-11176,
4940,
-752,
-7544,
9052,
-164,
-6565,
9927,
11728,
12863,
-2704,
1843,
10722,
-3711,
-9166,
6528,
8831,
3103,
12354,
1144,
1102,
7118,
-718,
1020,
-316,
4060,
-2659,
-7777,
5122,
1684,
-3250,
8331,
-2209,
4341,
-5083,
768,
-1523,
-7954,
-424,
13,
181,
-3834,
3455,
-3579,
10203,
-10345,
-1060,
-6681,
-3994,
-3321,
2401,
3325,
10831,
-3605,
-1442,
-885,
1615,
1792,
1767,
-2593,
9611,
-1660,
-8817,
1738,
-3176,
-4018,
2221,
-14774,
1599,
993,
13047,
350,
-6645,
4036,
-8634,
8181,
4812,
-4349,
-766,
12121,
-13601,
-8268,
-3793,
6672,
2595,
-1337,
9473,
-3658,
7251,
21538,
10722,
7258,
-1068,
-5500,
1443,
-6208,
-11598,
-1989,
-3684,
-2494,
-1725,
-10468,
4484,
-11420,
-1626,
-264,
-10556,
-5728,
10386,
-3506,
342,
4510,
-10986,
7880,
7581,
-8132,
9064,
-1124,
-8034,
9340,
-9850,
4882,
-2301,
6017,
-3222,
-2716,
-6186,
4205,
3296,
-5480,
-6707,
-4399,
-11149,
-6748,
9413,
3909,
-6879,
1633,
5545,
2820,
-8653,
-21,
-2529,
1349,
-1096,
117,
-2586,
-1615,
-6443,
-10198,
2599,
-4323,
7020,
-5277,
-6335,
-959,
6440,
6739,
-837,
-3429,
-3705,
-5219,
6305,
1888,
-6118,
14789,
2668,
-16300,
-13898,
-1345,
16106,
9439,
628,
-5250,
860,
5279,
-1711,
765,
5269,
-4512,
-9983,
1494,
-209,
-8751,
-1047,
2772,
1581,
14388,
-5142,
-4057,
-9991,
4674,
5123,
1779,
-2643,
6846,
-5073,
-3374,
2062,
-5874,
-3248,
-5432,
3949,
9650,
-6248,
6306,
3285,
1844,
-12964,
5463,
2646,
3068,
-2167,
-10841,
8963,
-5402,
-11168,
-209,
4659,
12082,
-1265,
-2092,
-3487,
-450,
4852,
288,
439,
-5503,
-4082,
-8203,
-2895,
-3625,
234,
1788,
-6828,
-7295,
-8818,
9473,
4519,
-11164,
-3496,
6635,
2197,
3338,
-1301,
-5997,
449,
3576,
-3695,
3605,
6360,
-348,
-3311,
-9003,
5724,
-4995,
2420,
2809,
10444,
-11582,
-4270,
-18621,
327,
-8067,
2613,
3296,
8218,
9318,
-5919,
1612,
4356,
-4126,
3208,
-6652,
-9486,
4287,
-3784,
5923,
-3594,
2414,
-18974,
-887,
-9853,
-4993,
-804,
6920,
-11102,
-4472,
1139,
187,
-3538,
-2676,
5164,
-6313,
6542,
-3268,
3249,
-1355,
-1915,
7927,
9367,
-5931,
12133,
4253,
1196,
-1465,
4146,
-4446,
-5244,
1871,
-995,
3216,
3836,
-5183,
10057,
-4176,
-2198,
12047,
-2140,
6935,
346,
6900,
4049,
-2397,
-3721,
12718,
1346,
-2369,
6014,
-7584,
3691,
-6811,
11818,
-146,
3502,
-3576,
4095,
1953,
1971,
-2983,
4242,
3394,
-11114,
993,
-5073,
-4198,
4562,
-8789,
4581,
1210,
-7222,
12357,
2837,
-3739,
6434,
18656,
1188,
3231,
8177,
1867,
9318,
7133,
-9022,
-840,
6484,
-622,
15660,
-2662,
3435,
-2710,
5059,
-10470,
12732,
2991,
14177,
-2444,
-3538,
3823,
-2890,
1318,
14164,
-4480,
4812,
-4807,
-1488,
1459,
-14005,
-2832,
-9737,
2277,
14237,
14073,
-6087,
994,
5982,
-5813,
315,
-1097,
-2216,
-3531,
5289,
-2144,
-5932,
-4247,
-10599,
-2035,
3982,
-4854,
10598,
7591,
-4862,
-8521,
8524,
2396,
-5428,
3772,
8953,
-4077,
10178,
-4013,
-7090,
3516,
-6856,
-1794,
-13722,
-7418,
5270,
-10738,
-11712,
46,
-1184,
12549,
6653,
578,
-2562,
16292,
1731,
-237,
4,
-1206,
-6011,
-5246,
2932,
-1603,
1581,
1198,
3291,
2258,
-5903,
-4659,
-392,
1691,
5526,
-4578,
-6846,
338,
1905,
2804,
-2882,
-2156,
-3992,
-804,
659,
-639,
-1975,
-5987,
-847,
-5680,
-7924,
1763,
-5126,
-5196,
4652,
-2766,
-4594,
-3290,
841,
3475,
570,
7313,
1230,
-5762,
815,
3503,
2512,
8182,
-1129,
-2178,
2898,
4950,
-1120,
-4973,
15980,
830,
6095,
8314,
13586,
-1306,
-2817,
-1545,
3803,
4910,
-4232,
-6347,
2279,
2958,
2986,
-2081,
1152,
-1763,
5049,
1591,
2395,
-8849,
4679,
-1333,
2019,
-1025,
-4712,
-2583,
-1641,
6501,
1693,
-1189,
-3479,
2243,
1197,
3192,
6529,
2052,
393,
4629,
3390,
8387,
-1321,
-5883,
2696,
894,
910,
-3040,
-13923,
3573,
217,
-3382,
962,
7038,
428,
-5992,
3392,
1304,
-675,
-6108,
7587,
-204,
850,
876,
-2750,
2368,
-4004,
1637,
-2342,
3976,
-2619,
5545,
3271,
453,
-1588,
8520,
11546,
-5187,
3444,
-1951,
-1281,
-5585,
1894,
-7093,
5845,
2272,
-931,
-1032,
-874,
5911,
4909,
7879,
5047,
-3157,
-2386,
-948,
703,
-9593,
-827,
-3558,
-3861,
4851,
375,
-3128,
-5439,
-2055,
-762,
1436,
2416,
-4786,
4124,
-2580,
1432,
-4094,
5484,
4967,
-3658,
7641,
-2791,
2623,
-1296,
-2487,
-3730,
-4001,
-7636,
7188,
-2751,
843,
5520,
-3540,
-557,
4255,
-184,
-3101,
6390,
-3503,
7036,
3190,
-3255,
-1067,
-7773,
1711,
69,
3679,
-218,
12137,
-6322,
-3919,
-9962,
-492,
-1652,
-11113,
-1040,
-3119,
-745,
-2489,
-3031,
3076,
979,
-4223,
-2229,
-9297,
8035,
6131,
-3273,
1548,
5334,
620,
2806,
-5165,
4074,
-1658,
1719,
-6888,
-6611,
6522,
3575,
-3443,
11662,
-11891,
6896,
2721,
5967,
-3586,
-3091,
4907,
3351,
5015,
-5139,
7715,
-3919,
3522,
1468,
205,
5079,
1480,
485,
1033,
-1226,
-3509,
1256,
3714,
2611,
-2684,
8398,
-3984,
436,
-2431,
2488,
2910,
8169,
1064,
-3132,
-3507,
-6166,
7097,
1265,
-4489,
-4767,
6938,
4469,
-4174,
9328,
-204,
-2033,
-6673,
-1416,
5466,
4418,
-457,
9005,
-3128,
3544,
894,
2527,
-1129,
2623,
7799,
1401,
-1556,
-2644,
-516,
-4143,
1609,
-2669,
-15,
-6288,
1001,
-1361,
-2265,
3690,
-2652,
-1049,
2855,
3389,
4262,
3152,
-4372,
-2795,
4452,
2402,
-2281,
-3743,
-1503,
2150,
-9689,
4009,
-77,
-845,
7195,
-9026,
4346,
-1748,
-4463,
-287,
-2379,
-4701,
-1156,
5606,
-1969,
1006,
4217,
-2533,
7769,
-1400,
-5969,
-2335,
1699,
4960,
-536,
7062,
-1062,
-4496,
506,
-429,
1813,
1783,
40,
-386,
6251,
680,
-1895,
3222,
-4439,
-7276,
-8216,
-273,
-11889,
6451,
4632,
2083,
-4176,
1918,
7756,
-2508,
57,
4217,
711,
-2206,
-2714,
334,
-3649,
558,
6888,
-5789,
4689,
4413,
711,
4476,
3069,
-3270,
157,
-2973,
202,
-4887,
914,
3110,
-4066,
1577,
5739,
-2002,
5318,
-5050,
-955,
10355,
2008,
2171,
508,
-3055,
-4903,
2378,
1136,
5852,
4277,
-6992,
-2065,
-3734,
-6476,
1743,
-555,
5862,
-9258,
4092,
-1312,
-1660,
-9136,
968,
1010,
-3242,
-2300,
-6607,
-2419,
2189,
-2121,
965,
3318,
1052,
884,
10092,
-1090,
-2813,
712,
-755,
4122,
-853,
-2061,
7764,
4937,
1015,
2995,
75,
-1338,
5654,
1820,
824,
-330,
-6594,
-11558,
6109,
224,
-60,
-6454,
-1090,
-1636,
1959,
-1263,
-3061,
-2181,
-295,
-3588,
1199,
5727,
-864,
10628,
-1138,
2718,
2683,
-766,
1884,
-976,
8687,
3701,
-6582,
-3022,
-959,
6124,
3488,
-8004,
-4091,
9114,
6223,
3830,
-9154,
8449,
741,
-2650,
1979,
9075,
189,
-1999,
-6483,
-4267,
739,
-1622,
-8095,
-4513,
303,
120,
-3954,
-221,
-5317,
-2451,
3955,
1064,
-2752,
-4331,
3006,
-754,
2510,
10355,
-2724,
3703,
6705,
-4030,
-8935,
-3002,
-3237,
584,
3407,
2098,
6146,
1713,
9461,
5896,
2711,
3579,
1326,
-2580,
12996,
2589,
27,
10668,
-3749,
-2524,
704,
2384,
8423,
-3590,
8057,
7031,
-2608,
723,
-2832,
-2208,
4077,
567,
2416,
-5763,
-1932,
-8382,
-7527,
1617,
3007,
1363,
-6354,
912,
-4282,
-4051,
-3680,
-14366,
-3060,
-6377,
3015,
3175,
-4006,
8619,
-1058,
6403,
351,
-2961,
-669,
-1417,
-9767,
2181,
1727,
1973,
4736,
6516,
2867,
5751,
1017,
1876,
4470,
-9215,
-4287,
2595,
5474,
-124,
2750,
860,
-1283,
5242,
-2302,
1318,
1489,
-6988,
-6492,
6214,
-5654,
449,
-313,
-4860,
4969,
8193,
-901,
3692,
-2988,
3143,
-1966,
4636,
-5345,
-2968,
-4004,
-2863,
-1438,
3372,
-3767,
105,
-2963,
157,
4799,
4614,
-8551,
1254,
1224,
-9305,
3496,
8102,
-2173,
-1990,
4367,
-6646,
-203,
-1221,
-3586,
9205,
8224,
2143,
6166,
5466,
-4277,
-7695,
-1197,
795,
-3729,
1134,
1066,
-2427,
2436,
-4701,
4163,
50,
1482,
7651,
1965,
-530,
1339,
424,
-1096,
-4131,
-6030,
6671,
2512,
3803,
1381,
10973,
-4468,
6296,
-4226,
-1273,
2667,
474,
4567,
-2916,
-4596,
7488,
-2045,
1194,
-2872,
-9880,
4161,
799,
-1987,
-6174,
4234,
2008,
1831,
-1728,
-7294,
8621,
-3937,
6947,
-2161,
4293,
-2278,
-2427,
-586,
3510,
7156,
814,
-3187,
1872,
7069,
-2536,
-9809,
6157,
-4240,
-3736,
-859,
-3081,
2462,
6020,
1958,
7205,
-7805,
-1641,
-48,
-81,
5284,
1691,
1062,
2099,
-4989,
-3673,
5744,
-7113,
-4544,
-2601,
-2838,
-2180,
634,
-1193,
-1572,
104,
517,
-5720,
-1856,
3914,
-1726,
1363,
-3401,
177,
-3312,
1999,
2763,
6055,
2323,
723,
-5193,
4217,
5311,
-1321,
-3122,
-648,
-888,
3229,
3314,
-382,
1644,
1277,
-4798,
335,
4845,
1992,
4041,
2086,
-6838,
1524,
1257,
-4052,
-2187,
-1543,
-3750,
1463,
2603,
1816,
-989,
4028,
248,
2396,
-1211,
341,
-2621,
3174,
-28,
-1056,
4375,
2683,
-1461,
7010,
-1142,
-10178,
2894,
-4397,
2650,
-1635,
-7508,
8412,
-2728,
-4153,
-5687,
4192,
6885,
7987,
3122,
2826,
2774,
4622,
1489,
1135,
-2770,
-2017,
1866,
1657,
302,
8244,
-4753,
3944,
-9766,
5954,
-213,
3489,
-1472,
-5641,
-7264,
-1671,
-4899,
-1985,
-2753,
3882,
5706,
1021,
2073,
4576,
-5400,
1303,
-3939,
5853,
-5530,
-8446,
1939,
4746,
2797,
-86,
-5390,
9328,
89,
-2299,
-2836,
-417,
4564,
-8314,
-919,
-3236,
-1944,
-3435,
652,
-1571,
145,
-108,
-10048,
-9215,
-6848,
-812,
-918,
6636,
-5685,
-267,
7140,
7231,
626,
1692,
5172,
-6704,
4950,
-161,
4084,
3400,
-2807,
-2640,
3244,
-1174,
1429,
-4198,
8215,
1691,
-357,
-79,
-10444,
7818,
7414,
1831,
1144,
-2975,
-264,
1489,
-1635,
-4136,
9197,
-3301,
-2753,
-4768,
1587,
1519,
3933,
1358,
4088,
662,
-262,
-9810,
-9723,
-1850,
-3920,
-2241,
-4201,
-2017,
-1097,
4872,
-2386,
2850,
-1197,
-1693,
708,
-3773,
318,
6364,
-910,
-5783,
-2194,
-858,
-3351,
-171,
15,
4842,
-1668,
209,
-2967,
574,
-3789,
-3939,
-8340,
2104,
-7848,
5086,
-1905,
-6434,
-2667,
5550,
-2087,
-4281,
2080,
1246,
-167,
-88,
-1725,
2007,
7005,
2129,
6945,
-5270,
-7793,
1015,
-4827,
-4744,
718,
3142,
2751,
1091,
1891,
3623,
-3596,
-7767,
-2372,
-3798,
1601,
1931,
-9765,
1563,
5689,
-3342,
4595,
10351,
2730,
905,
2114,
-230,
4276,
5844,
1148,
-1594,
2240,
-528,
45,
3297,
-3679,
-1989,
-1924,
-9707,
3579,
-3937,
-5362,
5674,
2103,
5719,
1406,
856,
-8416,
-2878,
-1180,
-1473,
932,
1209,
748,
589,
3788,
-4500,
5893,
6902,
997,
-2533,
-3660,
-1830,
-1886,
3184,
-2583,
1356,
-3413,
6021,
-247,
-793,
2466,
-9084,
-935,
404,
3865,
304,
-4599,
-763,
5468,
4473,
-1203,
-2880,
5137,
1072,
5413,
1111,
-2105,
864,
-5508,
4630,
-5457,
-6894,
-2080,
-5724,
-6521,
8800,
-3877,
-1558,
3467,
2457,
5700,
-2956,
-375,
336,
2243,
-1206,
3427,
-4901,
-4256,
5157,
13013,
8640,
545,
-2353,
1337,
1875,
0,
4,
0,
461,
8633,
6693,
750,
-9095,
-564,
1542,
-2808,
-562,
2536,
-1281,
3203,
5177,
-7448,
-3969,
-8471,
-4964,
309,
-428,
-4717,
-4226,
-1159,
-2784,
589,
4858,
-10621,
2042,
-3356,
-2100,
3061,
1274,
9768,
-3313,
-13076,
775,
7333,
-3818,
-17565,
1488,
-6059,
8262,
764,
6740,
-178,
10929,
9152,
-4723,
-4098,
-1009,
2691,
2381,
-3890,
-6291,
700,
-6879,
-8200,
526,
1497,
13086,
-5577,
-4517,
7240,
4695,
-5898,
12312,
-6272,
674,
5299,
7353,
1669,
1094,
-2421,
10835,
10489,
-3868,
-2391,
2170,
1147,
1991,
9121,
2625,
7440,
670,
1253,
-5202,
8929,
5251,
706,
9871,
9856,
-10220,
-2081,
772,
5043,
3113,
3245,
1215,
-3657,
-1858,
9500,
1305,
-7418,
-19719,
-13130,
-7460,
-4898,
-2267,
7073,
-7887,
-1987,
5814,
-3311,
1110,
-3377,
6163,
2389,
3265,
-8346,
-2382,
2944,
-5860,
-1131,
9781,
3750,
20249,
-7645,
3366,
-7369,
-6458,
91,
853,
1546,
1151,
4131,
10582,
-556,
5257,
-5095,
-7017,
-5125,
12062,
2802,
-3268,
-2019,
3499,
-779,
5242,
-6579,
-2950,
3422,
9199,
-1808,
977,
9238,
-684,
-6486,
-1042,
-7951,
2311,
4482,
-3442,
-751,
6551,
307,
-602,
4927,
2786,
-6579,
-4703,
5081,
-3964,
5979,
6781,
-856,
6983,
-1996,
-1089,
-1660,
6111,
10530,
-15951,
-12912,
9585,
2986,
16918,
692,
8990,
-12290,
-8264,
4257,
8325,
-1122,
5065,
-1781,
13900,
11203,
119,
3525,
3980,
-4113,
-11731,
9062,
6123,
-12702,
-1406,
1691,
-8332,
-4762,
-14269,
-6134,
-4912,
6746,
4855,
9333,
6044,
-2964,
-205,
5334,
59,
9064,
-13098,
-166,
-2767,
-10808,
-2674,
-10584,
11717,
-6749,
-10620,
-1686,
2096,
-5355,
-14290,
5341,
-5093,
-1305,
-1796,
2176,
-2768,
60,
6267,
-2494,
-7990,
5904,
5297,
4804,
750,
9746,
-4471,
3661,
-1479,
3427,
-10820,
1428,
-6864,
2340,
-1353,
-3550,
7733,
-2626,
6470,
-5706,
-76,
-5739,
94,
-380,
2790,
-7073,
1731,
-636,
-3483,
-8447,
6687,
-173,
6205,
-8,
-7569,
2570,
-4464,
-2909,
-3218,
5335,
5563,
-10888,
-327,
5173,
-3616,
2467,
-3909,
7306,
5241,
3264,
-13648,
22854,
-6131,
-12112,
686,
-4212,
7344,
1273,
-4053,
-9995,
-625,
-1916,
-3480,
-3988,
673,
3476,
4331,
-2504,
-3889,
8764,
1114,
3364,
4970,
-4868,
2142,
-573,
3063,
1954,
-6328,
1410,
-2133,
3206,
-4513,
-6115,
-3513,
4041,
1308,
-2960,
1356,
1491,
-16503,
10447,
-7722,
5258,
2041,
-8230,
10971,
-2032,
4134,
1307,
3921,
-3198,
3923,
6436,
-8209,
1320,
1423,
-154,
-4639,
-2392,
-361,
4697,
4713,
-1365,
3981,
-5149,
-4683,
1298,
-466,
1665,
6063,
3779,
-2479,
755,
7098,
-38,
17458,
1015,
130,
1642,
-5274,
1968,
-5066,
-9612,
-8609,
13564,
-2769,
-7066,
5864,
1270,
-516,
-144,
-555,
-5457,
934,
-3084,
3752,
1935,
1028,
-10169,
-628,
-9892,
6977,
-13227,
-4743,
-10945,
16387,
4187,
-4202,
928,
-4839,
-234,
-8899,
-8079,
-8957,
-5236,
4604,
502,
15971,
6544,
843,
-106,
-1758,
-5474,
-5758,
-4759,
-1517,
7283,
9301,
-1936,
-8250,
-6110,
-6026,
-6127,
-2760,
-5423,
4837,
-2271,
-508,
-5899,
3290,
-2951,
-8399,
1180,
9448,
12254,
676,
-4871,
-4995,
-6077,
4617,
4402,
13070,
2274,
6767,
-5093,
1398,
-5925,
1893,
-1640,
-7243,
1986,
4047,
300,
7243,
-1425,
1514,
-1571,
-765,
3194,
6735,
-13496,
-5040,
3057,
-4543,
-1314,
-834,
-2497,
-6800,
-4683,
-2028,
3020,
506,
-3979,
-1716,
9829,
721,
-7729,
-6991,
5136,
666,
6950,
3255,
-8098,
2029,
5174,
-9387,
5758,
-1771,
-4237,
420,
-15984,
1982,
759,
-4162,
-6491,
-18184,
1486,
-7319,
2575,
-230,
14511,
6411,
3519,
3068,
-1015,
-7618,
3278,
5573,
12449,
2132,
-6444,
-8348,
-4297,
-8266,
-7412,
2769,
-1843,
-4248,
1814,
10256,
-8967,
-148,
-2441,
-761,
-1470,
-5968,
10957,
6837,
5032,
16428,
4626,
9737,
7454,
-9495,
5035,
-3217,
5167,
-2653,
-743,
-1173,
-939,
-3982,
4914,
583,
8478,
1962,
11576,
7253,
5311,
17826,
8991,
433,
-1980,
-6209,
8740,
12052,
10360,
-6956,
-7910,
-1814,
10311,
-1876,
10608,
-3893,
-263,
-7189,
1780,
4310,
-7398,
-2939,
-6591,
-159,
5717,
2752,
-11853,
4466,
4389,
-559,
362,
10889,
-8662,
-2876,
13094,
-2848,
-5531,
-6038,
-9886,
-2327,
446,
-4892,
-7181,
1954,
162,
232,
614,
1260,
-8829,
12857,
-1223,
-1376,
-7482,
3384,
3145,
17289,
7359,
6623,
-2962,
6352,
4152,
261,
1279,
117,
5301,
-5391,
8035,
4651,
9858,
-431,
5651,
9882,
10653,
-4077,
9546,
-1796,
8550,
-174,
4041,
11124,
6058,
-30,
-3451,
-5914,
-1059,
-10714,
13793,
-2102,
8143,
2856,
-7347,
-997,
-10472,
-10302,
1329,
-304,
-11312,
-6197,
2009,
2838,
4388,
-6895,
15179,
-1769,
4954,
2397,
-1403,
4593,
-5541,
-3016,
-4871,
5749,
2418,
-15008,
16684,
6729,
-2553,
-3510,
-4780,
-8007,
4143,
7339,
3102,
843,
-11286,
8147,
-2092,
3059,
-348,
-8600,
-909,
6087,
6144,
-2490,
1724,
2176,
-1664,
-1125,
-834,
4108,
5594,
-318,
1357,
-425,
2959,
296,
2574,
4203,
5443,
-5027,
192,
-61,
5353,
2777,
-5074,
-9068,
-17189,
-9435,
-3490,
-12086,
4590,
7242,
-5367,
5621,
3257,
-4406,
-155,
-16373,
8333,
4384,
1849,
4749,
1307,
-14476,
-775,
-3242,
-7551,
2406,
-4464,
-3141,
4061,
7800,
1292,
8767,
7118,
4591,
11849,
-1310,
-2920,
19896,
2540,
-7784,
-6422,
-8830,
-5518,
13534,
-121,
-6395,
4985,
-5403,
1702,
-6682,
6761,
-3500,
4957,
5882,
1413,
-13040,
3451,
-4015,
-5533,
1165,
-8077,
-5388,
-2701,
-8184,
-7491,
2252,
1204,
-5301,
-2240,
18080,
-5326,
6308,
2725,
2337,
-7310,
-5103,
1138,
4119,
-11101,
378,
9536,
4252,
-8982,
2362,
-16371,
3694,
-4370,
-721,
8487,
3890,
1697,
856,
3991,
-360,
2598,
3100,
-6937,
-9348,
-3928,
1397,
-711,
12201,
2827,
-11072,
3554,
-12668,
-1269,
-5174,
14639,
-3024,
2185,
705,
6185,
-3719,
-13292,
-6093,
7148,
-7671,
-1774,
553,
-1427,
556,
-6721,
-667,
5516,
3624,
3130,
-11794,
3864,
15243,
777,
1558,
6536,
1452,
-1850,
-5905,
-8118,
7400,
7885,
8848,
-36,
6135,
-6576,
2231,
-9316,
-1102,
16003,
-7646,
6575,
-1278,
1472,
2156,
-442,
-2032,
4775,
-4968,
-8290,
-8231,
-1882,
7034,
5564,
1704,
12075,
-11878,
8709,
-8207,
-2082,
-524,
1834,
-2003,
-1658,
468,
694,
-5949,
-7170,
1194,
-5625,
-8727,
-1439,
784,
-11257,
-2713,
-3490,
7083,
-16142,
-2454,
2830,
6264,
-62,
-9768,
-3529,
1661,
3637,
-3885,
-14704,
-4858,
-3383,
8094,
9535,
-4063,
317,
-7972,
-3163,
-461,
-1262,
9581,
-14952,
-5825,
3320,
12724,
5563,
-2687,
3310,
1016,
6011,
2960,
-6287,
-5458,
-9278,
-1440,
-4205,
4957,
-6128,
-6982,
5238,
9107,
-6042,
3192,
4747,
1271,
5494,
-22,
-4911,
8822,
4225,
1880,
-1344,
-12955,
-8706,
7842,
-3243,
-1436,
-9117,
5903,
-226,
-6390,
-3034,
-5769,
-7414,
-4378,
-1016,
108,
365,
-11661,
7064,
-10997,
-13102,
6730,
-5175,
-14357,
1033,
-6146,
3551,
-14080,
-1934,
-7883,
-10,
-6313,
-3114,
2266,
425,
1028,
-4616,
-5315,
-7507,
-3328,
3451,
9450,
-3585,
10191,
1802,
-2189,
-3994,
2294,
-5841,
-7318,
-6478,
2618,
-825,
4773,
-717,
-6127,
-55,
-3925,
4847,
1712,
-16386,
7444,
-7920,
-1698,
7668,
-6124,
-2279,
5897,
-4164,
5507,
10979,
6052,
-5573,
-3495,
-2736,
952,
-3322,
-7377,
9818,
1838,
-876,
-3085,
4153,
4473,
-4271,
1112,
2234,
-754,
7715,
3935,
2423,
-3872,
4656,
-2942,
-6295,
-9941,
-12252,
-18520,
-1069,
2162,
5089,
-5792,
-4138,
6471,
-2325,
-1986,
1907,
-7201,
7170,
6865,
-338,
10965,
3806,
-1423,
3060,
3437,
1034,
-5324,
674,
-4814,
-9556,
1023,
-5594,
-8927,
14612,
-6824,
5347,
2228,
11342,
10790,
2191,
-6977,
5767,
-5292,
-8557,
-11673,
-2998,
1657,
-5551,
-3768,
3745,
2135,
5,
1008,
12079,
3977,
-6059,
-5024,
-6685,
-3257,
-8934,
2567,
7784,
7512,
1552,
-2358,
688,
-4597,
2843,
-686,
-3258,
-50,
-5958,
1051,
6295,
11248,
4255,
5791,
-1912,
4612,
7412,
5446,
-1140,
-4340,
11329,
-4814,
-691,
-7421,
10478,
-1816,
-3997,
-9435,
3475,
482,
2120,
-1556,
-5645,
7528,
-5493,
607,
-292,
-7300,
3668,
-6987,
8123,
-3226,
-522,
-1440,
-6318,
249,
-3940,
2660,
1186,
2140,
-1330,
5100,
-1948,
-610,
-605,
-5368,
-7,
-558,
4440,
499,
-4297,
5614,
-537,
-267,
2930,
-5118,
-2082,
6314,
-6051,
-3361,
11029,
3675,
-2806,
-4100,
-3335,
3729,
-2239,
-1051,
-760,
-3315,
-2765,
-837,
-7010,
1997,
1580,
-1687,
-4165,
-494,
-3218,
-5790,
-71,
-3894,
5764,
4173,
7434,
-3019,
-1274,
-749,
3527,
851,
4763,
-1333,
2045,
1621,
-787,
2067,
-2334,
-435,
3420,
-729,
-3671,
-10135,
2931,
-2255,
-5372,
-2432,
-8102,
11663,
3035,
2022,
3067,
369,
-1726,
1839,
3560,
599,
7214,
-3265,
-3621,
-1510,
-11087,
2087,
55,
8371,
4336,
-552,
-866,
-5928,
11397,
5060,
3618,
-5844,
-4118,
-8279,
-1219,
7573,
-8414,
3652,
1296,
-1031,
-271,
5983,
5528,
-7411,
806,
-2119,
-532,
-4528,
4245,
-512,
5175,
-1677,
8786,
8824,
3558,
-936,
498,
36,
2855,
3044,
4153,
-441,
3970,
-4937,
8224,
-7731,
3862,
2925,
-2243,
-5897,
8270,
5777,
4439,
545,
949,
-7570,
4234,
-2108,
4148,
146,
4592,
-3179,
6191,
8042,
-2000,
-11445,
-61,
6644,
-288,
-2973,
657,
4726,
6596,
-6344,
-486,
165,
6938,
1391,
2210,
-1791,
1595,
5051,
10989,
-1746,
-5187,
-4531,
-2473,
-346,
1185,
75,
-11463,
2961,
7341,
-5621,
3024,
1597,
11382,
-4831,
-3633,
6629,
-3619,
9367,
-2118,
1030,
-236,
-5163,
-10101,
2185,
-615,
5188,
-6949,
1381,
4245,
-4491,
-4167,
-10414,
-1351,
923,
3028,
-7152,
-7140,
8226,
1705,
8149,
3083,
1751,
-578,
-1611,
-4139,
4458,
4083,
7229,
2460,
2850,
7749,
-4821,
1490,
1052,
-4833,
-253,
7095,
-5506,
-1916,
10079,
-748,
4836,
-13636,
-325,
-2914,
4432,
5154,
2392,
2740,
-1220,
1126,
-2853,
-5701,
-3811,
6966,
-4787,
-3372,
6538,
2452,
3787,
1711,
-3320,
-1963,
5742,
1149,
-2440,
5322,
-2940,
-1898,
-2701,
-6246,
-2054,
-2168,
6249,
-7608,
-705,
-7733,
3113,
404,
-586,
-1257,
5508,
-8660,
-13061,
-3214,
4842,
-2251,
-597,
-4308,
1857,
6354,
849,
-4750,
1734,
-12666,
8577,
3814,
5589,
-4217,
-5696,
-5092,
-7383,
-7398,
2602,
2832,
-5023,
-1206,
407,
-4530,
1806,
3052,
280,
1131,
-189,
-4058,
-1143,
-3867,
-5394,
8796,
-3630,
-3080,
-1972,
-1066,
5698,
-1545,
2758,
-6923,
1331,
-7592,
-4422,
622,
5308,
-1704,
3401,
2940,
-8425,
11911,
303,
-4573,
-2128,
-2563,
2505,
-3475,
263,
-1159,
6070,
-5545,
5611,
438,
-4692,
3285,
3240,
3482,
3351,
2594,
792,
-1112,
-1553,
-6032,
8207,
-3059,
-1235,
-1920,
2847,
1781,
-4470,
-7180,
-1841,
-1697,
420,
2222,
-233,
-5376,
-931,
-7175,
3104,
5207,
3099,
-7685,
2534,
965,
-4094,
9136,
-1544,
337,
-419,
1703,
5103,
448,
12429,
-10086,
-2975,
-641,
5263,
2346,
5504,
3397,
2167,
224,
7925,
4762,
-119,
5208,
3904,
-2402,
822,
-5253,
1037,
113,
-582,
-1880,
84,
-25,
-1359,
-6633,
5741,
5948,
-3876,
967,
-283,
-4687,
-229,
4382,
-3135,
9987,
3324,
8065,
-1321,
-491,
-1599,
3011,
848,
2783,
-2528,
5365,
76,
5752,
-612,
-3261,
-7156,
-1611,
-9870,
-1118,
-3297,
-412,
-205,
4010,
4471,
3282,
3859,
2822,
-3270,
13084,
5021,
-5841,
-5226,
1763,
-1243,
8638,
7613,
-6023,
-4642,
-2542,
-406,
-7647,
-3969,
4190,
8265,
5089,
-1272,
-7914,
-2749,
547,
-6860,
-1492,
-2603,
-3076,
3153,
3753,
8848,
1762,
-2524,
3118,
-1757,
5756,
715,
-2900,
907,
5711,
-1895,
-5672,
-4179,
-5719,
9691,
-2346,
5256,
2516,
-3429,
-536,
-1802,
-6107,
2319,
-166,
1113,
6016,
-3622,
8698,
5298,
877,
2504,
-2674,
-1873,
-1150,
5732,
-2069,
-6436,
-5957,
-617,
-4826,
5913,
268,
4320,
-2048,
2455,
-1404,
-2319,
-4774,
4814,
-9196,
3058,
-4073,
209,
-297,
3430,
-517,
-3432,
9900,
-3422,
2253,
1863,
4849,
-858,
3365,
5638,
3134,
-5074,
10308,
-6115,
-2599,
3070,
1871,
-3856,
-4320,
-3617,
-3157,
2461,
2220,
1309,
318,
3710,
-1014,
-6552,
-1109,
3306,
1610,
12872,
7686,
4756,
-6150,
1211,
7403,
-2492,
-2744,
5642,
-9341,
7365,
-3489,
768,
5646,
-2598,
-2159,
-1242,
-7097,
5230,
-4471,
2469,
-604,
-2575,
1545,
1725,
2093,
-380,
2180,
-2457,
-1743,
-5622,
6520,
9478,
2385,
-8920,
-11310,
-6936,
-2636,
931,
3789,
583,
3564,
-2356,
-2310,
616,
-2979,
-3466,
5241,
-552,
3099,
4189,
8401,
77,
-1058,
4561,
1048,
1956,
2418,
-7026,
-1630,
-7737,
5266,
-3952,
2362,
-1605,
4205,
395,
3410,
5448,
554,
-1357,
-2431,
-5274,
144,
7114,
1155,
8600,
2457,
-1712,
1092,
5761,
-4856,
180,
5191,
3614,
3794,
4933,
1575,
4537,
1740,
329,
11545,
-7772,
1469,
-698,
-6283,
-3667,
2474,
2970,
1298,
4150,
291,
-2355,
846,
3829,
-854,
3350,
-1039,
-1688,
-635,
493,
4275,
1236,
3077,
11534,
-3048,
-1022,
7731,
-1990,
1094,
-5170,
1783,
-5102,
1614,
4747,
1423,
-7732,
2312,
-6511,
1568,
1235,
-4643,
-2888,
4892,
294,
429,
4298,
6151,
1673,
7252,
3914,
-5612,
-2029,
11465,
2077,
4139,
-3206,
2101,
4114,
-1407,
8755,
-3705,
8681,
6313,
-3305,
8536,
1978,
357,
253,
-3782,
3977,
-8120,
-988,
-4073,
-2795,
6726,
-5463,
3120,
2807,
5229,
2020,
-1578,
-356,
387,
7048,
3606,
-5777,
155,
-4010,
3107,
-5888,
-1312,
5458,
572,
-6586,
-166,
5715,
236,
1678,
3018,
1370,
-1357,
7000,
-6586,
4534,
-2694,
-8069,
12612,
-4594,
5541,
900,
4665,
2900,
-1898,
4776,
-2460,
-209,
-453,
3108,
-4617,
5549,
-2081,
-8770,
-5580,
3757,
4866,
2668,
4420,
-5964,
1252,
2302,
-2718,
2465,
3422,
2731,
4626,
-1990,
930,
899,
-228,
7118,
1273,
-551,
-792,
1968,
-2074,
-6009,
337,
-2161,
2701,
1832,
-5230,
-1706,
-1299,
-719,
-4382,
620,
7473,
1136,
-11496,
-2832,
7440,
-6379,
-956,
-207,
-3393,
3152,
-6413,
9498,
6253,
6455,
5099,
-8514,
-3974,
-1146,
2974,
1097,
-1502,
4192,
2696,
3936,
-8480,
-1693,
-5435,
-26,
6244,
3378,
-3524,
2235,
3075,
738,
-2039,
6702,
5114,
-2221,
1184,
-7575,
-901,
981,
-3300,
3291,
-1801,
2001,
-4734,
3795,
2042,
-6118,
5300,
263,
1153,
-8134,
-6101,
-9939,
2643,
589,
2134,
-656,
-3339,
-1319,
-219,
247,
5040,
-3526,
10609,
1338,
-112,
3356,
3789,
-5096,
1322,
15018,
5662,
-10581,
-2460,
4655,
3596,
3254,
2424,
-5223,
839,
46,
843,
-2173,
-4379,
-94,
-1069,
3898,
1606,
-1477,
4874,
8498,
5683,
2426,
3386,
-1588,
-4550,
-2373,
-2056,
-2570,
112,
3463,
-3319,
-10446,
566,
3233,
-4125,
-3236,
-3426,
11688,
-4040,
-6645,
-7257,
5561,
-10944,
-7915,
-581,
1779,
-2901,
-5675,
196,
-2768,
80,
662,
491,
-1777,
-6114,
7395,
2520,
1231,
7092,
9684,
702,
1846,
5879,
-3565,
369,
8,
4583,
4350,
-1021,
709,
-3969,
-5728,
838,
-2743,
3147,
-7808,
-2305,
5196,
5272,
-4821,
2428,
-333,
-167,
-424,
-1162,
18,
-1259,
3064,
3810,
-9562,
-3861,
3115,
8716,
-371,
-390,
-5857,
-6700,
-6888,
-2131,
-494,
-2116,
-2891,
858,
-818,
2113,
-4284,
-4345,
2993,
-7656,
2918,
672,
2758,
-783,
-8798,
4763,
2140,
2193,
5772,
-4825,
-3036,
4611,
6555,
-6207,
1633,
4576,
2097,
23,
3785,
-169,
-2233,
4498,
4839,
-3395,
5129,
-5674,
-2824,
-1245,
847,
-4224,
744,
2666,
-33,
-9806,
-193,
-4065,
-964,
6190,
819,
9860,
4,
0,
461,
5023,
9620,
-1509,
2654,
3225,
-1325,
3187,
-5913,
-4294,
-9541,
6694,
4022,
-3438,
-5085,
-1117,
10918,
17002,
-4049,
-465,
-3888,
-3039,
-5862,
-1130,
5716,
10870,
5812,
-7161,
1667,
1227,
-5037,
-1667,
-20161,
2915,
-1649,
767,
-4401,
-679,
9654,
-8877,
-4472,
3592,
4993,
-1825,
-4717,
4414,
15931,
8331,
1468,
2082,
-5909,
-3156,
-990,
-3901,
9586,
5098,
2999,
8493,
2591,
-6923,
-1392,
2366,
8775,
-1194,
9467,
2503,
12677,
-8204,
-5606,
-165,
-3392,
-6505,
11480,
295,
-4861,
10128,
6911,
10115,
-10628,
-273,
-2243,
1798,
-6706,
6849,
-11639,
-6352,
-7322,
-4583,
9962,
-14612,
-11114,
1936,
6299,
4130,
4655,
-319,
5999,
5554,
-783,
-5319,
-2187,
5580,
5161,
4808,
3706,
10747,
-5353,
-5724,
2834,
-10637,
6414,
-2391,
-3650,
8074,
-7535,
-3010,
-9484,
-3398,
-6823,
7691,
9442,
-4151,
-4059,
-3090,
6121,
-3150,
3003,
-3328,
-1989,
-3269,
-6424,
992,
-13207,
2250,
-3848,
-5427,
2963,
-4341,
1013,
643,
7369,
6591,
-9634,
-8661,
-4566,
1588,
-21181,
-2102,
830,
5807,
2557,
4073,
-13798,
-200,
6246,
1679,
-2677,
-6999,
-578,
-663,
-186,
1565,
-1072,
3683,
8540,
2441,
3483,
1330,
-4503,
-623,
-1732,
-6337,
-3087,
1635,
-5275,
896,
-5857,
-4282,
6727,
-3689,
-6823,
-2628,
-597,
-1542,
-1100,
869,
-5672,
2412,
299,
-10125,
6446,
-780,
-3049,
-2230,
620,
-516,
416,
-5276,
-4565,
4968,
-8391,
-1720,
3212,
4756,
4151,
2994,
-950,
1112,
-6180,
-8806,
11958,
6350,
4559,
896,
-3354,
1186,
1726,
359,
-6918,
-10971,
7814,
-16511,
166,
-13209,
-201,
9502,
-3742,
-909,
-2661,
-1418,
9023,
-8638,
-3564,
-6503,
2692,
-2332,
31,
2141,
-12068,
-10240,
2761,
-2825,
1648,
3574,
2210,
8084,
7828,
2954,
-5179,
-44,
3726,
-1876,
-122,
3059,
7222,
381,
-192,
1307,
8254,
5869,
5156,
-4142,
-5109,
-6060,
3516,
11989,
9546,
5483,
-5612,
-5142,
-2575,
-393,
-6792,
3954,
-4761,
13219,
3755,
-9766,
6765,
13297,
-4135,
2317,
-1585,
-6389,
2038,
-12568,
-4347,
-1577,
-2808,
-2229,
5204,
4264,
-1662,
10100,
461,
8819,
-2647,
4864,
4054,
3096,
-3648,
-815,
-6924,
8520,
-4348,
-2841,
4987,
6716,
-176,
11443,
2519,
-344,
-10090,
2272,
-6363,
-15712,
8857,
-7979,
1792,
2560,
4027,
12585,
1687,
5169,
-12904,
1377,
-12065,
11598,
-2536,
-3927,
857,
10159,
-7986,
14628,
3298,
-334,
5516,
1352,
-10319,
-678,
-2461,
3901,
-8965,
6269,
-3920,
-8010,
-2016,
5356,
-4640,
-2372,
-7744,
5212,
-9909,
-4078,
5132,
3380,
-12643,
547,
1023,
-7640,
9800,
1459,
2301,
-6680,
15750,
-4521,
3598,
-831,
3382,
-3311,
-9747,
-2095,
3708,
-11846,
18521,
-9596,
-4503,
2602,
1932,
-16848,
-4341,
-5389,
-1888,
4111,
-5178,
6556,
-2168,
-2968,
1688,
2086,
3917,
86,
-4671,
-8822,
-8575,
7809,
-8127,
-1979,
3047,
-6718,
9576,
-1318,
-366,
-2769,
2259,
10730,
4778,
213,
-6099,
5294,
2183,
610,
-14899,
-6649,
2084,
5783,
-8334,
-329,
-767,
-920,
6964,
-12577,
15723,
-9863,
8828,
4939,
-1059,
4480,
-2765,
-5776,
-4377,
-13757,
1792,
877,
-10191,
2610,
3037,
-197,
-7060,
1015,
4803,
9252,
1022,
12489,
-5173,
-5099,
4468,
-468,
-3200,
-3422,
-12276,
11403,
-6194,
-3442,
3244,
-5289,
3475,
-6416,
1877,
3203,
-13863,
4408,
3993,
3419,
1910,
9689,
7708,
-8425,
21024,
3938,
-9424,
2221,
2794,
11344,
6208,
-6188,
-4333,
-507,
8768,
11612,
3372,
9116,
12686,
-288,
7436,
2459,
569,
12628,
2528,
4388,
3244,
2177,
-3915,
-4646,
11641,
3776,
-4100,
9521,
10630,
-7993,
8034,
4781,
3954,
6988,
14818,
-4549,
5376,
11459,
1975,
-2248,
-312,
-527,
1270,
-6932,
-571,
5496,
2127,
-1125,
-2643,
4962,
2293,
3735,
-5305,
-396,
-14195,
-1483,
-4619,
3630,
-12756,
176,
-8547,
-5444,
4517,
829,
3739,
5024,
-1246,
1805,
-3528,
2082,
-6085,
11256,
-8345,
11920,
1345,
-4974,
-1445,
-7820,
8928,
4791,
-9705,
-10709,
2453,
5730,
4962,
4232,
5833,
-1866,
10530,
16581,
-3731,
-2819,
-7929,
-2783,
-2991,
15937,
-1239,
-7439,
-1683,
196,
836,
-8222,
37,
-3652,
-2860,
1608,
-2156,
11369,
1126,
9062,
3265,
8519,
6793,
-1844,
2483,
7924,
9997,
6270,
8632,
6507,
682,
-987,
-1548,
-11380,
10640,
-9410,
2728,
-8708,
-6176,
5066,
6595,
-2997,
6174,
2024,
1975,
5680,
-5186,
11367,
-1945,
2215,
-2973,
-202,
3767,
-4380,
-12342,
-7486,
-1190,
-14381,
8928,
7015,
4155,
-7925,
-8811,
-5088,
3357,
-8111,
2052,
9381,
511,
-13724,
4686,
-1569,
3028,
8345,
8770,
-290,
-583,
4345,
2095,
513,
-3235,
840,
5728,
-5330,
790,
12987,
-6842,
6773,
-7721,
7248,
-8182,
-13440,
5838,
-1643,
-1478,
-3599,
-3054,
11342,
12006,
-5963,
11072,
-2236,
5093,
-6864,
-2656,
-1006,
-7384,
-2108,
-5932,
-17813,
10203,
796,
653,
-1087,
-2049,
-1756,
-4180,
558,
2864,
-1087,
47,
-7206,
-5928,
-3331,
-5981,
11064,
4163,
-18106,
-6890,
7439,
-1875,
9662,
-2581,
6256,
-4957,
-8001,
12559,
-7050,
-3723,
7998,
1942,
-8116,
-10823,
-3207,
-16836,
-7200,
7991,
4174,
-1306,
-50,
20917,
11729,
3887,
4029,
4984,
-7546,
6786,
-9289,
-717,
1749,
1265,
11199,
-226,
-6906,
-6912,
11239,
-413,
-7671,
2715,
5239,
-4870,
-2178,
591,
8782,
-7132,
3203,
-2725,
-1034,
-7916,
2444,
-5491,
3263,
-3495,
2219,
-6080,
5525,
-1711,
-182,
879,
1917,
9185,
-12466,
1820,
-13155,
-11175,
712,
-6264,
1166,
-3200,
3383,
-7846,
-5855,
-3141,
833,
-3684,
-4610,
-6088,
-13140,
4137,
-4523,
-6045,
7151,
6751,
-289,
-17833,
-8899,
9440,
227,
-13044,
-5769,
18773,
-4406,
16293,
-6557,
8037,
-10949,
13046,
-1158,
-7576,
-10646,
2240,
-10923,
9150,
4120,
-6342,
-3974,
5146,
5009,
-6351,
1985,
-4988,
1492,
-2420,
-3655,
-2270,
-8955,
7951,
64,
-333,
17203,
-7838,
-1694,
16372,
-6274,
-1148,
1362,
2813,
15052,
1132,
-2618,
-11372,
-12289,
-8421,
-6424,
-7054,
-3779,
6420,
-1606,
1277,
2592,
4204,
1078,
-985,
2629,
3458,
-1077,
-4146,
957,
-2355,
-5492,
-9387,
2082,
-16473,
-7223,
21239,
-6013,
4783,
9568,
10225,
-7799,
-483,
-1396,
591,
-729,
-1961,
-436,
3069,
-5313,
7753,
-1524,
7389,
-15068,
3674,
-4458,
-5395,
1737,
-7151,
7410,
-5030,
-1972,
-2243,
3281,
4475,
-2172,
-5589,
-6175,
-10200,
5095,
17931,
16899,
5750,
-2690,
3742,
-9787,
7095,
4980,
1763,
8840,
-11648,
-5471,
3121,
9485,
9425,
7451,
38,
4132,
1144,
3985,
828,
-162,
9850,
-2799,
-433,
-563,
-1325,
4519,
6058,
7602,
7521,
3088,
-7431,
8805,
-7722,
2793,
11566,
-3065,
-1339,
-21519,
-9200,
7753,
2503,
6336,
-507,
4505,
-7235,
4864,
-3531,
2243,
-994,
-60,
756,
7368,
3893,
6400,
-4024,
-1684,
778,
9858,
560,
-6913,
10322,
1389,
-927,
3760,
-5184,
484,
6316,
-2852,
10401,
-12335,
9922,
7706,
3889,
11300,
6360,
13406,
-1322,
3815,
-3189,
6248,
3697,
3212,
-7910,
-6715,
-14024,
9384,
11169,
1652,
736,
6947,
2103,
4287,
-980,
-1365,
1192,
-7044,
4717,
-11697,
-15228,
-11129,
-367,
-939,
296,
2163,
11041,
-12002,
6443,
10164,
-4186,
-10927,
-2066,
4081,
1477,
-1661,
1248,
4774,
7732,
16005,
-6308,
-6621,
841,
4967,
768,
2663,
-8137,
-949,
4598,
-1413,
-4843,
6637,
-10290,
5110,
6450,
10807,
5823,
-6015,
-1368,
6794,
727,
-121,
-5213,
6525,
13561,
7043,
-3456,
8619,
-1613,
19933,
6293,
12196,
-5324,
-7554,
-1106,
7881,
-4434,
1481,
755,
4766,
-722,
-2341,
-468,
-4772,
-2520,
4765,
2895,
-3744,
-8166,
10492,
-1999,
2545,
4861,
-1521,
3909,
300,
-2999,
2689,
4755,
-501,
10626,
6460,
4996,
-1044,
-17186,
4904,
-2600,
-6615,
-2473,
-2341,
1769,
-3617,
-2248,
3485,
-5215,
8391,
4386,
5510,
-4053,
8221,
6543,
-11914,
-2124
};

#endif  /* _FFTC_TESTCFG_540_H_ */
