/******************************************************************************
 * Copyright (c) 2010-2011 Texas Instruments Incorporated - http://www.ti.com
 * 
 *  Redistribution and use in source and binary forms, with or without 
 *  modification, are permitted provided that the following conditions 
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright 
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the 
 *    documentation and/or other materials provided with the   
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 *****************************************************************************/
/******************************************************************************
 *
 * File Name:  	evm66x_phy.c
 *
 * Description:	This file contains the phy related APIs
 *
 ******************************************************************************/
/* Chip Level definitions include */
#include "platform_internal.h"

unsigned int pa_serdes_cfg_base =  0x0232A000;
#define PASS_CFG_BASE			0x02000000
#define SGMII0_OFFSET			0x00090100
#define SGMII1_OFFSET			0x00090200
#define SGMII2_OFFSET			0x00090400
#define SGMII3_OFFSET			0x00090500
#define SGMII0_STATUS			(PASS_CFG_BASE + SGMII0_OFFSET + 0x14)
#define SGMII1_STATUS			(PASS_CFG_BASE + SGMII1_OFFSET + 0x14)
#define SGMII2_STATUS			(PASS_CFG_BASE + SGMII2_OFFSET + 0x14)
#define SGMII3_STATUS			(PASS_CFG_BASE + SGMII3_OFFSET + 0x14)


#define mkptr(base,offset)	((volatile unsigned int *)((base)+(offset)))
unsigned int reg_poll_to(unsigned int wdth, 
                         unsigned int addr, 
                         unsigned int poll_val, 
                         unsigned int masked_bits, 
                         unsigned int to_cycles)
{
	unsigned int read_data, read_data_masked;
	unsigned int loop_count = 0;
	read_data = (*(unsigned int *) (addr));
	read_data_masked = read_data & masked_bits;


	while (read_data_masked != (poll_val & masked_bits))
	{

		read_data = (*(volatile unsigned int *) (addr));
		read_data_masked = read_data & masked_bits;

		loop_count++;

		if( loop_count == to_cycles )
		{
            printf("reg_poll_to max Limit reached \n");
			return 1;
		}
	}

	return 0;
}
//#define SERDES_INTERNAL_LOOPBACK
void CSL_SgmiiDefSerdesSetup()
{
  unsigned int old_val;
   volatile unsigned int i;


      old_val = (*mkptr(pa_serdes_cfg_base, 0x000));
     (*mkptr(pa_serdes_cfg_base, 0x000)) = ((old_val & 0x0000FFFF)| 0x00800000);

     old_val = (*mkptr(pa_serdes_cfg_base, 0x014));
     (*mkptr(pa_serdes_cfg_base, 0x014)) = ((old_val & 0xFFFF0000)| 0x00008282);

     old_val = (*mkptr(pa_serdes_cfg_base, 0x060));
     (*mkptr(pa_serdes_cfg_base, 0x060)) = ((old_val & 0xFF000000)| 0x00142438);

     old_val = (*mkptr(pa_serdes_cfg_base, 0x064));
     (*mkptr(pa_serdes_cfg_base, 0x064)) = ((old_val & 0xFF0000FF)| 0x00C3C700);

     old_val = (*mkptr(pa_serdes_cfg_base, 0x078));
     (*mkptr(pa_serdes_cfg_base, 0x078)) = ((old_val & 0xFFFF00FF)| 0x0000C000);

     old_val = (*mkptr(pa_serdes_cfg_base, 0x204));
     (*mkptr(pa_serdes_cfg_base, 0x204)) = ((old_val & 0x00FFFF00)| 0x38000080);

     old_val = (*mkptr(pa_serdes_cfg_base, 0x208));
     (*mkptr(pa_serdes_cfg_base, 0x208)) = ((old_val & 0xFFFFFF00)| 0x00000000);

     old_val = (*mkptr(pa_serdes_cfg_base, 0x20C));
     (*mkptr(pa_serdes_cfg_base, 0x20C)) = ((old_val & 0x00FFFFFF)| 0x02000000);

      old_val = (*mkptr(pa_serdes_cfg_base, 0x210));
     (*mkptr(pa_serdes_cfg_base, 0x210)) = ((old_val & 0x00FFFFFF)| 0x1B000000);

     old_val = (*mkptr(pa_serdes_cfg_base, 0x214));
     (*mkptr(pa_serdes_cfg_base, 0x214)) = ((old_val & 0xFFFF0000)| 0x00006FB8);

     old_val = (*mkptr(pa_serdes_cfg_base, 0x218));
     (*mkptr(pa_serdes_cfg_base, 0x218)) = ((old_val & 0x0000FF00)| 0x758000E4);

     old_val = (*mkptr(pa_serdes_cfg_base, 0x2AC));
     (*mkptr(pa_serdes_cfg_base, 0x2AC)) = ((old_val & 0xFFFF00FF)| 0x00004400);

     old_val = (*mkptr(pa_serdes_cfg_base, 0x22C));
     (*mkptr(pa_serdes_cfg_base, 0x22C)) = ((old_val & 0xFF0000FF)| 0x00100800);

     old_val = (*mkptr(pa_serdes_cfg_base, 0x280));
     (*mkptr(pa_serdes_cfg_base, 0x280)) = ((old_val & 0xFF00FF00)| 0x00820082);

     old_val = (*mkptr(pa_serdes_cfg_base, 0x284));
     (*mkptr(pa_serdes_cfg_base, 0x284)) = ((old_val & 0x00000000)| 0x1D0F0385);

     old_val = (*mkptr(pa_serdes_cfg_base, 0x404));
     (*mkptr(pa_serdes_cfg_base, 0x404)) = ((old_val & 0x00FFFF00)| 0x38000080);

     old_val = (*mkptr(pa_serdes_cfg_base, 0x408));
     (*mkptr(pa_serdes_cfg_base, 0x408)) = ((old_val & 0xFFFFFF00)| 0x00000000);

     old_val = (*mkptr(pa_serdes_cfg_base, 0x40C));
     (*mkptr(pa_serdes_cfg_base, 0x40C)) = ((old_val & 0x00FFFFFF)| 0x02000000);

      old_val = (*mkptr(pa_serdes_cfg_base, 0x410));
     (*mkptr(pa_serdes_cfg_base, 0x410)) = ((old_val & 0x00FFFFFF)| 0x1B000000);

     old_val = (*mkptr(pa_serdes_cfg_base, 0x414));
     (*mkptr(pa_serdes_cfg_base, 0x414)) = ((old_val & 0xFFFF0000)| 0x00006FB8);

     old_val = (*mkptr(pa_serdes_cfg_base, 0x418));
     (*mkptr(pa_serdes_cfg_base, 0x418)) = ((old_val & 0x0000FF00)| 0x758000E4);

     old_val = (*mkptr(pa_serdes_cfg_base, 0x4AC));
     (*mkptr(pa_serdes_cfg_base, 0x4AC)) = ((old_val & 0xFFFF00FF)| 0x00004400);

     old_val = (*mkptr(pa_serdes_cfg_base, 0x42C));
     (*mkptr(pa_serdes_cfg_base, 0x42C)) = ((old_val & 0xFF0000FF)| 0x00100800);

     old_val = (*mkptr(pa_serdes_cfg_base, 0x480));
     (*mkptr(pa_serdes_cfg_base, 0x480)) = ((old_val & 0xFF00FF00)| 0x00820082);

     old_val = (*mkptr(pa_serdes_cfg_base, 0x484));
     (*mkptr(pa_serdes_cfg_base, 0x484)) = ((old_val & 0x00000000)| 0x1D0F0385);

     old_val = (*mkptr(pa_serdes_cfg_base, 0x604));
     (*mkptr(pa_serdes_cfg_base, 0x604)) = ((old_val & 0x00FFFF00)| 0x38000080);

     old_val = (*mkptr(pa_serdes_cfg_base, 0x608));
     (*mkptr(pa_serdes_cfg_base, 0x608)) = ((old_val & 0xFFFFFF00)| 0x00000000);

     old_val = (*mkptr(pa_serdes_cfg_base, 0x60C));
     (*mkptr(pa_serdes_cfg_base, 0x60C)) = ((old_val & 0x00FFFFFF)| 0x02000000);

      old_val = (*mkptr(pa_serdes_cfg_base, 0x610));
     (*mkptr(pa_serdes_cfg_base, 0x610)) = ((old_val & 0x00FFFFFF)| 0x1B000000);

     old_val = (*mkptr(pa_serdes_cfg_base, 0x614));
     (*mkptr(pa_serdes_cfg_base, 0x614)) = ((old_val & 0xFFFF0000)| 0x00006FB8);

     old_val = (*mkptr(pa_serdes_cfg_base, 0x618));
     (*mkptr(pa_serdes_cfg_base, 0x618)) = ((old_val & 0x0000FF00)| 0x758000E4);

     old_val = (*mkptr(pa_serdes_cfg_base, 0x6AC));
     (*mkptr(pa_serdes_cfg_base, 0x6AC)) = ((old_val & 0xFFFF00FF)| 0x00004400);

     old_val = (*mkptr(pa_serdes_cfg_base, 0x62C));
     (*mkptr(pa_serdes_cfg_base, 0x62C)) = ((old_val & 0xFF0000FF)| 0x00100800);

     old_val = (*mkptr(pa_serdes_cfg_base, 0x680));
     (*mkptr(pa_serdes_cfg_base, 0x680)) = ((old_val & 0xFF00FF00)| 0x00820082);

     old_val = (*mkptr(pa_serdes_cfg_base, 0x684));
     (*mkptr(pa_serdes_cfg_base, 0x684)) = ((old_val & 0x00000000)| 0x1D0F0385);

     old_val = (*mkptr(pa_serdes_cfg_base, 0x804));
     (*mkptr(pa_serdes_cfg_base, 0x804)) = ((old_val & 0x00FFFF00)| 0x38000080);

     old_val = (*mkptr(pa_serdes_cfg_base, 0x808));
     (*mkptr(pa_serdes_cfg_base, 0x808)) = ((old_val & 0xFFFFFF00)| 0x00000000);

     old_val = (*mkptr(pa_serdes_cfg_base, 0x80C));
     (*mkptr(pa_serdes_cfg_base, 0x80C)) = ((old_val & 0x00FFFFFF)| 0x02000000);

      old_val = (*mkptr(pa_serdes_cfg_base, 0x810));
     (*mkptr(pa_serdes_cfg_base, 0x810)) = ((old_val & 0x00FFFFFF)| 0x1B000000);

     old_val = (*mkptr(pa_serdes_cfg_base, 0x814));
     (*mkptr(pa_serdes_cfg_base, 0x814)) = ((old_val & 0xFFFF0000)| 0x00006FB8);

     old_val = (*mkptr(pa_serdes_cfg_base, 0x818));
     (*mkptr(pa_serdes_cfg_base, 0x818)) = ((old_val & 0x0000FF00)| 0x758000E4);

     old_val = (*mkptr(pa_serdes_cfg_base, 0x8AC));
     (*mkptr(pa_serdes_cfg_base, 0x8AC)) = ((old_val & 0xFFFF00FF)| 0x00004400);

     old_val = (*mkptr(pa_serdes_cfg_base, 0x82C));
     (*mkptr(pa_serdes_cfg_base, 0x82C)) = ((old_val & 0xFF0000FF)| 0x00100800);

     old_val = (*mkptr(pa_serdes_cfg_base, 0x880));
     (*mkptr(pa_serdes_cfg_base, 0x880)) = ((old_val & 0xFF00FF00)| 0x00820082);

     old_val = (*mkptr(pa_serdes_cfg_base, 0x884));
     (*mkptr(pa_serdes_cfg_base, 0x884)) = ((old_val & 0x00000000)| 0x1D0F0385);

     old_val = (*mkptr(pa_serdes_cfg_base, 0xa00));
    (*mkptr(pa_serdes_cfg_base, 0xa00)) = ((old_val & 0xFFFF00FF)| 0x00000800);

    old_val = (*mkptr(pa_serdes_cfg_base, 0xa08));
    (*mkptr(pa_serdes_cfg_base, 0xa08)) = ((old_val & 0x0000FFFF)| 0X38A20000);

    old_val = (*mkptr(pa_serdes_cfg_base, 0xa30));
    (*mkptr(pa_serdes_cfg_base, 0xa30)) = ((old_val & 0xFF0000FF)| 0x008A8A00);

    old_val = (*mkptr(pa_serdes_cfg_base, 0xa84));
    (*mkptr(pa_serdes_cfg_base, 0xa84)) = ((old_val & 0xFFFF00FF)| 0x00000600);

    old_val = (*mkptr(pa_serdes_cfg_base, 0xa94));
    (*mkptr(pa_serdes_cfg_base, 0xa94)) = ((old_val & 0x00FFFFFF)| 0x10000000);

    old_val = (*mkptr(pa_serdes_cfg_base, 0xaa0));
    (*mkptr(pa_serdes_cfg_base, 0xaa0)) = ((old_val & 0x00FFFFFF)| 0x81000000);

    old_val = (*mkptr(pa_serdes_cfg_base, 0xabc));
    (*mkptr(pa_serdes_cfg_base, 0xabc)) = ((old_val & 0x00FFFFFF)| 0xFF000000);

    old_val = (*mkptr(pa_serdes_cfg_base, 0xac0));
    (*mkptr(pa_serdes_cfg_base, 0xabc)) = ((old_val & 0xFFFFFF00)| 0x0000008B);

    old_val = (*mkptr(pa_serdes_cfg_base, 0xb08));
    (*mkptr(pa_serdes_cfg_base, 0xb08)) = ((old_val & 0x0000FFFF)| 0x583F0000);

    old_val = (*mkptr(pa_serdes_cfg_base, 0xb0c));
    (*mkptr(pa_serdes_cfg_base, 0xb0c)) = ((old_val & 0xFFFFFF00)| 0x0000004e);

   #ifdef  SERDES_INTERNAL_LOOPBACK
   /*Beginning of SERDES LOOPBACK Configuration*/
   old_val = (*mkptr(pa_serdes_cfg_base, 0x200));
   (*mkptr(pa_serdes_cfg_base, 0x200)) = ((old_val & 0x00FFFFFF)| 0x40000000);

   old_val = (*mkptr(pa_serdes_cfg_base, 0x400));
   (*mkptr(pa_serdes_cfg_base, 0x400)) = ((old_val & 0x00FFFFFF)| 0x40000000);

   old_val = (*mkptr(pa_serdes_cfg_base, 0x600));
   (*mkptr(pa_serdes_cfg_base, 0x600)) = ((old_val & 0x00FFFFFF)| 0x40000000);

   old_val = (*mkptr(pa_serdes_cfg_base, 0x800));
   (*mkptr(pa_serdes_cfg_base, 0x800)) = ((old_val & 0x00FFFFFF)| 0x40000000);
  /*End of Serdes loopback configuration*/
  #endif

   old_val = (*mkptr(pa_serdes_cfg_base, 0x000));
  (*mkptr(pa_serdes_cfg_base, 0x000)) = ((old_val & 0xFFFFFF00)| 0x00000003);

  old_val = (*mkptr(pa_serdes_cfg_base, 0xa00));
  (*mkptr(pa_serdes_cfg_base, 0xa00)) = ((old_val & 0xFFFFFF00)| 0x0000005F);


 /*Enable TX and RX via the LANExCTL_STS 0x0000 + x*4 */
   *mkptr(pa_serdes_cfg_base, 0x1fe0) = 0xF800F8C0;
   *mkptr(pa_serdes_cfg_base, 0x1fe4) = 0xF800F8C0;
   *mkptr(pa_serdes_cfg_base, 0x1fe8) = 0xF800F8C0;
   *mkptr(pa_serdes_cfg_base, 0x1fec) = 0xF800F8C0;

   /*Enable pll via the pll_ctrl 0x0014*/
   *mkptr(pa_serdes_cfg_base, 0x1ff4) = 0xe0000000;

  /*Waiting for SGMII Serdes PLL lock.*/
  reg_poll_to(32, SGMII0_STATUS, 0x10, 0x10, 10000);
  reg_poll_to(32, SGMII1_STATUS, 0x10, 0x10, 10000);
  reg_poll_to(32, SGMII2_STATUS, 0x10, 0x10, 10000);
  reg_poll_to(32, SGMII3_STATUS, 0x10, 0x10, 10000);


  for(i = 0; i < 5000; i++);
  for(i = 0; i < 40000; i++);
}


/**
 *  @brief
 *      Configure the sgmii Serdes on devices using the initialization sequence
 */
void configSerdes()
{
	CSL_SgmiiDefSerdesSetup();
    /* All done with configuration. Return Now. */
    return;
}

/** ============================================================================
 *   @n@b Init_SGMII
 *
 *   @b Description
 *   @n SGMII peripheral initialization code.
 *
 *   @param[in]
 *   @n macPortNum      MAC port number for which the SGMII port setup must
 *                      be performed.
 *
 *   @return
 *   @n None
 * =============================================================================
 */
#ifdef SIMULATOR_SUPPORT
void Init_SGMII (uint32_t macPortNum)
{
    CSL_SGMII_ADVABILITY    sgmiiCfg;
	CSL_SGMII_STATUS        sgmiiStatus;

    /* Reset the port before configuring it */
    CSL_SGMII_doSoftReset (macPortNum);
    while (CSL_SGMII_getSoftResetStatus (macPortNum) != 0);

    /* Hold the port in soft reset and set up
     * the SGMII control register:
     *      (1) Enable Master Mode
     *      (2) Enable Auto-negotiation
     */
    CSL_SGMII_startRxTxSoftReset (macPortNum);
    CSL_SGMII_enableMasterMode (macPortNum);
    CSL_SGMII_enableAutoNegotiation (macPortNum);
    CSL_SGMII_endRxTxSoftReset (macPortNum);

    /* Setup the Advertised Ability register for this port:
     *      (1) Enable Full duplex mode
     *      (2) Enable Auto Negotiation
     *      (3) Enable the Link
     */
    sgmiiCfg.linkSpeed      =   CSL_SGMII_1000_MBPS;
    sgmiiCfg.duplexMode     =   CSL_SGMII_FULL_DUPLEX;
    CSL_SGMII_setAdvAbility (macPortNum, &sgmiiCfg);

    /* All done with configuration. Return Now. */
    return;
}
#else
void Init_SGMII (uint32_t macPortNum)
{
    CSL_SGMII_ADVABILITY    sgmiiCfg;
    CSL_SGMII_STATUS        sgmiiStatus;

    /* Reset the port before configuring it */
    CSL_SGMII_doSoftReset (macPortNum);
    while (CSL_SGMII_getSoftResetStatus (macPortNum) != 0);

     if (macPortNum < 2) {
        /* Hold the port in soft reset and set up
         * the SGMII control register:
         *      (1) Enable Master Mode
         *      (2) Enable Auto-negotiation
         */
        CSL_SGMII_startRxTxSoftReset (macPortNum);
        CSL_SGMII_disableMasterMode (macPortNum);
        CSL_SGMII_enableAutoNegotiation (macPortNum);
        CSL_SGMII_endRxTxSoftReset (macPortNum);

        /* Setup the Advertised Ability register for this port:
         *      (1) Enable Full duplex mode
         *      (2) Enable Auto Negotiation
         *      (3) Enable the Link
         */
        sgmiiCfg.linkSpeed      =   CSL_SGMII_1000_MBPS;
        sgmiiCfg.duplexMode     =   CSL_SGMII_FULL_DUPLEX;
        CSL_SGMII_setAdvAbility (macPortNum, &sgmiiCfg);

        do
        {
            CSL_SGMII_getStatus(macPortNum, &sgmiiStatus);
        } while (sgmiiStatus.bIsLinkUp != 1);

        /* Wait for SGMII Autonegotiation to complete without error */
        do
        {
            CSL_SGMII_getStatus(macPortNum, &sgmiiStatus);
            if (sgmiiStatus.bIsAutoNegError != 0)
                return; /* This is an error condition */
        } while (sgmiiStatus.bIsAutoNegComplete != 1);
    }

    if (macPortNum >= 2) {
        /* Hold the port in soft reset and set up
         * the SGMII control register:
         *      (1) Disable Master Mode
         *      (2) Enable Auto-negotiation
         */
        CSL_SGMII_startRxTxSoftReset (macPortNum);
        CSL_SGMII_disableMasterMode (macPortNum);
        CSL_SGMII_enableAutoNegotiation (macPortNum);
        CSL_SGMII_endRxTxSoftReset (macPortNum);

        /* Setup the Advertised Ability register for this port:
         *      (1) Enable Full duplex mode
         *      (2) Enable Auto Negotiation
         *      (3) Enable the Link
         */
        sgmiiCfg.linkSpeed      =   CSL_SGMII_1000_MBPS;
        sgmiiCfg.duplexMode     =   CSL_SGMII_FULL_DUPLEX;
        sgmiiCfg.bLinkUp        =   1;
        CSL_SGMII_setAdvAbility (macPortNum, &sgmiiCfg);

        do
        {
            CSL_SGMII_getStatus(macPortNum, &sgmiiStatus);
        } while (sgmiiStatus.bIsLinkUp != 1);
     }

    /* All done with configuration. Return Now. */
    return;
}
#endif


